@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./cocci.ml"
 open Common
 
 module CCI = Ctlcocci_integration
@@ -65,7 +44,6 @@ let cfile_of_program program2_with_ppmethod outf =
 (* for memoization, contains only one entry, the one for the SP *)
 let _hparse = Hashtbl.create 101
 let _h_ocaml_init = Hashtbl.create 101
-let _hctl = Hashtbl.create 101
 
 (* --------------------------------------------------------------------- *)
 (* Cocci related *)
@@ -387,7 +365,7 @@ let show_or_not_rule_name ast rulenb =
 	match ast with
 	  Ast_cocci.CocciRule (nm, (deps, drops, exists), x, _, _) -> nm
 	| Ast_cocci.ScriptRule (nm, _, _, _, _, _) -> nm
-	| _ -> i_to_s rulenb in
+	| _ -> string_of_int rulenb in
       Common.pr_xxxxxxxxxxxxxxxxx ();
       pr (name ^ " = ");
       Common.pr_xxxxxxxxxxxxxxxxx ()
@@ -403,14 +381,14 @@ let show_or_not_scr_rule_name name =
       Common.pr_xxxxxxxxxxxxxxxxx ()
     end
 
-let show_or_not_ctl_text2 ctl ast rulenb =
+let show_or_not_ctl_text2 ctl mvs ast rulenb =
   if !Flag_cocci.show_ctl_text then begin
 
     adjust_pp_with_indent (fun () ->
       Format.force_newline();
       Pretty_print_cocci.print_plus_flag := true;
       Pretty_print_cocci.print_minus_flag := true;
-      Pretty_print_cocci.unparse ast;
+      Pretty_print_cocci.unparse mvs ast;
       );
 
     pr "CTL = ";
@@ -422,8 +400,8 @@ let show_or_not_ctl_text2 ctl ast rulenb =
       );
     pr "";
   end
-let show_or_not_ctl_text a b c =
-      Common.profile_code "show_xxx" (fun () -> show_or_not_ctl_text2 a b c)
+let show_or_not_ctl_text a b c d =
+      Common.profile_code "show_xxx" (fun () -> show_or_not_ctl_text2 a b c d)
 
 
 
@@ -447,17 +425,25 @@ let show_or_not_celem2 prelude celem =
   |  Ast_c.Definition ({Ast_c.f_name = namefuncs},_) ->
       let funcs = Ast_c.str_of_name namefuncs in
       Flag.current_element := funcs;
-      (" function: ",funcs)
+      (" function: ",Some (funcs,namefuncs))
   |  Ast_c.Declaration
       (Ast_c.DeclList ([{Ast_c.v_namei = Some (name,_)}, _], _)) ->
       let s = Ast_c.str_of_name name in
       Flag.current_element := s;
-      (" variable ",s);
+      (" variable ",Some(s,name));
   |  _ ->
       Flag.current_element := "something_else";
-      (" ","something else");
+      (" ",None);
   ) in
-  if !Flag.show_trying then pr2 (prelude ^ tag ^ trying)
+  if !Flag.show_trying
+  then
+    match trying with
+      Some(str,name) ->
+	let info = Ast_c.info_of_name name in
+	let file = Filename.basename(Ast_c.file_of_info info) in
+	let line = Ast_c.line_of_info info in
+	pr2 (Printf.sprintf "%s%s%s: %s:%d" prelude tag str file line)
+    | None -> pr2 (Printf.sprintf "%s%s something else" prelude tag)
 
 let show_or_not_celem a b  =
   Common.profile_code "show_xxx" (fun () -> show_or_not_celem2 a b)
@@ -468,7 +454,7 @@ let show_or_not_trans_info2 trans_info =
   let trans_info =
     List.map (function (index,trans_info) -> trans_info) trans_info in
   if !Flag.show_transinfo then begin
-    if null trans_info then pr2 "transformation info is empty"
+    if trans_info = [] then pr2 "transformation info is empty"
     else begin
       pr2 "transformation info returned:";
       let trans_info =
@@ -477,7 +463,7 @@ let show_or_not_trans_info2 trans_info =
       in
       indent_do (fun () ->
         trans_info +> List.iter (fun (i, subst, re) ->
-          pr2 ("transform state: " ^ (Common.i_to_s i));
+          pr2 ("transform state: " ^ (string_of_int i));
           indent_do (fun () ->
             adjust_pp_with_indent_and_header "with rule_elem: " (fun () ->
               Pretty_print_cocci.print_plus_flag := true;
@@ -519,8 +505,9 @@ let worth_trying2 cfiles (tokens,_,query,_) =
   let res =
   match (!Flag_cocci.windows,!Flag.scanner,tokens,query,cfiles) with
     (true,_,_,_,_) | (_,_,None,_,_) | (_,_,_,None,_) | (_,Flag.CocciGrep,_,_,_)
+      | (_,Flag.GitGrep,_,_,_)
     -> true
-  | (_,_,_,Some query,[cfile]) -> Cocci_grep.interpret query cfile
+  | (_,_,_,Some (q1,q2,_),[cfile]) -> Cocci_grep.interpret (q1,q2) cfile
   | (_,_,Some tokens,_,_) ->
    (* could also modify the code in get_constants.ml *)
       let tokens = tokens +> List.map (fun s ->
@@ -537,8 +524,8 @@ let worth_trying2 cfiles (tokens,_,query,_) =
 
       ) in
       let com =
-	sprintf "egrep -q '(%s)' %s" (join "|" tokens) (join " " cfiles)
-      in
+	Printf.sprintf "egrep -q '(%s)' %s"
+	  (String.concat "|" tokens) (String.concat " " cfiles) in
       (match Sys.command com with
       | 0 (* success *) -> true
       | _ (* failure *) ->
@@ -547,8 +534,8 @@ let worth_trying2 cfiles (tokens,_,query,_) =
 	  false (* no match, so not worth trying *)) in
   (match (res,tokens) with
     (false,Some tokens) ->
-      pr2_once ("Expected tokens " ^ (Common.join " " tokens));
-      pr2 ("Skipping:" ^ (Common.join " " cfiles))
+      pr2_once ("Expected tokens " ^ (String.concat " " tokens));
+      pr2 ("Skipping:" ^ (String.concat " " cfiles))
   | _ -> ());
   res
 
@@ -689,11 +676,11 @@ let interpret_include_path relpath =
 	| None -> search_include_path exists tail relpath) in
   let rec search_path exists searchlist = function
       [] ->
-	let res = Common.concat "/" relpath in
+	let res = String.concat "/" relpath in
 	cache_add include_table (searchlist,relpath) res;
 	Some res
     | (hd::tail) as relpath1 ->
-	let relpath1 = Common.concat "/" relpath1 in
+	let relpath1 = String.concat "/" relpath1 in
 	(match search_include_path exists searchlist relpath1 with
 	  None -> search_path unique_file_exists searchlist tail
 	| Some f ->
@@ -718,7 +705,7 @@ let (includes_to_parse:
 	  [Flag_cocci.I_ALL_INCLUDES; Flag_cocci.I_REALLY_ALL_INCLUDES] in
       let xs = List.map (function (file,(cs,_,_)) -> (file,cs)) xs in
       xs +> List.map (fun (file, cs) ->
-	let dir = Common.dirname file in
+	let dir = Filename.dirname file in
 
 	cs +> Common.map_filter (fun (c,_info_item) ->
 	  match c with
@@ -727,7 +714,7 @@ let (includes_to_parse:
 		 {Ast_c.i_include = ((x,ii)); i_rel_pos = info_h_pos;})  ->
 	    (match x with
             | Ast_c.Local xs ->
-		let relpath = Common.join "/" xs in
+		let relpath = String.concat "/" xs in
 		let f = Filename.concat dir relpath in
 		if (Sys.file_exists f)
 		then Some f
@@ -745,7 +732,7 @@ let (includes_to_parse:
 
             | Ast_c.NonLocal xs ->
 		if all_includes ||
-	        Common.fileprefix (Common.last xs) =$= Common.fileprefix file
+	        Common.fileprefix (Common.last xs) = Common.fileprefix file
 		then interpret_include_path xs
 		else None
             | Ast_c.Weird _ -> None
@@ -922,7 +909,7 @@ type toplevel_cocci_info_script_rule = {
   scr_ast_rule:
       string *
       (Ast_cocci.script_meta_name * Ast_cocci.meta_name *
-	 Ast_cocci.metavar) list *
+	 Ast_cocci.metavar * Ast_cocci.mvinit) list *
       Ast_cocci.meta_name list (*fresh vars*) *
       string;
   language: string;
@@ -961,7 +948,8 @@ type cocci_info = toplevel_cocci_info list *
 type constant_info =
     (string list option (*grep tokens*) *
        string list option (*glimpse tokens*) *
-       (Str.regexp * Str.regexp list) option (*coccigrep tokens*) *
+       (Str.regexp * Str.regexp list * string list)
+       option (*coccigrep/gitgrep tokens*) *
        Get_constants2.combine option)
 
 type kind_file = Header | Source
@@ -1056,7 +1044,7 @@ let prepare_cocci ctls free_var_lists negated_pos_lists
 	| Ast_cocci.InitialScriptRule _ | Ast_cocci.FinalScriptRule _ -> true
 	| _ -> false in
 
-      if not (List.length ctl_toplevel_list =|= 1) && not (is_script_rule ast)
+      if not (List.length ctl_toplevel_list = 1) && not (is_script_rule ast)
       then failwith "not handling multiple minirules";
 
       match ast with
@@ -1250,7 +1238,7 @@ let rec prepare_h seen env (hpath : string) choose_includes parse_strings
   | Some h_cs ->
       (*let h_cs = cprogram_of_file_cached parse_strings hpath in*)
       let local_includes =
-	if choose_includes =*= Flag_cocci.I_REALLY_ALL_INCLUDES
+	if choose_includes = Flag_cocci.I_REALLY_ALL_INCLUDES
 	then
 	  List.filter
 	    (function x -> not (List.mem x !seen))
@@ -1265,12 +1253,12 @@ let rec prepare_h seen env (hpath : string) choose_includes parse_strings
 	     local_includes) in
       let info_h_cs = build_info_program h_cs !env in
       env :=
-	if null info_h_cs
+	if info_h_cs = []
 	then !env
 	else last_env_toplevel_c_info info_h_cs;
       others@
       [{
-	fname = Common.basename hpath;
+	fname = Filename.basename hpath;
 	full_fname = hpath;
 	asts = info_h_cs;
 	was_modified_once = ref false;
@@ -1289,7 +1277,6 @@ let prepare_c files choose_includes parse_strings : file_info list =
 	       pr2_once ("C file " ^ file ^ " not readable");
 	       prev)
 	 [] files) in
-  let (files,cprograms) = List.split files_and_cprograms in
   let includes = includes_to_parse files_and_cprograms choose_includes in
   let seen = ref includes in
 
@@ -1307,7 +1294,7 @@ let prepare_c files choose_includes parse_strings : file_info list =
   Flag_parsing_c.parsing_header_for_types := false;
 
   let cfiles =
-    (zip files cprograms) +>
+    files_and_cprograms +>
     List.map
       (function (file, cprogram) ->
       (* todo?: don't update env ? *)
@@ -1315,7 +1302,7 @@ let prepare_c files choose_includes parse_strings : file_info list =
         (* we do that only for the c, not for the h *)
         ignore(update_include_rel_pos (cs +> List.map (fun x -> x.ast_c)));
         {
-        fname = Common.basename file;
+        fname = Filename.basename file;
         full_fname = file;
         asts = cs;
         was_modified_once = ref false;
@@ -1431,11 +1418,13 @@ let merge_env new_e old_e =
 
 let merge_env_list new_e old_e = new_e@old_e
 
-let contains_binding e (_,(r,m),_) =
-  try
-    let _ = List.find (function ((re, rm), _) -> r =*= re && m =$= rm) e in
-    true
-  with Not_found -> false
+let contains_binding e = function
+    (_,(r,m),_,Ast_cocci.NoMVInit) ->
+      (try
+	let _ = List.find (function ((re, rm), _) -> r = re && m = rm) e in
+	true
+      with Not_found -> false)
+  | _ -> true
 
 exception Exited
 
@@ -1443,7 +1432,7 @@ let python_application mv ve script_vars r =
   let mv =
     List.map
       (function
-	  ((Some x,None),y,z) -> (x,y,z)
+	  ((Some x,None),y,z,init) -> (x,y,z,init)
 	| _ ->
 	    failwith
 	      (Printf.sprintf "unexpected ast metavar in rule %s"
@@ -1494,7 +1483,7 @@ let apply_script_rule r cache newes e rules_that_have_matched
     begin
       let (_, mv, script_vars, _) = r.scr_ast_rule in
       let ve =
-	(List.map (function (n,v) -> (("virtual",n),Ast_c.MetaIdVal (v,[])))
+	(List.map (function (n,v) -> (("virtual",n),Ast_c.MetaIdVal (v)))
 	   !Flag.defined_virtual_env) @ e in
       let not_bound x = not (contains_binding ve x) in
       (match List.filter not_bound mv with
@@ -1502,7 +1491,7 @@ let apply_script_rule r cache newes e rules_that_have_matched
 	  let relevant_bindings =
 	    List.filter
 	      (function ((re,rm),_) ->
-		List.exists (function (_,(r,m),_) -> r =*= re && m =$= rm) mv)
+		List.exists (function (_,(r,m),_,_) -> r = re && m = rm) mv)
 	      e in
 	  (try
 	    match List.assoc relevant_bindings cache with
@@ -1534,10 +1523,11 @@ let apply_script_rule r cache newes e rules_that_have_matched
 		  (* failure means we should drop e, no new bindings *)
 		  (((relevant_bindings,None) :: cache), newes)
 	      | Some script_vals ->
-		  let script_vals =
-		    List.map (function x -> Ast_c.MetaIdVal(x,[]))
-		      script_vals in
-		  let new_e = (List.combine script_vars script_vals) @ e in
+		  let script_var_env =
+		    List.filter
+		      (function (x,Ast_c.MetaNoVal) -> false | _ -> true)
+		      (List.combine script_vars script_vals) in
+		  let new_e = script_var_env @ e in
 		  let new_e =
 		    new_e +>
 		    List.filter
@@ -1550,7 +1540,7 @@ let apply_script_rule r cache newes e rules_that_have_matched
       |	unbound ->
 	  (if !Flag_cocci.show_dependencies
 	  then
-	    let m2c (_,(r,x),_) = r^"."^x in
+	    let m2c (_,(r,x),_,_) = r^"."^x in
 	    pr2 (Printf.sprintf "script not applied: %s not bound"
 		   (String.concat ", " (List.map m2c unbound))));
 	  let e =
@@ -1588,7 +1578,7 @@ let consistent_positions binding reqopts =
       [] -> true
     | [_] -> true
     | l::ls ->
-	let desired_functions = 
+	let desired_functions =
 	  List.fold_left
             (fun prev (_,elem,_,_) ->
               if not (List.mem elem prev) then elem::prev else prev)
@@ -1611,7 +1601,7 @@ let rec apply_cocci_rule r rules_that_have_ever_matched parse_strings es
     (ccs:file_info list ref) =
   Common.profile_code r.rule_info.rulename (fun () ->
     show_or_not_rule_name r.ast_rule r.rule_info.ruleid;
-    show_or_not_ctl_text r.ctl r.ast_rule r.rule_info.ruleid;
+    show_or_not_ctl_text r.ctl r.metavars r.ast_rule r.rule_info.ruleid;
 
     let reorganized_env =
       reassociate_positions r.free_vars r.negated_pos_vars !es in
@@ -1718,13 +1708,13 @@ let rec apply_cocci_rule r rules_that_have_ever_matched parse_strings es
 		   List.filter
 		     (fun (s,v) -> List.mem s r.rule_info.used_after)) in
 	      let new_e =
-		if null new_bindings
+		if new_bindings = []
 		then
 		  begin
 		  (*use the old bindings, specialized to the used_after_list*)
 		    if !Flag_ctl.partial_match
 		    then
-		      printf
+		      Printf.printf
 			"Empty list of bindings, I will restart from old env\n";
 		    [(old_bindings_to_keep,rules_that_have_matched)]
 		  end
@@ -1823,7 +1813,7 @@ and reassociate_positions free_vars negated_pos_vars envs =
 	       (function (other_non_pos,other_pos) ->
                  (* do we want equal? or just somehow compatible? eg non_pos
 		    binds only E, but other_non_pos binds both E and E1 *)
-		 non_pos =*= other_non_pos)
+		 non_pos = other_non_pos)
 	       splitted_relevant in
 	   Hashtbl.add extended_relevant non_pos
 	     (List.sort compare
@@ -1864,7 +1854,7 @@ and process_a_generated_a_env_a_toplevel2 r env = function
       let free_vars =
 	List.filter
 	  (function
-	      (rule,_) when rule =$= r.rule_info.rulename -> false
+	      (rule,_) when rule = r.rule_info.rulename -> false
 	    | (_,"ARGS") -> false
 	    | _ -> true)
 	  r.free_vars in
@@ -1872,7 +1862,7 @@ and process_a_generated_a_env_a_toplevel2 r env = function
       let metavars =
 	List.filter
 	  (function md ->
-	    let (rl,_) = Ast_cocci.get_meta_name md in rl =$= r.rule_info.rulename)
+	    let (rl,_) = Ast_cocci.get_meta_name md in rl = r.rule_info.rulename)
 	  r.metavars in
       if Common.include_set free_vars env_domain
       then Unparse_hrule.pp_rule metavars r.ast_rule env cfile.full_fname
@@ -1915,7 +1905,7 @@ and process_a_ctl_a_env_a_toplevel2 r e c f =
 
 	   r.rule_info.was_matched := true;
 
-	   if not (null trans_info) &&
+	   if trans_info <> [] &&
 	     not (!Flag.sgrep_mode2 && not !Flag_cocci.show_diff)
 	   then
 	     begin
@@ -1966,7 +1956,7 @@ let rec bigloop2 rs (ccs: file_info list) parse_strings =
             let (l,mv,script_vars,code) = r.scr_ast_rule in
 	    let nm = r.scr_rule_info.rulename in
 	    let deps = r.scr_rule_info.dependencies in
-            Pretty_print_cocci.unparse
+            Pretty_print_cocci.unparse []
 	      (Ast_cocci.ScriptRule (nm,l,deps,mv,script_vars,code)));
 	end;
 
@@ -2038,7 +2028,7 @@ let initial_final_bigloop2 ty rebuild r =
 
       adjust_pp_with_indent (fun () ->
 	Format.force_newline();
-	Pretty_print_cocci.unparse
+	Pretty_print_cocci.unparse []
 	  (rebuild r.scr_ast_rule r.scr_rule_info.dependencies));
     end;
 
@@ -2174,7 +2164,7 @@ let full_engine2 (cocci_infos,parse_strings) cfiles =
   if !Flag_cocci.selected_only
   then
     begin
-      pr2 ("selected " ^ (Common.join " " cfiles));
+      pr2 ("selected " ^ (String.concat " " cfiles));
       cfiles +> List.map (fun s -> s, None)
     end
   else
@@ -2222,7 +2212,7 @@ let full_engine2 (cocci_infos,parse_strings) cfiles =
             let outfile =
 	      Common.new_temp_file "cocci-output" ("-" ^ c_or_h.fname) in
 
-            if c_or_h.fkind =*= Header
+            if c_or_h.fkind = Header
             then pr2 ("a header file was modified: " ^ c_or_h.fname);
 
             (* and now unparse everything *)
@@ -2280,9 +2270,9 @@ let has_finalize (cocci_infos,_) =
 (*****************************************************************************)
 
 let check_duplicate_modif2 xs =
-  (* opti: let groups = Common.groupBy (fun (a,resa) (b,resb) -> a =$= b) xs *)
+  (* opti: let groups = Common.groupBy (fun (a,resa) (b,resb) -> a = b) xs *)
   if !Flag_cocci.verbose_cocci
-  then pr2 ("Check duplication for " ^ i_to_s (List.length xs) ^ " files");
+  then pr2 ("Check duplication for " ^ string_of_int (List.length xs) ^ " files");
 
   let groups = Common.group_assoc_bykey_eff xs in
   groups +> Common.map_filter (fun (file, xs) ->
@@ -2292,7 +2282,7 @@ let check_duplicate_modif2 xs =
     | res::xs ->
         match res with
         | None ->
-            if not (List.for_all (fun res2 -> res2 =*= None) xs)
+            if not (List.for_all (fun res2 -> res2 = None) xs)
             then begin
               pr2 ("different modification result for " ^ file);
               None
@@ -2305,7 +2295,7 @@ let check_duplicate_modif2 xs =
               | Some res2 ->
                   let diff = Common.cmd_to_list ("diff -u -b -B "^res^" "^res2)
                   in
-                  null diff
+                  diff = []
             ) xs) then begin
               pr2 ("different modification result for " ^ file);
               None
@@ -2314,4 +2304,3 @@ let check_duplicate_modif2 xs =
   )
 let check_duplicate_modif a =
   Common.profile_code "check_duplicate" (fun () -> check_duplicate_modif2 a)
-
