@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./cocci.mli"
 open Common
 
 (* full_engine takes (coccifile, isofile) and cfiles in parameters and
@@ -42,7 +21,8 @@ type cocci_info
 type constant_info =
     string list option (*grep tokens*) *
       string list option (*glimpse tokens*) *
-      (Str.regexp * Str.regexp list) option (*coccigrep tokens*) *
+      (Str.regexp * Str.regexp list * string list)
+      option (*coccigrep/gitgrep tokens*) *
       Get_constants2.combine option
 val pre_engine : (filename * filename) -> cocci_info * constant_info
 val worth_trying : filename list -> constant_info -> bool
@@ -71,11 +51,7 @@ val sp_of_file :
 	 Ast_cocci.meta_name list list list *
 	 (*fresh used after list seeds*)
 	 Ast_cocci.meta_name list list list) *
-      Ast_cocci.meta_name list list list *
-      (string list option (*grep tokens*) *
-	 string list option (*glimpse tokens*) *
-	 (Str.regexp * Str.regexp list) option (*coccigrep tokens*) *
-	 Get_constants2.combine option) *
+      Ast_cocci.meta_name list list list * constant_info *
       bool (* format information needed for strings? *)
 
 val normalize_path : string -> string
