@@ -154,11 +154,6 @@ val redirect_stdin_opt : filename option -> (unit -> 'a) -> 'a
 
 val with_pr2_to_string: (unit -> unit) -> string list
 
-val fprintf : out_channel -> ('a, out_channel, unit) format -> 'a
-val printf : ('a, out_channel, unit) format -> 'a
-val eprintf : ('a, out_channel, unit) format -> 'a
-val sprintf : ('a, unit, string) format -> 'a
-
 (* alias *)
 val spf : ('a, unit, string) format -> 'a
 
@@ -201,28 +196,6 @@ val debug : (unit -> unit) -> unit
 (* Profiling (cpu/mem) *)
 (*****************************************************************************)
 
-val get_mem : unit -> unit
-val memory_stat : unit -> string
-
-val timenow : unit -> string
-
-val _count1 : int ref
-val _count2 : int ref
-val _count3 : int ref
-val _count4 : int ref
-val _count5 : int ref
-
-val count1 : unit -> unit
-val count2 : unit -> unit
-val count3 : unit -> unit
-val count4 : unit -> unit
-val count5 : unit -> unit
-val profile_diagnostic_basic : unit -> string
-
-val time_func : (unit -> 'a) -> 'a
-
-
-
 (* see flag: type prof = PALL | PNONE | PSOME of string list *)
 (* see flag: val profile : prof ref *)
 
@@ -358,13 +331,6 @@ val adjust_pp_with_indent_and_header : string -> (unit -> unit) -> unit
 val mk_str_func_of_assoc_conv:
   ('a * string) list -> (string -> 'a) * ('a -> string)
 
-(*****************************************************************************)
-(* Macro *)
-(*****************************************************************************)
-
-(* was working with my macro.ml4 *)
-val macro_expand : string -> unit
-
 (*****************************************************************************)
 (* Composition/Control *)
 (*****************************************************************************)
@@ -493,7 +459,6 @@ val exn_to_s : exn -> string
 (* alias *)
 val string_of_exn : exn -> string
 
-type error = Error of string
 
 type evotype = unit
 val evoval : evotype
@@ -575,38 +540,6 @@ val action_list:
 val do_action:
   Arg.key -> string list (* args *) -> cmdline_actions -> unit
 
-(*****************************************************************************)
-(* Equality *)
-(*****************************************************************************)
-
-(* Using the generic (=) is tempting, but it backfires, so better avoid it *)
-
-(* To infer all the code that use an equal, and that should be
- * transformed, is not that easy, because (=) is used by many
- * functions, such as List.find, List.mem, and so on. The strategy to find
- * them is to turn what you were previously using into a function, because
- * (=) return an exception when applied to a function, then you simply
- * use ocamldebug to detect where the code has to be transformed by
- * finding where the exception was launched from.
- *)
-
-val (=|=) : int    -> int    -> bool
-val (=<=) : char   -> char   -> bool
-val (=$=) : string -> string -> bool
-val (=:=) : bool   -> bool   -> bool
-
-val (=*=): 'a -> 'a -> bool
-
-(* if want to restrict the use of '=', uncomment this:
- *
- * val (=): unit -> unit -> bool
- *
- * But it will not forbid you to use caml functions like List.find, List.mem
- * which internally use this convenient but evolution-unfriendly (=)
-*)
-
-
-
 (*###########################################################################*)
 (* And now basic types *)
 (*###########################################################################*)
@@ -818,12 +751,6 @@ type bool3 = True3 | False3 | TrueFalsePb3 of string
 (* Strings *)
 (*****************************************************************************)
 
-val slength : string -> int (* alias *)
-val concat : string -> string list -> string (* alias *)
-
-val i_to_s : int -> string
-val s_to_i : string -> int
-
 (* strings take space in memory. Better when can share the space used by
  * similar strings.
  *)
@@ -845,7 +772,6 @@ val lowercase : string -> string
 
 val quote : string -> string
 
-val null_string : string -> bool
 val is_blank_string : string -> bool
 val is_string_prefix : string -> string -> bool
 
@@ -890,7 +816,6 @@ val matched7 : string -> string * string * string * string * string * string * s
 val string_match_substring : Str.regexp -> string -> bool
 
 val split : string (* sep regexp *) -> string -> string list
-val join : string (* sep *) -> string list -> string
 
 val split_list_regexp : string -> string list -> (string * string list) list
 
@@ -906,8 +831,6 @@ val contain_regular_word: string -> bool
 (*****************************************************************************)
 
 (* now at beginning of this file: type filename = string *)
-val dirname : string -> string
-val basename : string -> string
 
 val filesuffix : filename -> string
 val fileprefix : filename -> string
@@ -1039,6 +962,8 @@ val min_dmy : date_dmy -> date_dmy -> date_dmy
 val maximum_dmy : date_dmy list -> date_dmy
 val minimum_dmy : date_dmy list -> date_dmy
 
+val this_year : unit -> int
+
 (*****************************************************************************)
 (* Lines/Words/Strings *)
 (*****************************************************************************)
@@ -1272,9 +1197,6 @@ val removelast : 'a list -> 'a list
 val inits : 'a list -> 'a list list
 val tails : 'a list -> 'a list list
 
-
-val ( ++ ) : 'a list -> 'a list -> 'a list
-
 val foldl1 : ('a -> 'a -> 'a) -> 'a list -> 'a
 val fold_k : ('a -> 'b -> ('a -> 'a) -> 'a) -> ('a -> 'a) -> 'a -> 'b list -> 'a
 val fold_right1 : ('a -> 'a -> 'a) -> 'a list -> 'a
@@ -1448,6 +1370,7 @@ val union_set : 'a set -> 'a set -> 'a set
 val minus_set : 'a set -> 'a set -> 'a set
 
 val union_all : ('a set) list -> 'a set
+val inter_all : ('a set) list -> 'a set
 
 val big_union_set : ('a -> 'b set) -> 'a set -> 'b set
 val card_set : 'a set -> int
@@ -1818,15 +1741,10 @@ val forall : ('a -> bool) -> 'a list -> bool
 
 val big_union : ('a -> 'b set) -> 'a list -> 'b set
 
-(* same than [] but easier to search for, because [] can also be a pattern *)
-val empty_list : 'a list
-
 val sort : ('a -> 'a -> int) -> 'a list -> 'a list
 
 val length : 'a list -> int
 
-val null : 'a list -> bool
-
 val head : 'a list -> 'a
 val tail : 'a list -> 'a list
 
@@ -1844,12 +1762,6 @@ val is_singleton : 'a list -> bool
 (* And now misc functions *)
 (*###########################################################################*)
 
-(*****************************************************************************)
-(* DB (LFS) *)
-(*****************************************************************************)
-
-(* cf oassocbdb.ml or oassocdbm.ml  *)
-
 (*****************************************************************************)
 (* GUI (LFS, CComment, otimetracker) *)
 (*****************************************************************************)
@@ -1950,12 +1862,6 @@ val full_charpos_to_pos : filename -> (int * int) array
 val complete_parse_info :
   filename -> (int * int) array -> parse_info -> parse_info
 
-val full_charpos_to_pos_large:
-  filename -> (int -> (int * int))
-
-val complete_parse_info_large :
-  filename -> (int -> (int * int))  -> parse_info -> parse_info
-
 (* return line x col x str_line  from a charpos. This function is quite
  * expensive so don't use it to get the line x col from every token in
  * a file. Instead use full_charpos_to_pos.
@@ -2043,4 +1949,3 @@ class ['a] olist :
   end
 
 val typing_sux_test : unit -> unit
-
