@@ -2,7 +2,7 @@ open Common
 
 open Oassoc
 
-class ['a,'b] oassocb xs = 
+class ['a,'b] oassocb xs =
   object(o)
     inherit ['a,'b] oassoc
 
@@ -16,12 +16,11 @@ class ['a,'b] oassocb xs =
 
     method del (k,v) = {< data = Mapb.remove k data >}
     method mem e = raise Todo
-    method null = (Mapb.height data =|= 0)
+    method null = (Mapb.height data = 0)
 
     method assoc k = Mapb.find k data
     method delkey k = {< data = Mapb.remove k data >}
 
-    method keys = 
+    method keys =
       List.map fst (o#tolist)
-end     
-
+end
