@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./ctl_engine.ml"
 (*external c_counter : unit -> int = "c_counter"*)
 let timeout = 800
 (* Optimize triples_conj by first extracting the intersection of the two sets,
@@ -144,7 +123,7 @@ module OGRAPHEXT_GRAPH =
     type node = int;;
     type cfg = (string,unit) Ograph_extended.ograph_mutable;;
     let predecessors cfg n = List.map fst ((cfg#predecessors n)#tolist);;
-    let print_node i = Format.print_string (Common.i_to_s i)
+    let print_node i = Format.print_string (string_of_int i)
   end
 ;;
 
@@ -1047,44 +1026,6 @@ let pre_forall dir (grp,_,states) y all reqst =
       (*normalize*)
         (foldl1 (@) (List.map (foldl1 triples_conj) neighbor_triples))
 
-let pre_forall_AW dir (grp,_,states) y all reqst =
-  let check s =
-    match reqst with
-      None -> true | Some reqst -> List.mem s reqst in
-  let pred =
-    match dir with
-      A.FORWARD -> G.predecessors | A.BACKWARD -> G.successors in
-  let succ =
-    match dir with
-      A.FORWARD -> G.successors | A.BACKWARD -> G.predecessors in
-  let neighbors =
-    List.map
-      (function p -> (p,succ grp p))
-      (setify
-	 (concatmap
-	    (function (s,_,_) -> List.filter check (pred grp s)) y)) in
-  (* would a hash table be more efficient? *)
-  let all = List.sort state_compare all in
-  let rec up_nodes child s = function
-      [] -> []
-    | (s1,th,wit)::xs ->
-	(match compare s1 child with
-	  -1 -> up_nodes child s xs
-	| 0 -> (s,th,wit)::(up_nodes child s xs)
-	| _ -> []) in
-  let neighbor_triples =
-    List.fold_left
-      (function rest ->
-	function (s,children) ->
-	  (List.map
-	     (function child ->
-	       match up_nodes child s all with [] -> raise AW | l -> l)
-	     children) :: rest)
-      [] neighbors in
-  match neighbor_triples with
-    [] -> []
-  | _ -> foldl1 (@) (List.map (foldl1 triples_conj_AW) neighbor_triples)
-
 (* drop_negwits will call setify *)
 let satEX dir m s reqst = pre_exist dir m s reqst;;
 
@@ -1129,6 +1070,31 @@ let satEU dir ((_,_,states) as m) s1 s2 reqst print_graph =
       setfix f s2
 ;;
 
+let satEU_forAW dir ((cfg,_,states) as m) s1 s2 reqst print_graph =
+  if s1 = []
+  then s2
+  else
+    if !pNEW_INFO_OPT
+    then
+      let rec f y new_info =
+	if List.exists (G.extract_is_loop cfg) (get_states new_info)
+	then raise AW
+	else
+	  match new_info with
+	    [] -> y
+	  | new_info ->
+	      let first = triples_conj s1 (pre_exist dir m new_info reqst) in
+	      let res = triples_union first y in
+	      let new_info = setdiff res y in
+	      f res new_info in
+      f s2 s2
+    else
+      let f y =
+	let pre = pre_exist dir m y reqst in
+	triples_union s2 (triples_conj s1 pre) in
+      setfix f s2
+;;
+
 (* EF phi == E[true U phi] *)
 let satEF dir m s2 reqst =
   inc satEF_calls;
@@ -1165,16 +1131,13 @@ type ('pred,'anno) auok =
 
 (* A[phi1 U phi2] == phi2 \/ (phi1 /\ AXA[phi1 U phi2]) *)
 let satAU dir ((cfg,_,states) as m) s1 s2 reqst print_graph =
+  let strip s = List.map (function s -> (s,[],[])) (get_states s) in
   let ctr = ref 0 in
   inc satAU_calls;
   if s1 = []
   then AUok s2
   else
     (*let ctr = ref 0 in*)
-    let pre_forall =
-      if !Flag_ctl.loop_in_src_code
-      then pre_forall_AW
-      else pre_forall in
     if !pNEW_INFO_OPT
     then
       let rec f y newinfo =
@@ -1183,41 +1146,34 @@ let satAU dir ((cfg,_,states) as m) s1 s2 reqst print_graph =
 	  [] -> AUok y
 	| new_info ->
 	    ctr := !ctr + 1;
-	    (*print_state (Printf.sprintf "iteration %d\n" !ctr) y;
-	    flush stdout;*)
 	    print_graph y ctr;
-	    let pre =
-	      try Some (pre_forall dir m new_info y reqst)
-	      with AW -> None in
-	    match pre with
-	      None -> AUfailed y
-	    | Some pre ->
-		match triples_conj s1 pre with
-		  [] -> AUok y
-		| first ->
-		    (*print_state "s1" s1;
-		    print_state "pre" pre;
-		    print_state "first" first;*)
-		    let res = triples_union first y in
-		    let new_info =
-		      if not !something_dropped
-		      then first
-		      else setdiff res y in
-		  (*Printf.printf
-		     "iter %d res %d new_info %d\n"
-		     !ctr (List.length res) (List.length new_info);
-		     flush stdout;*)
-		    f res new_info in
-      f s2 s2
+	    let pre = pre_forall dir m new_info y reqst in
+	    match triples_conj s1 pre with
+	      [] -> AUok y
+	    | first ->
+		let res = triples_union first y in
+		let new_info =
+		  if not !something_dropped
+		  then first
+		  else setdiff res y in
+		f res new_info in
+	  try
+	    (if !Flag_ctl.loop_in_src_code
+	    then
+	      let _ =
+		satEU_forAW dir m (strip s1) (strip s2) reqst print_graph in
+	      ());
+	    f s2 s2
+	  with AW -> AUfailed s2
     else
       if !Flag_ctl.loop_in_src_code
       then AUfailed s2
       else
 	(*let setfix =
-	  fix (function s1 -> function s2 ->
-	    let s1 = List.map (function (s,th,w) -> (s,th,nub w)) s1 in
-	    let s2 = List.map (function (s,th,w) -> (s,th,nub w)) s2 in
-	    subseteq s1 s2) in for popl *)
+	   fix (function s1 -> function s2 ->
+	   let s1 = List.map (function (s,th,w) -> (s,th,nub w)) s1 in
+	   let s2 = List.map (function (s,th,w) -> (s,th,nub w)) s2 in
+	   subseteq s1 s2) in for popl *)
 	let f y =
 	  inc_step();
 	  ctr := !ctr + 1;
@@ -2462,7 +2418,7 @@ let sat m phi reqopt =
     Hashtbl.clear memo_label;
     let (x,label,preproc,states) = m in
     if (!Flag_ctl.bench > 0) || preprocess m reqopt
-    then    
+    then
       ((* to drop when Yoann initialized this flag *)
       if List.exists (G.extract_is_loop x) states
       then Flag_ctl.loop_in_src_code := true;
