@@ -79,10 +79,7 @@
  */
 
 /*
- * $Log: g_NCR5380.c,v $
- * Revision 1.1  2007/11/01 09:43:07  julia
- * *** empty log message ***
- *
+ * $Log$
  * Revision 1.1.1.1  2007/03/28 16:38:53  pad
  * your commit message
  *
@@ -544,7 +541,7 @@ int generic_NCR5380_biosparam(struct scsi_device *sdev,
  *	@dst: buffer to read into
  *	@len: buffer length
  *
- *	Perform a psuedo DMA mode read from an NCR53C400 or equivalent
+ *	Perform a pseudo DMA mode read from an NCR53C400 or equivalent
  *	controller
  */
  
@@ -628,7 +625,7 @@ static inline int NCR5380_pread(struct Scsi_Host *instance, unsigned char *dst,
  *	@dst: buffer to read into
  *	@len: buffer length
  *
- *	Perform a psuedo DMA mode read from an NCR53C400 or equivalent
+ *	Perform a pseudo DMA mode read from an NCR53C400 or equivalent
  *	controller
  */
 
