@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./c_vs_c.ml"
 open Common
 
 open Ast_c
@@ -85,14 +64,14 @@ let same_s saopt sbopt =
   | Some namea, Some nameb ->
       let sa = Ast_c.str_of_name namea in
       let sb = Ast_c.str_of_name nameb in
-      sa =$= sb
+      sa = sb
   | _ -> false
 
 
 let rec fullType a b =
   let ((qua,iiqa), tya) = a in
   let ((qub,iiqb), tyb) = b in
-  (qua.const =:= qub.const && qua.volatile =:= qub.volatile) >&&>
+  (qua.const = qub.const && qua.volatile = qub.volatile) >&&>
 
     let (qu,iiq) = (qua, iiqa) in
     typeC tya tyb >>= (fun ty ->
@@ -107,12 +86,12 @@ and typeC tya tyb =
 
   match a, b with
   | BaseType a, BaseType b ->
-      a =*= b >&&> return (BaseType a, iix)
+      a = b >&&> return (BaseType a, iix)
   | Pointer a, Pointer b ->
       fullType a b >>= (fun x -> return (Pointer x, iix))
 
   | StructUnionName (sua, sa), StructUnionName (sub, sb) ->
-      (sua =*= sub && sa =$= sb) >&&>
+      (sua = sub && sa = sb) >&&>
         return (StructUnionName (sua, sa), iix)
 
   | TypeName (namea, opta), TypeName (nameb, optb) ->
@@ -121,7 +100,7 @@ and typeC tya tyb =
 
       (* assert compatible opta optb ? *)
       (*option fullType opta optb*)
-      sa =$= sb >&&>
+      sa = sb >&&>
        let opt =
          (match opta, optb with
          | None, None -> None
@@ -139,7 +118,7 @@ and typeC tya tyb =
       let get_option f = function Some x -> Some (f x) | None -> None in
       let ea = get_option Lib_parsing_c.al_expr ea in
       let eb = get_option Lib_parsing_c.al_expr eb in
-      ea =*= eb >&&> fullType a b >>= (fun x -> return (Array (ea, x), iix))
+      ea = eb >&&> fullType a b >>= (fun x -> return (Array (ea, x), iix))
 
   | FunctionType (returna, paramsa), FunctionType (returnb, paramsb) ->
       let (tsa, (ba,iihas3dotsa)) = paramsa in
@@ -148,7 +127,7 @@ and typeC tya tyb =
       let bx = ba in
       let iihas3dotsx = iihas3dotsa in
 
-      (ba =:= bb && List.length tsa =|= List.length tsb) >&&>
+      (ba = bb && List.length tsa = List.length tsb) >&&>
       fullType returna returnb >>= (fun returnx ->
 
       Common.zip tsa tsb +> List.fold_left
@@ -168,7 +147,7 @@ and typeC tya tyb =
 
 
             (* todo?  iso on name or argument ? *)
-            (ba =:= bb && same_s saopt sbopt) >&&>
+            (ba = bb && same_s saopt sbopt) >&&>
             fullType ta tb >>= (fun tx ->
               let paramx = { p_register = (bx, iibx);
                              p_namei = sxopt;
@@ -183,21 +162,21 @@ and typeC tya tyb =
       ))
 
   | Enum (saopt, enuma), Enum (sbopt, enumb) ->
-      (saopt =*= sbopt &&
-      List.length enuma =|= List.length enumb &&
+      (saopt = sbopt &&
+      List.length enuma = List.length enumb &&
       Common.zip enuma enumb +> List.for_all (fun
         (((namesa,eopta), iicommaa), ((namesb,eoptb),iicommab))
           ->
             let sa = str_of_name namesa in
             let sb = str_of_name namesb in
-            sa =$= sb &&
-            (* todo ? eopta and b can have some info so ok to use =*= ?  *)
-            eopta =*= eoptb
+            sa = sb &&
+            (* todo ? eopta and b can have some info so ok to use = ?  *)
+            eopta = eoptb
         )
       ) >&&>
         return (Enum (saopt, enuma), iix)
 
-  | EnumName sa, EnumName sb -> sa =$= sb >&&> return (EnumName sa, iix)
+  | EnumName sa, EnumName sb -> sa = sb >&&> return (EnumName sa, iix)
 
   | ParenType a, ParenType b ->
       (* iso here ? *)
@@ -208,7 +187,7 @@ and typeC tya tyb =
   | TypeOfExpr ea, TypeOfExpr eb ->
       let ea = Lib_parsing_c.al_expr ea in
       let eb = Lib_parsing_c.al_expr eb in
-      ea =*= eb >&&> return (TypeOfExpr ea, iix)
+      ea = eb >&&> return (TypeOfExpr ea, iix)
 
   | TypeOfType a, TypeOfType b ->
       fullType a b >>= (fun x -> return (TypeOfType x, iix))
@@ -219,7 +198,7 @@ and typeC tya tyb =
 
 
   | StructUnion (sua, saopt, sta), StructUnion (sub, sbopt, stb) ->
-      (sua =*= sub && saopt =*= sbopt && List.length sta =|= List.length stb)
+      (sua = sub && saopt = sbopt && List.length sta = List.length stb)
       >&&>
       (function tin ->
 	(* zip is only safe if the above succeeds *)
@@ -234,7 +213,7 @@ and typeC tya tyb =
             | DeclarationField (FieldDeclList (fa, iipta)),
               DeclarationField (FieldDeclList (fb, iiptb)) ->
                 let iipt = iipta in (* TODO ?*)
-                (List.length fa =|= List.length fb) >&&>
+                (List.length fa = List.length fb) >&&>
 		(function tin ->
 		  (* only executable if the length is correct *)
                 (Common.zip fa fb +> List.fold_left
@@ -253,7 +232,7 @@ and typeC tya tyb =
                       | BitField (nameopta, ta, infoa, ea),
                         BitField (nameoptb, tb, infob, eb) ->
                           let infox = infoa in
-                          (same_s nameopta nameoptb && ea =*= eb) >&&>
+                          (same_s nameopta nameoptb && ea = eb) >&&>
                           fullType ta tb >>= (fun tx ->
                             return (((BitField (nameopta,tx,infox,ea)), iix)::xs)
                           )
@@ -343,7 +322,7 @@ let subexpression_of_expression small_exp big_exp =
     (* comparison used in Cocci_vs_c.equal_inh_metavarval *)
     (* have to strip each subexp, because stripping puts some offsets in the
        term rather than setting everything to 0.  No idea why... *)
-    if small_exp =*= Lib_parsing_c.al_inh_expr big_exp
+    if small_exp = Lib_parsing_c.al_inh_expr big_exp
     then res := true
     else k big_exp in
   let bigf = { Visitor_c.default_visitor_c with Visitor_c.kexpr = expr } in
