@@ -1,31 +1,10 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
 
-# 0 "./check_exhaustive_pattern.ml"
-
 (* Just to warn me when there is some news in the types in
  * ast_cocci.ml or even ast_c.ml, so that I can then adjust my code in
  * pattern.ml or transformation.ml.
@@ -47,6 +26,7 @@ let dumb_astcocci_rule_elem = function
  | A.Exp expr -> ()
  | A.TopExp expr -> ()
  | A.Ty ty -> ()
+ | A.TopId id -> ()
  | A.TopInit init -> ()
  | A.FunHeader (bef,allminus, fninfo, ida, _, paramsa, _, _) -> ()
  | A.Decl decl -> ()
@@ -74,6 +54,7 @@ let dumb_astcocci_rule_elem = function
  | A.Include _ -> ()
  | A.Default _ -> ()
  | A.Case _ -> ()
+ | A.AsRe _ -> ()
  | A.DisjRuleElem _ -> failwith "not possible - compiled away in asttoctl"
 
 let dumb_astcocci_decl = function
@@ -81,22 +62,22 @@ let dumb_astcocci_decl = function
  | A.Init (stg, typa, sa, _, expa, _) -> ()
  | A.FunProto _ -> ()
  | A.TyDecl (typa, _)     -> ()
- | A.MacroDecl(fn, _, eas, _, _) -> ()
- | A.MacroDeclInit(fn, _, eas, _, _, _, _) -> ()
+ | A.MacroDecl(stg, fn, _, eas, _, _) -> ()
+ | A.MacroDeclInit(stg, fn, _, eas, _, _, _, _) -> ()
  | A.MetaDecl _ -> ()
  | A.MetaField _ -> ()
  | A.MetaFieldList _ -> ()
  | A.AsDecl _ -> ()
  | A.Typedef(d,ty1,ty2,pv) -> ()
  | A.DisjDecl xs -> ()
- | A.OptDecl _ | A.UniqueDecl _ -> ()
+ | A.OptDecl _ -> ()
 
 let dumb_astcocci_initialiser = function (* seems same as the above *)
     A.Init(stg,ty,id,eq,ini,sem) -> ()
   | A.UnInit(stg,ty,id,sem) -> ()
   | A.FunProto _ -> ()
-  | A.MacroDecl(fn, _, eas, _, _) -> ()
-  | A.MacroDeclInit(fn, _, eas, _, _, _, _) -> ()
+  | A.MacroDecl(_, fn, _, eas, _, _) -> ()
+  | A.MacroDeclInit(_, fn, _, eas, _, _, _, _) -> ()
   | A.TyDecl(ty,sem) -> ()
   | A.Typedef(d,ty1,ty2,pv) -> ()
   | A.DisjDecl(decls) -> ()
@@ -105,11 +86,11 @@ let dumb_astcocci_initialiser = function (* seems same as the above *)
   | A.MetaFieldList(name,_,_,_) -> ()
   | A.AsDecl(_,_) -> ()
   | A.OptDecl(decl) -> ()
-  | A.UniqueDecl(decl) -> ()
 
 let dumb_astcocci_expr = function
  | A.MetaExpr (ida,_,_, opttypa, _, _) -> ()
  | A.AsExpr (_,_) -> ()
+ | A.AsSExpr (_,_) -> ()
  | A.Edots (_,_) -> ()
  | A.MetaErr _ -> ()
  | A.Ident ida -> ()
@@ -140,10 +121,8 @@ let dumb_astcocci_expr = function
  | A.NestExpr _ -> ()
  | A.MetaExprList _ -> ()
  | A.EComma _ -> ()
- | A.Ecircles _ -> ()
- | A.Estars _ -> ()
  | A.DisjExpr eas -> ()
- | A.UniqueExp _ -> ()
+ | A.ConjExpr eas -> ()
  | A.OptExp _ -> ()
 
 let dumb_astcocci_fulltype = function
@@ -151,7 +130,6 @@ let dumb_astcocci_fulltype = function
   | A.AsType(_,_) -> ()
   | A.DisjType(types) -> ()
   | A.OptType(ty) -> ()
-  | A.UniqueType(ty) -> ()
 
 let dumb_astcocci_type = function
  | A.MetaType(ida,_,_) -> ()
