@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./cocci_vs_c.mli"
 (*****************************************************************************)
 (* Cocci vs C *)
 (*****************************************************************************)
@@ -199,6 +178,10 @@ module type PARAM =
       (Ast_cocci.fullType, Ast_c.fullType) matcher ->
       (Ast_cocci.fullType, Control_flow_c.node) matcher
 
+    val cocciId :
+      (Ast_cocci.ident, Ast_c.name) matcher ->
+      (Ast_cocci.ident, Control_flow_c.node) matcher
+
     val cocciInit :
       (Ast_cocci.initialiser, Ast_c.initialiser) matcher ->
       (Ast_cocci.initialiser, Control_flow_c.node) matcher
@@ -214,8 +197,10 @@ module type PARAM =
 	  (unit -> Common.filename * string * Ast_c.posl * Ast_c.posl) ->
       (unit -> tin -> 'x tout) -> (tin -> 'x tout)
 
-    val check_idconstraint :
-      ('a -> 'b -> bool) -> 'a -> 'b ->
+    val check_constraints :
+      ('a -> 'b -> (Ast_cocci.meta_name -> Ast_c.metavar_binding_kind) ->
+	bool) ->
+	'a -> 'b ->
 	(unit -> tin -> 'x tout) -> (tin -> 'x tout)
 
     val check_constraints_ne :
@@ -247,8 +232,6 @@ module COCCI_VS_C :
 
       val rule_elem_node : (Ast_cocci.rule_elem, Control_flow_c.node) matcher
 
-      val expression :     (Ast_cocci.expression, Ast_c.expression)   matcher
-
       (* there are far more functions in this functor but they do not have
        * to be exported
        *)
