@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./ctlcocci_integration.ml"
 open Common
 
 open Ograph_extended
@@ -147,11 +126,11 @@ let labels_for_ctl (dropped_isos : string list)
 	  (fun prev (nodei,node) ->
 	    match F.unwrap node with
 	      F.SeqStart (_, bracelevel, _) ->
-		let make_var x = ("",i_to_s x) in
+		let make_var x = ("",string_of_int x) in
 		let vl = Lib_engine.ParenVal (make_var bracelevel) in
 		(nodei, (p,[(s --> vl)])) :: prev
 	    | F.SeqEnd (bracelevel, _) ->
-		let make_var x = ("",i_to_s x) in
+		let make_var x = ("",string_of_int x) in
 		let vl = Lib_engine.ParenVal (make_var bracelevel) in
 		(nodei, (p,[(s --> vl)])) :: prev
 	    | _ -> prev)
@@ -338,20 +317,20 @@ let fix_flow_ctl2 (flow : F.cflow) : F.cflow =
 
   (* for the #define CFG who have no Exit but have at least a EndNode *)
   (try
-      let endi  = F.find_node (fun x -> x =*= F.EndNode) !g in
+      let endi  = F.find_node (fun x -> x = F.EndNode) !g in
       !g#add_arc ((endi, endi), F.Direct);
     with Not_found -> ()
   );
 
   (* for the regular functions *)
   (try
-    let exitnodei  = F.find_node (fun x -> x =*= F.Exit) !g in
-    let errornodei = F.find_node (fun x -> x =*= F.ErrorExit) !g in
+    let exitnodei  = F.find_node (fun x -> x = F.Exit) !g in
+    let errornodei = F.find_node (fun x -> x = F.ErrorExit) !g in
 
     !g#add_arc ((exitnodei, exitnodei), F.Direct);
 
-    if null ((!g#successors   errornodei)#tolist) &&
-       null ((!g#predecessors errornodei)#tolist)
+    if ((!g#successors   errornodei)#tolist) = [] &&
+       ((!g#predecessors errornodei)#tolist) = []
     then !g#del_node errornodei
     else !g#add_arc ((errornodei, errornodei), F.Direct);
    with Not_found -> ()
@@ -427,12 +406,12 @@ let prefix l1 l2 =
 
 let compatible_labels l1 l2 =
   match (l1,l2) with
-    (Lib_engine.Absolute(l1),Lib_engine.Absolute(l2)) -> l1 =*= l2
+    (Lib_engine.Absolute(l1),Lib_engine.Absolute(l2)) -> l1 = l2
   | (Lib_engine.Absolute(l1),Lib_engine.Prefix(l2))   -> prefix l1 l2
   | (Lib_engine.Prefix(l1),Lib_engine.Absolute(l2))   -> prefix l2 l1
   | (Lib_engine.Prefix(l1),Lib_engine.Prefix(l2))     ->
       not (l1 = []) && not (l2 = []) &&
-      List.hd l1 =*= List.hd l2 (* labels are never empty *)
+      List.hd l1 = List.hd l2 (* labels are never empty *)
 
 let merge_labels l1 l2 =
   match (l1,l2) with
@@ -450,7 +429,7 @@ module ENV =
   struct
     type value = Lib_engine.metavar_binding_kind2
     type mvar = Ast_cocci.meta_name
-    let eq_mvar x x' = x =*= x'
+    let eq_mvar x x' = x = x'
     let eq_val v v' =
       (* v = v' *)
       match (v,v') with
@@ -463,7 +442,7 @@ module ENV =
           C_vs_c.eq_type a b
       |	(Lib_engine.LabelVal(l1),Lib_engine.LabelVal(l2)) ->
 	  compatible_labels l1 l2
-      |	_ -> v =*= v'
+      |	_ -> v = v'
     let merge_val v v' = (* values guaranteed to be compatible *)
       (* v *)
       match (v,v') with
@@ -494,7 +473,7 @@ module CFG =
     let successors   cfg n = List.map fst ((cfg#successors n)#tolist)
     let extract_is_loop cfg n =
       Control_flow_c.extract_is_loop (cfg#nodes#find n)
-    let print_node i = Format.print_string (i_to_s i)
+    let print_node i = Format.print_string (string_of_int i)
     let size cfg = cfg#nodes#length
 
     (* In ctl_engine, we use 'node' for the node but in the Ograph_extended
@@ -563,7 +542,7 @@ let (satbis_to_trans_info:
 let rec coalesce_positions = function
     [] -> []
   | (x,Ast_c.MetaPosValList l)::rest ->
-      let (same,others) = List.partition (function (x1,_) -> x =*= x1) rest in
+      let (same,others) = List.partition (function (x1,_) -> x = x1) rest in
       let ls =
 	List.fold_left
 	  (function prev ->
@@ -580,12 +559,12 @@ let strip env =
     (function (v,vl) ->
       let vl =
 	match vl with
-	  Ast_c.MetaExprVal (a,c) ->
-	    Ast_c.MetaExprVal(Lib_parsing_c.al_inh_expr a,c)
+	  Ast_c.MetaExprVal (a,c,ty) ->
+	    Ast_c.MetaExprVal(Lib_parsing_c.al_inh_expr a,c,ty)
 	| Ast_c.MetaExprListVal a ->
 	    Ast_c.MetaExprListVal(Lib_parsing_c.al_inh_arguments a)
-	| Ast_c.MetaStmtVal a ->
-	    Ast_c.MetaStmtVal(Lib_parsing_c.al_inh_statement a)
+	| Ast_c.MetaStmtVal(a,ty) ->
+	    Ast_c.MetaStmtVal(Lib_parsing_c.al_inh_statement a,ty)
 	| Ast_c.MetaInitVal a ->
 	    Ast_c.MetaInitVal(Lib_parsing_c.al_inh_init a)
 	| Ast_c.MetaInitListVal a ->
