@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./pattern_c.ml"
 open Common
 
 module Flag_engine = Flag_matcher
@@ -123,7 +102,7 @@ module XMATCH = struct
     if res2 = [] (*try to avoid a trivial @*)
     then res1
     else
-      res1 ++
+      res1 @
 	(res2 +> List.filter (fun (x, binding) ->
           not
             (res1 +> List.exists (fun (_,already) ->
@@ -142,8 +121,7 @@ module XMATCH = struct
 *)
     (* opti? use set instead of list *)
     let l1 = m1 tin in
-    let l2 = m2 tin in
-    if l2 = [] then l1 else l1 ++ l2 (*a small benefit; avoid a trivial @*)
+    let l2 = m2 tin in l1 @ l2
 
 
   let return res = fun tin ->
@@ -236,6 +214,24 @@ module XMATCH = struct
       (a, node), binding
     )
 
+  let cocciId = fun expf expa node -> fun tin ->
+    (* This is not correct.  It should not match type names, ie name
+       defined by a typedef, and it should match struct and enum names,
+       which are currently not names.  TODO *)
+    let globals = ref [] in
+    let bigf = {
+      Visitor_c.default_visitor_c with
+        Visitor_c.kname = (fun (k, bigf) expb ->
+	  match expf expa expb tin with
+	  | [] -> (* failed *) k expb
+	  | xs -> globals := xs @ !globals)
+    }
+    in
+    Visitor_c.vk_node bigf node;
+    !globals +> List.map (fun ((a, _exp), binding) ->
+      (a, node), binding
+    )
+
   let cocciInit = fun expf expa node -> fun tin ->
 
     let globals = ref [] in
@@ -261,10 +257,10 @@ module XMATCH = struct
     match mck with
     | Ast_cocci.PLUS c -> Ast_cocci.PLUS c
     | Ast_cocci.CONTEXT (pos, xs) ->
-        assert (pos =*= Ast_cocci.NoPos || pos =*= Ast_cocci.DontCarePos);
+        assert (pos = Ast_cocci.NoPos || pos = Ast_cocci.DontCarePos);
         Ast_cocci.CONTEXT (posmck, xs)
     | Ast_cocci.MINUS (pos, inst, adj, xs) ->
-        assert (pos =*= Ast_cocci.NoPos || pos =*= Ast_cocci.DontCarePos);
+        assert (pos = Ast_cocci.NoPos || pos = Ast_cocci.DontCarePos);
         Ast_cocci.MINUS (posmck, inst, adj, xs)
 
 
@@ -318,13 +314,6 @@ module XMATCH = struct
   (* ------------------------------------------------------------------------*)
   (* Constraints on metavariable values *)
   (* ------------------------------------------------------------------------*)
-  let check_idconstraint matcher c id = fun f tin ->
-    if matcher c id then
-      (* success *)
-      f () tin
-    else
-      (* failure *)
-      fail tin
 
   let check_constraints_ne matcher constraints exp = fun f tin ->
     let rec loop = function
@@ -335,6 +324,11 @@ module XMATCH = struct
 	  | _ (* success *) -> fail tin in
     loop constraints
 
+  let check_constraints matcher constraints term = fun f tin ->
+    if matcher constraints term (function id -> tin.binding0 +> List.assoc id)
+    then f () tin (* success *)
+    else fail tin (* failure *)
+
   let check_pos_constraints constraints pvalu f tin =
     check_constraints_ne
       (fun c exp tin ->
@@ -382,22 +376,8 @@ module XMATCH = struct
 	  let success valu' =
 	    Some (tin.binding +> Common.insert_assoc (k, valu')) in
           (match valu with
-            Ast_c.MetaIdVal (a,c)    ->
-	      (* c is a negated constraint *)
-	      let rec loop = function
-		  [] -> success(Ast_c.MetaIdVal(a,[]))
-		| c::cs ->
-		    let tmp =
-		      Common.optionise
-			(fun () -> tin.binding0 +> List.assoc c) in
-		    (match tmp with
-		      Some (Ast_c.MetaIdVal(v,_)) ->
-			if a =$= v
-			then None (* failure *)
-			else success(Ast_c.MetaIdVal(a,[]))
-		    | Some _ -> failwith "Not possible"
-		    | None -> success(Ast_c.MetaIdVal(a,[]))) in
-	      loop c
+            Ast_c.MetaIdVal (a)    ->
+	      success(Ast_c.MetaIdVal(a))
           | Ast_c.MetaAssignOpVal op      ->
 	      success(Ast_c.MetaAssignOpVal op)
           | Ast_c.MetaBinaryOpVal op      ->
@@ -406,7 +386,7 @@ module XMATCH = struct
 	      success(Ast_c.MetaFuncVal a)
           | Ast_c.MetaLocalFuncVal a ->
 	      success(Ast_c.MetaLocalFuncVal a) (*more?*)
-          | Ast_c.MetaExprVal (a,c) ->
+          | Ast_c.MetaExprVal (a,c,ty) ->
 	      (* c in the value is only to prepare for the future in which
 		 we figure out how to have subterm constraints on unbound
 		 variables.  Now an environment will only contain expression
@@ -418,13 +398,13 @@ module XMATCH = struct
 		else Lib_parsing_c.semi_al_expr a in
 	      let inh_stripped = Lib_parsing_c.al_inh_expr a in
 	      let rec loop = function
-		  [] -> success(Ast_c.MetaExprVal(stripped,[]))
+		  [] -> success(Ast_c.MetaExprVal(stripped,[],ty))
 		| c::cs ->
 		    let tmp =
 		      Common.optionise
 			(fun () -> tin.binding0 +> List.assoc c) in
 		    (match tmp with
-		      Some (Ast_c.MetaExprVal(v,_)) ->
+		      Some (Ast_c.MetaExprVal(v,_,_)) ->
 			if C_vs_c.subexpression_of_expression inh_stripped v
 			then loop cs (* forget satisfied constraints *)
 			else None (* failure *)
@@ -439,7 +419,7 @@ module XMATCH = struct
 		   (if strip
 		   then Lib_parsing_c.al_arguments a
 		   else Lib_parsing_c.semi_al_arguments a))
-		
+
           | Ast_c.MetaDeclVal a ->
 	      success
 		(Ast_c.MetaDeclVal
@@ -458,35 +438,41 @@ module XMATCH = struct
 		   (if strip
 		   then Lib_parsing_c.al_fields a
 		   else Lib_parsing_c.semi_al_fields a))
-          | Ast_c.MetaStmtVal a ->
-	      success
-		(Ast_c.MetaStmtVal
-		   (if strip
-		   then Lib_parsing_c.al_statement a
-		   else Lib_parsing_c.semi_al_statement a))
+          | Ast_c.MetaStmtVal(a,ty) ->
+	      let stripped =
+		if strip
+		then Lib_parsing_c.al_statement a
+		else Lib_parsing_c.semi_al_statement a in
+	      success(Ast_c.MetaStmtVal(stripped,ty))
+          | Ast_c.MetaStmtListVal(a,ty) ->
+	      let stripped =
+		if strip
+		then Lib_parsing_c.al_statement_seq_list a
+		else Lib_parsing_c.semi_al_statement_seq_list a in
+	      success(Ast_c.MetaStmtListVal(stripped,ty))
           | Ast_c.MetaTypeVal a ->
 	      success
 		(Ast_c.MetaTypeVal
 		   (if strip
 		   then Lib_parsing_c.al_type a
 		   else Lib_parsing_c.semi_al_type a))
-		
+
           | Ast_c.MetaInitVal a ->
 	      success
 		(Ast_c.MetaInitVal
 		   (if strip
 		   then Lib_parsing_c.al_init a
 		   else Lib_parsing_c.semi_al_init a))
-		
+
           | Ast_c.MetaInitListVal a ->
 	      success
 		(Ast_c.MetaInitListVal
 		   (if strip
 		   then Lib_parsing_c.al_inits a
 		   else Lib_parsing_c.semi_al_inits a))
-		
+
           | Ast_c.MetaListlenVal a -> success(Ast_c.MetaListlenVal a)
-		
+
           | Ast_c.MetaParamVal a ->
 	      success
 		(Ast_c.MetaParamVal
@@ -499,7 +485,7 @@ module XMATCH = struct
 		   (if strip
 		   then Lib_parsing_c.al_params a
 		   else Lib_parsing_c.semi_al_params a))
-		
+
           | Ast_c.MetaFragListVal a ->
 	      success
 		(Ast_c.MetaFragListVal
@@ -512,10 +498,11 @@ module XMATCH = struct
 		   (if strip
 		   then Lib_parsing_c.al_string_format a
 		   else Lib_parsing_c.semi_al_string_format a))
-		
+
           | Ast_c.MetaPosVal (pos1,pos2) ->
 	      success(Ast_c.MetaPosVal (pos1,pos2))
-          | Ast_c.MetaPosValList l -> success (Ast_c.MetaPosValList l))
+          | Ast_c.MetaPosValList l -> success (Ast_c.MetaPosValList l)
+	  | Ast_c.MetaNoVal -> None)
 
   let pos_variables tin ia get_pvalu finish =
     match Ast_cocci.get_pos_var ia with
@@ -601,7 +588,7 @@ module XMATCH = struct
       pos_variables tin ia
 	(function _ -> [Lib_parsing_c.lin_col_by_pos [ib]])
 	finish
-      
+
   let tokenf_mck mck ib = fun tin ->
     let pos = Ast_c.info_to_fixpos ib in
     let posmck = Ast_cocci.FixPos (pos, pos) in
