@@ -36,7 +36,7 @@ let unparse_kbuild_info xs filename =
     xs +> List.iter (function Directory (s, ys) ->
       pr s;
       ys +> List.iter (function Group zs ->
-        pr ("  " ^ (join " " zs));
+        pr ("  " ^ (String.concat " " zs));
       );
       pr "";
     )
@@ -124,16 +124,16 @@ let parse_makefile file =
     | s when s =~ "obj-\\$(CONFIG_.*)[ \t]*[\\+:]=\\(.*\\)" ->
         let s = matched1 s in
         let objs = Common.split "[ \t]+" s in
-        assert(List.for_all (fun s -> thd3 (Common.dbe_of_filename s) =$= "o")
+        assert(List.for_all (fun s -> thd3 (Common.dbe_of_filename s) = "o")
                   objs);
 
-        pr2 ("OBJS: " ^ (join "|" objs))
+        pr2 ("OBJS: " ^ (String.concat "|" objs))
 
     | s when s =~ "[a-zA-Z0-9_]+-objs[ \t]*[\\+:]=\\(.*\\)" ->
         let s = matched1 s in
         let objs = Common.split "[ \t]+" s in
 
-        pr2 ("OBJSMODULE: " ^ (join "|" objs))
+        pr2 ("OBJSMODULE: " ^ (String.concat "|" objs))
 
     | s  ->
         pr2_no_nl ("OTHER: " ^ s)
@@ -177,7 +177,7 @@ let check_up_to_date a b  =
       optionise (fun () -> List.assoc dir das),
       optionise (fun () -> List.assoc dir dbs)
     with
-    | None, None -> raise Impossible
+    | None, None -> raise (Impossible 57)
     | None, Some gbs -> pr2 ("new directory appeared:" ^ dir)
     | Some gas, None -> pr2 ("old directory disappeared:" ^ dir)
     | Some gas, Some gbs ->
@@ -186,7 +186,7 @@ let check_up_to_date a b  =
         let all_files = afiles $+$ bfiles in
         all_files +> List.iter (fun file ->
           match List.mem file afiles, List.mem file bfiles with
-          | false, false -> raise Impossible
+          | false, false -> raise (Impossible 58)
           | false, true -> pr2 ("new file appeared:" ^ file ^ " in " ^ dir)
           | true, false -> pr2 ("old file disappeared:" ^ file  ^ " in " ^ dir)
           | true, true -> ()
@@ -223,7 +223,3 @@ let files_in_dirs dirs kbuild_info =
         []
     )
   ) +> List.concat
-
-
-
-
