@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./main.ml"
 open Common
 module FC = Flag_cocci
 
@@ -256,7 +235,7 @@ let run_profile p =
 (*****************************************************************************)
 
 let usage_msg =
-  "Usage: " ^ basename Sys.argv.(0) ^
+  "Usage: " ^ Filename.basename Sys.argv.(0) ^
     " --sp-file <SP> <infile> [-o <outfile>] [--iso-file <iso>] [options]" ^
     "\n" ^ "Options are:"
 
@@ -289,7 +268,7 @@ let short_options = [
   "--reverse", Arg.Set Flag_parsing_cocci.interpret_inverted,
   "  invert the semantic patch before applying it";
 
-  "-U", Arg.Int (fun n -> Flag_parsing_c.diff_lines := Some (i_to_s n)),
+  "-U", Arg.Int (fun n -> Flag_parsing_c.diff_lines := Some (string_of_int n)),
   "  set number of diff context lines";
   "--partial-match",        Arg.Set Flag_ctl.partial_match,
   "    report partial matches of the SP on the C file";
@@ -334,6 +313,8 @@ let short_options = [
 
   "--no-scanner", Arg.Unit (function _ -> Flag.scanner := Flag.NoScanner),
   "    no indexing";
+  "--use-gitgrep", Arg.Unit (function _ -> Flag.scanner := Flag.GitGrep),
+  "    works with -dir, works on git tree subdirectories";
   "--use-glimpse", Arg.Unit (function _ -> Flag.scanner := Flag.Glimpse),
   "    works with -dir, use info generated by glimpseindex";
   "--use-idutils",
@@ -357,6 +338,8 @@ let short_options = [
     Prepare_ocamlcocci.load_file f'),
   "    <file> Loads the file containing the OCaml code in charge of parse errors reporting";
 
+  "--print-options-only", Arg.Unit (fun () -> ()),
+  "   print selected options and exit";
 
   "--version",   Arg.Unit (fun () ->
     let withpython = if Pycocci.python_support then "with" else "without" in
@@ -516,8 +499,9 @@ let other_options = [
     "   gather timing information about the main coccinelle functions";
     "--bench", Arg.Int (function x -> Flag_ctl.bench := x),
     "   <level> for profiling the CTL engine";
-    "--timeout", Arg.Int (fun x -> FC.timeout := Some x),
-    "   <sec> timeout in seconds";
+    "--timeout",
+    Arg.Int (fun x -> FC.timeout := (if x = 0 then None else Some x)),
+    "   <sec> timeout in seconds, 0 for no timeout";
     "--steps", Arg.Int (fun x -> Flag_ctl.steps := Some x),
     "   max number of model checking steps per code unit";
     "--iso-limit", Arg.Int (fun x -> Flag_parsing_cocci.iso_limit := Some x),
@@ -588,9 +572,11 @@ let other_options = [
     "--noif0-passing",      Arg.Clear Flag_parsing_c.if0_passing, " ";
     "--itu",      Arg.Set Flag_parsing_c.exts_ITU,
     "   Experimental extensions for handling #ifdef developed at ITU.dk";
-    "--defined", Arg.String (Flag_parsing_c.add Flag_parsing_c.defined), " ";
+    "--defined", Arg.String (Flag_parsing_c.add Flag_parsing_c.defined),
+    "   <symbol> treat cpp symbol as defined in #ifdef";
     "--undefined", Arg.String
-        (Flag_parsing_c.add Flag_parsing_c.undefined), " ";
+        (Flag_parsing_c.add Flag_parsing_c.undefined),
+    "   <symbol> treat cpp symbol as undefined in #ifdef";
     "--noadd-typedef-root", Arg.Clear Flag_parsing_c.add_typedef_root, " ";
     (* could use Flag_parsing_c.options_algo instead *)
 
@@ -620,6 +606,8 @@ let other_options = [
     "  spacing of + code follows the conventions of Linux";
     "--smpl-spacing", Arg.Unit Flag_parsing_c.set_smpl_spacing,
     "  spacing of + code follows the semantic patch";
+    "--indent", Arg.Set_int Flag_parsing_c.indent,
+    "  default indent, in spaces (no tabs)";
     "-D", Arg.String Flag.set_defined_virtual_rules,
     "  indicate that a virtual rule should be considered to be matched";
     "--c++", Arg.Set Flag.c_plus_plus,
@@ -713,7 +701,7 @@ let other_options = [
   ),
 
     (* -token_c, -parse_c, etc  *)
-  ((Common.options_of_actions action (Test_parsing_c.actions())) ++
+  ((Common.options_of_actions action (Test_parsing_c.actions())) @
     [
     (let s = "--parse-cocci"  in s, Arg.Unit (fun () -> action := s),
     "   <file>");
@@ -726,7 +714,15 @@ let other_options = [
 
 
 let all_options =
-  short_options ++ List.concat (List.map Common.thd3 other_options)
+  short_options @ List.concat (List.map Common.thd3 other_options)
+
+let all_string_option_names =
+  List.fold_left
+    (function prev ->
+      function
+	  (_,Arg.Unit _,_) -> prev
+	| (nm,_,_) -> nm :: prev)
+    [] all_options
 
 (* I don't want the -help and --help that are appended by Arg.align *)
 let arg_align2 xs =
@@ -768,7 +764,8 @@ let arg_parse2 l f msg argv =
 	begin
 	  let xs = Common.lines emsg in
 	    (* take only head, it's where the error msg is *)
-	    pr2 (List.hd xs);
+	    (* was pr2, but that doesn't always get generated *)
+	    Printf.eprintf "%s\n%!" (List.hd xs);
 	    !short_usage_func();
 	    raise (Common.UnixExit (2))
 	end
@@ -808,7 +805,7 @@ let adjust_stdin cfiles k =
 	try
           let (dir, base, ext) = Common.dbe_of_filename cfile in
           let varfile = Common.filename_of_dbe (dir, base, "var") in
-          if ext =$= "c" && Common.lfile_exists varfile
+          if ext = "c" && Common.lfile_exists varfile
           then Some varfile
           else None
 	with Invalid_argument("Filename.chop_extension") -> None in
@@ -834,7 +831,7 @@ let glimpse_filter2 (_,query,_,_) dir =
 		   if filelist <> [] then
 		     begin
 		       let firstfile = List.hd filelist in
-		       if Filename.is_relative firstfile || Filename.is_implicit firstfile then			 
+		       if Filename.is_relative firstfile || Filename.is_implicit firstfile then
 			 List.map (fun file -> dir ^ Filename.dir_sep ^ file) filelist
 		       else
 			 filelist
@@ -847,16 +844,26 @@ let glimpse_filter2 (_,query,_,_) dir =
 let glimpse_filter a b  =
   Common.profile_code "glimpse_filter" (fun () -> glimpse_filter2 a b)
 
-let coccigrep_filter2 (_,_,query,_) dir =
+let coccigrep_filter (_,_,query,_) dir =
   match query with
     None -> pr2 "no inferred keywords"; None
-  | Some query ->
-      Some
-	(Test_parsing_c.get_files dir +>
-	 List.filter (Cocci_grep.interpret query))
+  | Some (q1,q2,_) ->
+      let res =
+	Test_parsing_c.get_files dir +>
+	List.filter (Cocci_grep.interpret (q1,q2)) in
+      Printf.eprintf "%d files match\n" (List.length res);
+      Some res
 
-let coccigrep_filter a b  =
-  Common.profile_code "coccigrep_filter" (fun () -> coccigrep_filter2 a b)
+let gitgrep_filter ((_,_,query,_) as x) dir =
+  match query with
+    None -> pr2 "no inferred keywords"; None
+  | Some (_,_,query) ->
+      let suffixes = if !Flag.include_headers then "'*.[ch]'" else "'*.c'" in
+      match Git_grep.interpret dir query suffixes with
+	Some res ->
+	  Printf.eprintf "%d files match\n" (List.length res);
+	  Some res
+      |	None -> coccigrep_filter x dir
 
 let idutils_filter (_,_,_,query) dir =
   match query with
@@ -890,10 +897,10 @@ let rec main_action xs =
        *)
 	  dir := (Common.is_directory x);
 
-          if !cocci_file =$= ""
+          if !cocci_file = ""
           then failwith "I need a cocci file,  use --sp-file <file>";
 
-	  if !dir && !Flag.patch =*= None
+	  if !dir && !Flag.patch = None
 	  then
 	    (match xs with
 	    | [] -> Flag.patch := Some (Cocci.normalize_path x)
@@ -912,46 +919,35 @@ let rec main_action xs =
 	      match !dir, !kbuild_info, !Flag.scanner, xs with
             (* glimpse *)
               | false, _, _, _ -> [x::xs]
-              | true, s, (Flag.Glimpse|Flag.IdUtils|Flag.CocciGrep), _
+	      |	true, "",
+		  (Flag.Glimpse|Flag.IdUtils|Flag.CocciGrep|Flag.GitGrep),
+		  [] ->
+		    let interpreter =
+		      match !Flag.scanner with
+			Flag.Glimpse -> glimpse_filter
+		      | Flag.IdUtils -> idutils_filter
+		      | Flag.CocciGrep -> coccigrep_filter
+		      | Flag.GitGrep -> gitgrep_filter
+		      |	_ -> failwith "impossible" in
+		    let files =
+		      match interpreter constants x with
+			None -> Test_parsing_c.get_files x
+		      | Some files -> files in
+                    files +> List.map (fun x -> [x])
+              | true, s,
+		  (Flag.Glimpse|Flag.IdUtils|Flag.CocciGrep|Flag.GitGrep), _
 		when s <> "" ->
                   failwith "--use-xxx filters do not work with --kbuild"
-              | true, "", Flag.Glimpse, [] ->
-                  (*if not (null xs)
-                  then failwith "--use-glimpse can accept only one dir"*)
-
-                  let files =
-		    match glimpse_filter constants x with
-		      None -> Test_parsing_c.get_files x
-		    | Some files -> files in
-                  files +> List.map (fun x -> [x])
-              | true, "", Flag.IdUtils, [] ->
-                  (*if not (null xs)
-                  then failwith "--id-utils can accept only one dir"*)
-
-                  let files =
-		    match idutils_filter constants x with
-		      None -> Test_parsing_c.get_files x
-		    | Some files -> files in
-                  files +> List.map (fun x -> [x])
-              | true, "", Flag.CocciGrep, [] ->
-                  (*if not (null xs)
-                  then failwith "--id-utils can accept only one dir"*)
-
-                  let files =
-		    match coccigrep_filter constants x with
-		      None -> Test_parsing_c.get_files x
-		    | Some files -> files in
-                  files +> List.map (fun x -> [x])
                   (* normal *)
 	      | true, "", _, _ ->
 		  Test_parsing_c.get_files
-		    (join " " (x::xs)) +> List.map (fun x -> [x])
+		    (String.concat " " (x::xs)) +> List.map (fun x -> [x])
 
             (* kbuild *)
 	      | true, kbuild_info_file,_,_ ->
 		  let dirs =
-                    Common.cmd_to_list ("find "^(join " " (x::xs))^" -type d")
-                  in
+                    Common.cmd_to_list
+		      ("find "^(String.concat " " (x::xs))^" -type d") in
 		  let info = Kbuild.parse_kbuild_info kbuild_info_file in
 		  let groups = Kbuild.files_in_dirs dirs info in
 
@@ -978,7 +974,7 @@ let rec main_action xs =
 		  let rec loop ct = function
 		      [] -> []
 		    | x::xs ->
-			if (ct mod max) =|= index
+			if (ct mod max) = index
 			then x::(loop (ct+1) xs)
 			else loop (ct+1) xs in
 		  loop 0 infiles
@@ -1014,22 +1010,29 @@ let rec main_action xs =
 	      Filename.chop_extension (Filename.basename !cocci_file) in
 	    (if Sys.file_exists prefix
 	    then failwith (Printf.sprintf "Directory %s used for temporary files already exists and should be removed." prefix));
+	    let clean _ =
+	      let files = Array.to_list(Sys.readdir prefix) in
+	      let (stdouts,stderrs) =
+		List.partition
+		  (function x -> Str.string_match (Str.regexp "stdout") x 0)
+		  files in
+	      List.iter (function x -> Common.file_to_stdout (prefix^"/"^x))
+		stdouts;
+	      List.iter (function x -> Common.file_to_stderr (prefix^"/"^x))
+		stderrs;
+	      let _ = Sys.command (Printf.sprintf "rm -rf %s" prefix) in
+	      () in
 	    let res =
-	      Parmap.parfold
-		~init:(fun id -> Parmap.redirect ~path:prefix ~id)
-		~ncores
-		~chunksize
-		(fun x y -> op y x) (Parmap.L l) z merge in
-	    let files = Array.to_list(Sys.readdir prefix) in
-	    let (stdouts,stderrs) =
-	      List.partition
-		(function x -> Str.string_match (Str.regexp "stdout") x 0)
-		files in
-	    List.iter (function x -> Common.file_to_stdout (prefix^"/"^x))
-	      stdouts;
-	    List.iter (function x -> Common.file_to_stderr (prefix^"/"^x))
-	      stderrs;
-	    let _ = Sys.command (Printf.sprintf "rm -rf %s" prefix) in
+	      try
+		Parmap.parfold
+		  ~init:(fun id -> Parmap.redirect ~path:prefix ~id)
+		  ~ncores
+		  ~chunksize
+		  (fun x y -> op y x) (Parmap.L l) z merge
+	      with e ->
+		(Printf.eprintf "exception on %s: %s\n" prefix (Dumper.dump e);
+		 clean(); raise e) in
+	    clean();
 	    res
 	  in
 	  let (actual_fold, run_in_parallel) =
@@ -1051,12 +1054,13 @@ let rec main_action xs =
 		    Cocci.worth_trying cfiles constants
 		      then
 		    begin
-		  pr2 ("HANDLING: " ^ (join " " cfiles));
+		  pr2 ("HANDLING: " ^ (String.concat " " cfiles));
 		  (*pr2 (List.hd(Common.cmd_to_list "free -m | grep Mem"));*)
 		  flush stderr;
 
 		  Common.timeout_function_opt !FC.timeout (fun () ->
-  	            Common.report_if_take_time 10 (join " " cfiles) (fun () ->
+		    Common.report_if_take_time 10 (String.concat " " cfiles)
+		      (fun () ->
                       try
 			let optfile =
 			  if !output_file <> "" && !compat_mode then
@@ -1155,9 +1159,9 @@ and generate_outfiles outfiles x (* front file *) xs (* other files *) =
 		 * anymore in /tmp.
               *)
               (*
-	         if !output_file =$= ""
+	         if !output_file = ""
 	         then begin
-                 let tmpfile = "/tmp/"^Common.basename infile in
+                 let tmpfile = "/tmp/"^Filename.basename infile in
                  pr2 (spf "One file modified. Result is here: %s" tmpfile);
                  Common.command2 ("cp "^outfile^" "^tmpfile);
 	         end
@@ -1165,9 +1169,9 @@ and generate_outfiles outfiles x (* front file *) xs (* other files *) =
 	    ));
   if !output_file <> "" && not !compat_mode then
     (match outfiles with
-    | [infile, Some outfile] when infile =$= x && null xs ->
+    | [infile, Some outfile] when infile = x && xs=[] ->
         Common.command2 ("cp " ^outfile^ " " ^ !output_file)
-    | [infile, None] when infile =$= x && null xs ->
+    | [infile, None] when infile = x && xs=[] ->
         Common.command2 ("cp " ^infile^ " " ^ !output_file)
     | [] ->
         failwith
@@ -1200,16 +1204,24 @@ let main () =
     let arglist = Array.to_list Sys.argv in
     let arglist = Command_line.command_line arglist in
     let arglist = List.map fix_chars arglist in
+    let arglist = Read_options.read_options all_string_option_names arglist in
     let arglist = fix_idutils arglist in
 
+    (if List.mem "--print-options-only" arglist
+    then
+      begin
+	Printf.eprintf "options: %s\n" (String.concat " " arglist);
+	raise (UnixExit 0)
+      end);
+
     let contains_cocci =
       (* rather a hack... don't want to think about all possible options *)
       List.exists (function x -> Filename.check_suffix x ".cocci") arglist
         && not (List.mem "--parse-cocci" arglist)
 	&& not (List.mem "--rule-dependencies" arglist) in
-    if not (null (Common.inter_set arglist
+    if (Common.inter_set arglist
 	            ["--cocci-file";"--sp-file";"--sp";"--test";"--testall";
-                      "--test-okfailed";"--test-regression-okfailed"]))
+                      "--test-okfailed";"--test-regression-okfailed"]) <> []
          || contains_cocci
     then run_profile quiet_profile;
 
@@ -1251,7 +1263,7 @@ let main () =
                 chosen
               end
             else List.hd !args
-        in if !FC.include_path =*= []
+        in if !FC.include_path = []
            then FC.include_path := [Filename.concat chosen_dir "include"]);
 
     args := List.rev !args;
@@ -1344,16 +1356,16 @@ let main () =
     | xs when List.mem !action (Common.action_list all_actions) ->
         Common.do_action !action xs all_actions
 
-    | [] when !action =$= "--parse-cocci" ->
+    | [] when !action = "--parse-cocci" ->
         Testing.test_parse_cocci !cocci_file
 
-    | [] when !action =$= "--rule-dependencies" ->
+    | [] when !action = "--rule-dependencies" ->
         Testing.test_rule_dependencies !cocci_file
 
      (* I think this is used by some scripts in some Makefile for our
       * big-tests. So don't remove.
       *)
-    | [file1;file2] when !action =$= "--compare-c" ->
+    | [file1;file2] when !action = "--compare-c" ->
        Test_parsing_c.test_compare_c file1 file2 (* result = unix code *)
 
     (* could add the Test_parsing_c.test_actions such as -parse_c & co *)
