@@ -7,11 +7,11 @@ let prepare coccifile code =
     List.fold_left
       (function prev ->
 	function
-	    Ast_cocci.ScriptRule (name,"ocaml",deps,mv,code) ->
+	    Ast_cocci.ScriptRule (name,"ocaml",deps,mv,script_vars,code) ->
 	      code :: prev
-	  | Ast_cocci.InitialScriptRule (name,"ocaml",deps,code) ->
+	  | Ast_cocci.InitialScriptRule (name,"ocaml",deps,mvs,code) ->
 	      code :: prev
-	  | Ast_cocci.FinalScriptRule (name,"ocaml",deps,code) ->
+	  | Ast_cocci.FinalScriptRule (name,"ocaml",deps,mvs,code) ->
 	      code :: prev
 	  | _ -> prev)
       [] code in
@@ -19,7 +19,9 @@ let prepare coccifile code =
   then None
   else failwith "OCaml scripting is unsupported. Compile spatch with OCaml version >= 3.11"
 
+let prepare_simple _ =
+  failwith "OCaml scripting is unsupported. Compile spatch with OCaml version >= 3.11"
+
 let load_file mlfile = ()
 let clean_file mlfile = ()
 let test () = ()
-
