@@ -16,12 +16,12 @@ let call_pretty0 f a = caller "" f a
 let exprrep = call_pretty Pretty_print_c.pp_expression_gen
 
 let stringrep = function
-  Ast_c.MetaIdVal        (s,_) -> s
+  Ast_c.MetaIdVal        s -> s
 | Ast_c.MetaAssignOpVal op -> call_pretty Pretty_print_c.pp_assignOp_gen op
 | Ast_c.MetaBinaryOpVal op -> call_pretty Pretty_print_c.pp_binaryOp_gen op
 | Ast_c.MetaFuncVal      s -> s
 | Ast_c.MetaLocalFuncVal s -> s
-| Ast_c.MetaExprVal      (expr,_) -> exprrep expr
+| Ast_c.MetaExprVal      (expr,_,_) -> exprrep expr
 | Ast_c.MetaExprListVal  expr_list ->
     call_pretty Pretty_print_c.pp_arg_list_gen expr_list
 | Ast_c.MetaTypeVal      typ -> call_pretty Pretty_print_c.pp_type_gen typ
@@ -33,8 +33,10 @@ let stringrep = function
     call_pretty Pretty_print_c.pp_field_gen field
 | Ast_c.MetaFieldListVal field ->
     call_pretty Pretty_print_c.pp_field_list_gen field
-| Ast_c.MetaStmtVal      statement ->
+| Ast_c.MetaStmtVal      (statement,_) ->
     call_pretty Pretty_print_c.pp_statement_gen statement
+| Ast_c.MetaStmtListVal      (statxs,_) ->
+    call_pretty Pretty_print_c.pp_statement_seq_list_gen statxs
 | Ast_c.MetaParamVal     param ->
     call_pretty Pretty_print_c.pp_param_gen param
 | Ast_c.MetaParamListVal params ->
@@ -48,6 +50,6 @@ let stringrep = function
     let print_pos = function
 	Ast_cocci.Real x -> string_of_int x
       | Ast_cocci.Virt(x,off) -> Printf.sprintf "%d+%d" x off in
-    Common.sprintf ("pos(%s,%s)") (print_pos pos1) (print_pos pos2)
+    Printf.sprintf ("pos(%s,%s)") (print_pos pos1) (print_pos pos2)
 | Ast_c.MetaPosValList positions -> "TODO: <<postvallist>>"
-
+| Ast_c.MetaNoVal -> failwith "no value"
