@@ -23,12 +23,12 @@ let ast_binding vl = function
     None -> []
   | Some _ ->
       [match vl with
-	Ast_c.MetaIdVal(id,_) | Ast_c.MetaFuncVal id
+	Ast_c.MetaIdVal id | Ast_c.MetaFuncVal id
       | Ast_c.MetaLocalFuncVal id ->
 	  Coccilib.Str id
       | Ast_c.MetaAssignOpVal op -> Coccilib.AssignOp op
       | Ast_c.MetaBinaryOpVal op -> Coccilib.BinaryOp op
-      | Ast_c.MetaExprVal(expr,_) -> Coccilib.Expr expr
+      | Ast_c.MetaExprVal(expr,_,_) -> Coccilib.Expr expr
       | Ast_c.MetaExprListVal arglist -> Coccilib.ExprList arglist
       | Ast_c.MetaParamVal param -> Coccilib.Param param
       | Ast_c.MetaParamListVal paramlist -> Coccilib.ParamList paramlist
@@ -39,9 +39,11 @@ let ast_binding vl = function
       | Ast_c.MetaDeclVal decl -> Coccilib.Decl decl
       | Ast_c.MetaFieldVal field -> Coccilib.Field field
       | Ast_c.MetaFieldListVal field -> Coccilib.FieldList field
-      | Ast_c.MetaStmtVal stm -> Coccilib.Stmt stm
+      | Ast_c.MetaStmtVal(stm,_) -> Coccilib.Stmt stm
+      | Ast_c.MetaStmtListVal(stm,_) -> Coccilib.StmtList stm
       | Ast_c.MetaFragListVal frags -> Coccilib.FragList frags
       | Ast_c.MetaFmtVal fmt -> Coccilib.Fmt fmt
+      | Ast_c.MetaNoVal -> failwith "no value for script metavariable"
 
       | Ast_c.MetaPosVal _ | Ast_c.MetaPosValList _ | Ast_c.MetaListlenVal _ ->
 	  failwith "not associated with a declared metavariable"]
@@ -51,21 +53,25 @@ let run mv ve script_vars name code =
   let find_binding (r,m) =
     try
       let elem =
-	List.find (function ((re,rm),_) -> r =*= re && m =$= rm) ve in
+	List.find (function ((re,rm),_) -> r = re && m = rm) ve in
       Some elem
     with Not_found -> None in
 
   let args =
     List.concat
       (List.map
-	 (function ((str_name,ast_name),(r,m),_) ->
+	 (function ((str_name,ast_name),(r,m),_,init) ->
 	   match find_binding (r,m) with
-	     None -> []
+	     None ->
+	       (match init with
+		 Ast_cocci.NoMVInit -> failwith "no value for ocaml metavars"
+	       | Ast_cocci.MVInitString s -> [Coccilib.Str s]
+	       | Ast_cocci.MVInitPosList -> [Coccilib.Pos []])
 	   | Some (_,vl) ->
 	       (string_binding vl str_name) @ (ast_binding vl ast_name))
 	 mv) in
 
-  let script_args = List.map (function _ -> ref "") script_vars in
+  let script_args = List.map (function _ -> ref Ast_c.MetaNoVal) script_vars in
 
   (* call the function *)
   Coccilib.include_match true;
