@@ -351,6 +351,9 @@ and expression = (expressionbis * exp_info ref (* semantic: *)) wrap3
   | New of (argument wrap2 (* , *) list) option * argument
   | Delete of expression
 
+  (* CPP [defined] operator, e.g. #if defined(A) *)
+  | Defined of name
+
   (* cppext: IfdefExpr TODO *)
 
   (* cppext: normally just expression *)
@@ -551,9 +554,11 @@ and declaration =
   | DeclList of onedecl wrap2 (* , *) list wrap (* ; fakestart sto *)
   (* cppext: *)
     (* bool is true if there is a ; at the end *)
-  | MacroDecl of (string * argument wrap2 list * bool) wrap (* fakestart *)
+  | MacroDecl of
+      (storagebis * string * argument wrap2 list * bool) wrap (* fakestart *)
   | MacroDeclInit of
-      (string * argument wrap2 list * initialiser) wrap (* fakestart *)
+      (storagebis * string * argument wrap2 list * initialiser)
+	wrap (* fakestart *)
 
      and onedecl =
        { v_namei: (name * v_init) option;
@@ -789,14 +794,13 @@ and program = toplevel list
  *)
 and metavars_binding = (Ast_cocci.meta_name, metavar_binding_kind) assoc
   and metavar_binding_kind =
-  | MetaIdVal        of string *
-	                Ast_cocci.meta_name list (* negative constraints *)
+  | MetaIdVal        of string
   | MetaFuncVal      of string
   | MetaLocalFuncVal of string
 
   | MetaExprVal      of expression (* a "clean expr" *) *
 	                (*subterm constraints, currently exprs*)
-	                Ast_cocci.meta_name list
+	                Ast_cocci.meta_name list * stripped
   | MetaExprListVal  of argument wrap2 list
   | MetaParamVal     of parameterType
   | MetaParamListVal of parameterType wrap2 list
@@ -807,7 +811,8 @@ and metavars_binding = (Ast_cocci.meta_name, metavar_binding_kind) assoc
   | MetaDeclVal      of declaration
   | MetaFieldVal     of field
   | MetaFieldListVal of field list
-  | MetaStmtVal      of statement
+  | MetaStmtVal      of statement * stripped
+  | MetaStmtListVal  of statement_sequencable list * stripped
   | MetaFmtVal       of string_format
   | MetaFragListVal  of string_fragment list
   | MetaAssignOpVal  of assignOp
@@ -821,7 +826,10 @@ and metavars_binding = (Ast_cocci.meta_name, metavar_binding_kind) assoc
   | MetaPosValList   of
       (Common.filename * string (*element*) * posl * posl) list (* min, max *)
   | MetaListlenVal   of int
+  | MetaNoVal
 
+(* WITHOUT_TYPES is only for code generated by a script *)
+and stripped = WITH_TYPES | WITHOUT_TYPES
 
 (*****************************************************************************)
 (* C comments *)
@@ -1068,9 +1076,9 @@ let compare_pos ii1 ii2 =
     (Real p1, Real p2) ->
       compare p1.Common.charpos p2.Common.charpos
   | (Virt (p1,_), Real p2) ->
-      if (compare p1.Common.charpos p2.Common.charpos) =|= (-1) then (-1) else 1
+      if (compare p1.Common.charpos p2.Common.charpos) = (-1) then (-1) else 1
   | (Real p1, Virt (p2,_)) ->
-      if (compare p1.Common.charpos p2.Common.charpos) =|= 1 then 1 else (-1)
+      if (compare p1.Common.charpos p2.Common.charpos) = 1 then 1 else (-1)
   | (Virt (p1,o1), Virt (p2,o2)) ->
       let poi1 = p1.Common.charpos in
       let poi2 = p2.Common.charpos in
@@ -1080,7 +1088,7 @@ let compare_pos ii1 ii2 =
       |	x -> x
 
 let equal_posl (l1,c1) (l2,c2) =
-  (l1 =|= l2) && (c1 =|= c2)
+  (l1 = l2) && (c1 = c2)
 
 let compare_posl (l1,c1) (l2,c2) =
   match l2 - l1 with
@@ -1100,7 +1108,7 @@ let info_to_fixpos ii =
 let is_test (e : expression) =
   let (_,info), _ = e in
   let (_,test) = !info in
-  test =*= Test
+  test = Test
 
 (*****************************************************************************)
 (* Abstract line *)
@@ -1220,7 +1228,7 @@ let rec (split_comma: 'a wrap2 list -> ('a, il) either list) =
   function
   | [] -> []
   | (e, ii)::xs ->
-      if null ii
+      if ii=[]
       then (Left e)::split_comma xs
       else Right ii::Left e::split_comma xs
 
@@ -1251,14 +1259,14 @@ let (unsplit_nocomma: ('a, il) either list -> 'a list) = function l ->
 
 let s_of_inc_file inc_file =
   match inc_file with
-  | Local xs -> xs +> Common.join "/"
-  | NonLocal xs -> xs +> Common.join "/"
+  | Local xs -> xs +> String.concat "/"
+  | NonLocal xs -> xs +> String.concat "/"
   | Weird s -> s
 
 let s_of_inc_file_bis inc_file =
   match inc_file with
-  | Local xs -> "\"" ^ xs +> Common.join "/" ^ "\""
-  | NonLocal xs -> "<" ^ xs +> Common.join "/" ^ ">"
+  | Local xs -> "\"" ^ xs +> String.concat "/" ^ "\""
+  | NonLocal xs -> "<" ^ xs +> String.concat "/" ^ ">"
   | Weird s -> s
 
 let fieldname_of_fieldkind fieldkind =
@@ -1270,7 +1278,7 @@ let fieldname_of_fieldkind fieldkind =
 let s_of_attr attr =
   attr
   +> List.map (fun (Attribute s, ii) -> s)
-  +> Common.join ","
+  +> String.concat ","
 
 
 (* ------------------------------------------------------------------------- *)
@@ -1278,11 +1286,11 @@ let str_of_name ident =
   match ident with
   | RegularName (s,ii) -> s
   | CppConcatenatedName xs ->
-      xs +> List.map (fun (x,iiop) -> unwrap x) +> Common.join "##"
+      xs +> List.map (fun (x,iiop) -> unwrap x) +> String.concat "##"
   | CppVariadicName (s, ii) -> "##" ^ s
   | CppIdentBuilder ((s,iis), xs) ->
       s ^ "(" ^
-        (xs +> List.map (fun ((x,iix), iicomma) -> x) +> Common.join ",") ^
+        (xs +> List.map (fun ((x,iix), iicomma) -> x) +> String.concat ",") ^
         ")"
 
 let get_s_and_ii_of_name name =
@@ -1315,7 +1323,7 @@ let get_local_ii_of_expr_inlining_ii_of_name e =
   let (ebis,_),ii = e in
   match ebis, ii with
   | Ident name, noii ->
-      assert(null noii);
+      assert (noii = []);
       ii_of_name name
   | RecordAccess   (e, name), ii ->
       ii @ ii_of_name name
@@ -1369,3 +1377,18 @@ let get_annot_info info key =
 let get_comments_before info = (!(info.comments_tag)).mbefore
 let get_comments_after info = (!(info.comments_tag)).mafter
 
+let string_of_toplevel = function
+  | Declaration _ -> "declaration"
+  | Definition _ -> "definition"
+  | CppTop _ -> "CppTop"
+  | IfdefTop _ -> "IfdefTop"
+  | MacroTop _ -> "MacroTop"
+  | EmptyDef _ -> "EmptyDef"
+  | NotParsedCorrectly _ -> "NotParsedCorrectly"
+  | FinalDef _ -> "FinalDef"
+  | Namespace _ -> "Namespace"
+
+let string_of_inc_file = function
+  | Local lst -> "local://" ^ (String.concat "/" lst)
+  | NonLocal lst -> "nonlocal://" ^ (String.concat "/" lst)
+  | Weird s -> "weird://" ^ s
