@@ -299,7 +299,9 @@ let extract_is_fake ((node, info), nodestr) = info.is_fake
 let mk_any_node is_fake node labels bclabels nodestr =
   let nodestr =
     if !Flag_parsing_c.show_flow_labels
-    then nodestr ^ ("[" ^ (labels +> List.map i_to_s +> join ",") ^ "]")
+    then
+      nodestr ^
+      ("[" ^ (labels +> List.map string_of_int +> String.concat ",") ^ "]")
     else nodestr
   in
   ((node, {labels = labels;is_loop=false;bclabels=bclabels;is_fake=is_fake}),
@@ -324,7 +326,7 @@ let find_node f g =
 let remove_one_node nodei g =
   let preds = (g#predecessors nodei)#tolist in
   let succs = (g#successors nodei)#tolist in
-  assert (not (null preds));
+  assert (preds <> []);
 
   preds +> List.iter (fun (predi, Direct) ->
     g#del_arc ((predi, nodei), Direct);
