@@ -1,7 +1,7 @@
 open Ast_c
 
 type node = node1 * string (* For debugging. Used by print_graph *)
-  and node1 = node2 * nodeinfo 
+  and node1 = node2 * nodeinfo
    and nodeinfo = {
       labels: int list;   (* Labels. Trick used for CTL engine *)
       bclabels: int list; (* parent of a break or continue node *)
@@ -9,7 +9,7 @@ type node = node1 * string (* For debugging. Used by print_graph *)
       is_fake: bool;
     }
   and node2 =
-  | TopNode 
+  | TopNode
   | EndNode
 
   | FunHeader     of definition (* but empty body *)
@@ -25,8 +25,8 @@ type node = node1 * string (* For debugging. Used by print_graph *)
   | WhileHeader   of statement * expression wrap
   | DoHeader      of statement * info
   | DoWhileTail   of expression wrap
-  | ForHeader     of statement * 
-                 (exprStatement wrap * exprStatement wrap * exprStatement wrap)
+  | ForHeader     of statement *
+                 (declOrExpr * exprStatement wrap * exprStatement wrap)
                  wrap
   | SwitchHeader  of statement * expression wrap
   | MacroIterHeader of statement * (string * argument wrap2 list) wrap
@@ -42,6 +42,11 @@ type node = node1 * string (* For debugging. Used by print_graph *)
   | IfdefElse of ifdef_directive
   | IfdefEndif of ifdef_directive
 
+  (* IfdefIteHeader is the header node for Ifdef_Ite selection statements.
+   * Ifdef_Ite is decorated on top of the CFG for an If statement.
+   *)
+  | IfdefIteHeader of il
+
   (* ------------------------ *)
   | DefineHeader of string wrap * define_kind
 
@@ -53,14 +58,16 @@ type node = node1 * string (* For debugging. Used by print_graph *)
 
   | Include of includ
 
-  | MacroTop of string * argument wrap2 list * il 
+  | PragmaHeader of string wrap * pragmainfo
+
+  | MacroTop of string * argument wrap2 list * il
 
   (* ------------------------ *)
   | Case      of statement * expression wrap
   | Default   of statement * unit wrap
 
   | Continue  of statement * unit wrap
-  | Break     of statement * unit wrap
+  | Break     of statement * unit wrap * bool (* true for switch *)
 
   (* no counter part in cocci *)
   | CaseRange of statement * (expression * expression) wrap
@@ -71,23 +78,32 @@ type node = node1 * string (* For debugging. Used by print_graph *)
   | Asm of statement * asmbody wrap
   | MacroStmt of statement * unit wrap
 
+  | Exec of statement * exec_code list wrap
 
   (* ------------------------ *)
-  | Enter 
+  | Enter
   | Exit
   | Fake
-  | CaseNode of int 
+  | CaseNode of int
 
   (* ------------------------ *)
   (* for ctl:  *)
-  | TrueNode
+  | TrueNode of bool ref
   | FalseNode
   | InLoopNode
-  | AfterNode
+  | AfterNode of after_type
   | FallThroughNode
   | LoopFallThroughNode
   | ErrorExit
 
+and after_type =
+  | RetAfterNode (* after for a block ending in return *)
+  | GotoAfterNode (* after for a block ending in goto *)
+  | BreakAfterNode (* after for a block ending in break *)
+  | ContAfterNode (* after for a block ending in continue *)
+  | SWBreakAfterNode (* after for a block ending in break from switch *)
+  | NormalAfterNode
+
 type edge = Direct
 
 type cflow = (node, edge) Ograph_extended.ograph_mutable
