@@ -1,18 +1,3 @@
-(* Yoann Padioleau
- *
- * Copyright (C) 2010, University of Copenhagen DIKU and INRIA.
- * Copyright (C) 2007, 2008 Ecole des Mines de Nantes
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License (GPL)
- * version 2 as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * file license.txt for more details.
- *)
-
 open Common
 
 module TH = Token_helpers
@@ -42,7 +27,7 @@ open Token_views_c
  *   - (3) in an argument to a macro call as in   IDENT(if);
  * Case 1 is easy to fix in define_ident.
  * Case 2 is easy to fix in define_parse where detect such toks in
- * the parameter and then replace their occurence in the body in a Tident.
+ * the parameter and then replace their occurrence in the body in a Tident.
  * Case 3 is only an issue when the expanded token is not really use
  * as usual but use for instance in concatenation as in  a ## if
  * when expanded. In the case the grammar this time will not be happy
@@ -66,7 +51,8 @@ let pr2, pr2_once = Common.mk_pr2_wrappers Flag_parsing_c.verbose_parsing
 type define_def = string * define_param * define_body
  and define_param =
    | NoParam
-   | Params of string list
+   | Params of define_arg list
+ and define_arg = FixedArg of string | VariadicArg of string
  and define_body =
    | DefineBody of Parser_c.token list
    | DefineHint of parsinghack_hint
@@ -134,14 +120,15 @@ let string_of_define_def (s, params, body) =
     | NoParam ->
         spf "#define %s " s
     | Params xs ->
-        spf "#define %s(%s) " s (Common.join "," xs)
+	let xs = List.map (function FixedArg s -> s | VariadicArg s -> s) xs in
+        spf "#define %s(%s) " s (String.concat "," xs)
   in
   let s2 =
     match body with
     | DefineHint hint ->
         string_of_parsinghack_hint hint
     | DefineBody xs ->
-        Common.join " " (xs +> List.map Token_helpers.str_of_tok)
+        String.concat " " (xs +> List.map Token_helpers.str_of_tok)
   in
   s1 ^ s2
 
@@ -172,7 +159,6 @@ let rec remap_keyword_tokens xs =
           x::y::remap_keyword_tokens xs
 
       | Parser_c.TCppConcatOp (i1),   y ->
-
           let s = TH.str_of_tok y in
           let ii = TH.info_of_tok y in
           if s ==~ Common.regexp_alpha
@@ -281,13 +267,14 @@ let rec (cpp_engine:
     (* expand only TIdent ? no cos the parameter of the macro
      * can actually be some 'register' so may have to look for
      * any tokens candidates for the expansion.
-     * Only subtelity is maybe dont expand the TDefineIdent.
+     * Only subtelity is maybe don't expand the TDefineIdent.
      *
      * update: in fact now the caller (define_parse) will have done
      * the job right and already replaced the macro parameter with a TIdent.
      *)
     match tok with
-    | TIdent (s,i1) when List.mem_assoc s env -> Common.assoc s env
+    | TIdent (s,i1) when List.mem_assoc s env ->
+	Common.assoc s env
     | x -> [x]
   )
   +> List.flatten
@@ -320,6 +307,7 @@ let rec apply_macro_defs
  ?evaluate_concatop
  ?(inplace_when_single=true)
  defs xs =
+
  let rec apply_macro_defs xs =
   match xs with
   | [] -> ()
@@ -365,44 +353,57 @@ let rec apply_macro_defs
           | DefineBody bodymacro ->
 
               (* bugfix: better to put this that before the match body,
-               * cos our macrostatement hint can have variable number of
-               * arguments and so it's ok if it does not match exactly
-               * the number of arguments. *)
-              if List.length params != List.length xxs
-              then begin
-                pr2_once ("WEIRD: macro with wrong number of arguments: " ^ s);
-                (* old: id.new_tokens_before <- bodymacro; *)
+		 * cos our macrostatement hint can have variable number of
+		 * arguments and so it's ok if it does not match exactly
+		 * the number of arguments. *)
+	      let build_binder params xxs =
+		let rec loop = function
+		    ([],[]) -> Some (function [] -> [] | _ -> failwith "bad")
+		  | ([],[[]]) -> Some (function [[]] -> [] | _ -> failwith "bad")
+		  | ([],l) -> None
+		  | ([(VariadicArg s)],l) ->
+		      Some (function l -> List.map (function a -> (s,a)) l)
+		  | ((VariadicArg _)::_,l) -> None
+		  | ((FixedArg _)::_,[]) -> None
+		  | ((FixedArg s)::rest,x::xs) ->
+		      (match loop (rest,xs) with
+			Some k ->
+			  Some (function l -> (s,(List.hd l)) :: k (List.tl l))
+		      |	None -> None) in
+		loop (params, xxs) in
+	      (match build_binder params xxs with
+		None ->
+                  pr2_once
+		    ("WEIRD: macro with wrong number of arguments: " ^ s);
+                  (* old: id.new_tokens_before <- bodymacro; *)
 
-                (* update: if wrong number, then I just pass this macro *)
-                [Parenthised (xxs, info_parens)] +>
+                  (* update: if wrong number, then I just pass this macro *)
+                  [Parenthised (xxs, info_parens)] +>
                   iter_token_paren (set_as_comment Token_c.CppMacro);
-                set_as_comment Token_c.CppMacro id;
+                  set_as_comment Token_c.CppMacro id
+	      |	Some bind ->
 
-                ()
-              end
-              else
+                  let xxs' = xxs +> List.map (fun x ->
+		    (tokens_of_paren_ordered x) +> List.map (fun x ->
+		      TH.visitor_info_of_tok Ast_c.make_expanded x.tok
+			)
+		      ) in
+                  id.new_tokens_before <-
+                      (* !!! cpp expansion job here  !!! *)
+		    cpp_engine ?evaluate_concatop
+		      (bind xxs') bodymacro;
 
-                let xxs' = xxs +> List.map (fun x ->
-                  (tokens_of_paren_ordered x) +> List.map (fun x ->
-                    TH.visitor_info_of_tok Ast_c.make_expanded x.tok
-                  )
-                ) in
-                id.new_tokens_before <-
-                  (* !!! cpp expansion job here  !!! *)
-                  cpp_engine ?evaluate_concatop
-                    (Common.zip params xxs') bodymacro;
-
-                (* important to do that after have apply the macro, otherwise
-                 * will pass as argument to the macro some tokens that
-                 * are all TCommentCpp
-                 *)
-                [Parenthised (xxs, info_parens)] +>
+                      (* important to do that after have apply the macro,
+			 otherwise will pass as argument to the macro some
+			 tokens that are all TCommentCpp
+                      *)
+                  [Parenthised (xxs, info_parens)] +>
                   iter_token_paren (set_as_comment Token_c.CppMacro);
-                set_as_comment Token_c.CppMacro id;
+                  set_as_comment Token_c.CppMacro id)
 
-            | DefineHint (HintMacroStatement as hint) ->
+          | DefineHint (HintMacroStatement as hint) ->
                 (* important to do that after have apply the macro, otherwise
-                 * will pass as argument to the macro some tokens that
+                   * will pass as argument to the macro some tokens that
                  * are all TCommentCpp
                  *
                  * note: such macrostatement can have a variable number of
@@ -447,9 +448,9 @@ let rec apply_macro_defs
       let (_s, params, body) = Hashtbl.find defs s in
 
       (match params with
-      | Params params ->
+      | Params _ ->
           pr2 ("WEIRD: macro with params but no parens found: " ^ s);
-          (* dont apply the macro, perhaps a redefinition *)
+          (* don't apply the macro, perhaps a redefinition *)
           ()
       | NoParam ->
           (match body with
@@ -516,36 +517,40 @@ let rec (define_parse: Parser_c.token list -> (string * define_def) list) =
             xs +> Common.split_when (function TDefEOL _ -> true | _ -> false) in
 	  let params =
             tokparams +> Common.map_filter (function
-              | TComma _ -> None
-              | TIdent (s, _) -> Some s
+              |	 TComma _ -> None
+              |	 TIdent (s, _) -> Some (FixedArg s)
 
               (* TODO *)
-              | TDefParamVariadic (s, _) -> Some s
+              |	 TDefParamVariadic (s, _) -> Some (VariadicArg s)
               (* TODO *)
-              | TEllipsis _ -> Some "..."
+              |	 TEllipsis _ -> Some (VariadicArg "...")
 
-              | x ->
+              |	 x ->
               (* bugfix: param of macros can be tricky *)
-		  let s = TH.str_of_tok x in
-		  if s ==~ Common.regexp_alpha
-		  then begin
-		    pr2 (spf "remapping: %s to a macro parameter" s);
-		    Some s
-		  end
-		  else
-		    begin
-		      pr2 (spf "bad character %s in macro parameter list" s);
-		      raise Bad_param
-		    end)  in
+                  let s = TH.str_of_tok x in
+                  if s ==~ Common.regexp_alpha
+                  then begin
+                    pr2 (spf "remapping: %s to a macro parameter" s);
+                    Some (FixedArg s)
+                  end
+                  else
+                    begin
+                      pr2 (spf "bad character %s in macro parameter list" s);
+                      raise Bad_param
+                    end) in
           (* bugfix: also substitute to ident in body so cpp_engine will
-           * have an easy job.
-           *)
+             * have an easy job.
+          *)
 	  let body = body +> List.map (fun tok ->
             match tok with
             | TIdent _ -> tok
             | _ ->
 		let s = TH.str_of_tok tok in
 		let ii = TH.info_of_tok tok in
+		let params =
+		  List.map
+		    (function FixedArg s -> s | VariadicArg s -> s)
+		    params in
 		if s ==~ Common.regexp_alpha && List.mem s params
 		then begin
 		  pr2 (spf "remapping: %s to an ident in macro body" s);
@@ -582,5 +587,3 @@ let extract_macros xs =
     not (TH.is_comment x)
   ) in
   define_parse cleaner
-
-
