@@ -22,7 +22,7 @@ let common_h   = ref (mk_macro_path ~cocci_path:!path "common_macros.h")
 
 let cmdline_flags_macrofile () =
   [
-    "-macro_file_builtins", Arg.Set_string std_h,
+    "--macro-file-builtins", Arg.Set_string std_h,
     " <file> (default=" ^ !std_h ^ ")";
   ]
 
@@ -40,17 +40,6 @@ let cmdline_flags_cpp () = [
     " <dir>"
   ]
 
-(*****************************************************************************)
-(* types *)
-(*****************************************************************************)
-let std_envir = ref (Filename.concat !path "config/envos/environment_splint.h")
-
-let cmdline_flags_envfile () =
-  [
-    "-env_file", Arg.Set_string std_envir,
-    " <file> (default=" ^ !std_envir ^ ")";
-  ]
-
 (*****************************************************************************)
 (* show *)
 (*****************************************************************************)
@@ -87,22 +76,22 @@ let show_flow_labels = ref true
 
 let cmdline_flags_verbose () =
   [
-    "-no_verbose_parsing", Arg.Clear verbose_parsing , "  ";
-    "-no_verbose_lexing", Arg.Clear verbose_lexing , "  ";
-    "-no_verbose_annotater", Arg.Clear verbose_annotater , "  ";
+    "--no-verbose-parsing", Arg.Clear verbose_parsing , "  ";
+    "--no-verbose-lexing", Arg.Clear verbose_lexing , "  ";
+    "--no-verbose-annotater", Arg.Clear verbose_annotater , "  ";
 
-    "-no_parse_error_msg", Arg.Clear verbose_parsing, " ";
-    "-no_type_error_msg",  Arg.Clear verbose_type, " ";
+    "--no-parse-error-msg", Arg.Clear verbose_parsing, " ";
+    "--no-type-error-msg",  Arg.Clear verbose_type, " ";
 
 
-    "-filter_msg",      Arg.Set  filter_msg ,
+    "--filter-msg",      Arg.Set  filter_msg ,
     "  filter some cpp message when the macro is a \"known\" cpp construct";
-    "-filter_msg_define_error",Arg.Set filter_msg_define_error,
+    "--filter-msg-define-error",Arg.Set filter_msg_define_error,
     "  filter the error msg";
 
-    "-filter_define_error",Arg.Set filter_define_error,
+    "--filter-define-error",Arg.Set filter_define_error,
     "  filter the error, which will not be added in the stat";
-    "-filter_passed_level",Arg.Set_int filter_passed_level,"  ";
+    "--filter-passed-level",Arg.Set_int filter_passed_level,"  ";
   ]
 
 
@@ -124,13 +113,13 @@ let debug_cfg = ref false
 (*   "debug C parsing/unparsing", "" *)
 let cmdline_flags_debugging () =
   [
-  "-debug_cpp",          Arg.Set  debug_cpp, " ";
-  "-debug_lexer",        Arg.Set  debug_lexer , " ";
-  "-debug_etdt",         Arg.Set  debug_etdt , "  ";
-  "-debug_typedef",      Arg.Set  debug_typedef, "  ";
+  "--debug-cpp",          Arg.Set  debug_cpp, " ";
+  "--debug-lexer",        Arg.Set  debug_lexer , " ";
+  "--debug-etdt",         Arg.Set  debug_etdt , "  ";
+  "--debug-typedef",      Arg.Set  debug_typedef, "  ";
 
-  "-debug_cfg",          Arg.Set debug_cfg , "  ";
-  "-debug_unparsing",      Arg.Set  debug_unparsing, "  ";
+  "--debug-cfg",          Arg.Set debug_cfg , "  ";
+  "--debug-unparsing",      Arg.Set  debug_unparsing, "  ";
   ]
 
 (*****************************************************************************)
@@ -140,12 +129,12 @@ let cmdline_flags_debugging () =
 let check_annotater = ref true
 let cmdline_flags_checks () =
   [
-  "-disable_check_annotater",          Arg.Clear  check_annotater, " ";
-  "-enable_check_annotater",          Arg.Set  check_annotater, " ";
+  "--disable-check-annotater",          Arg.Clear  check_annotater, " ";
+  "--enable-check-annotater",          Arg.Set  check_annotater, " ";
   ]
 
 (*****************************************************************************)
-(* change algo *)
+(* change algorithm *)
 (*****************************************************************************)
 
 (* cocci specific *)
@@ -153,7 +142,7 @@ let label_strategy_2 = ref false
 
 let cmdline_flags_algos () =
   [
-    "-l1",                Arg.Clear label_strategy_2, " ";
+    "--l1",                Arg.Clear label_strategy_2, " ";
   ]
 
 (*****************************************************************************)
@@ -162,26 +151,33 @@ let cmdline_flags_algos () =
 
 let cpp_directive_passing = ref false
 let ifdef_directive_passing = ref false
+let ifdef_to_if = ref true(*false*)
 
 let disable_multi_pass = ref false
 let disable_add_typedef = ref false
 
 let if0_passing = ref true
 let add_typedef_root = ref true
+let exts_ITU = ref false (* ITU.dk extensions *)
+
+(* defined and undefined constants *)
+let add c s = c := (Str.split (Str.regexp ",") s) @ !c
+let defined = ref ([] : string list)
+let undefined = ref ([] : string list)
 
 let cmdline_flags_parsing_algos () = [
 
-    "-directive_passing",              Arg.Set cpp_directive_passing,
+    "--directive-passing",              Arg.Set cpp_directive_passing,
     "   pass most cpp directives, especially when inside function";
-    "-ifdef_passing",              Arg.Set ifdef_directive_passing,
+    "--ifdef-passing",              Arg.Set ifdef_directive_passing,
     "   pass ifdef directives ";
 
-    "-noif0_passing",   Arg.Clear if0_passing,
+    "--noif0-passing",   Arg.Clear if0_passing,
     " ";
-    "-noadd_typedef_root",   Arg.Clear add_typedef_root, " ";
-    "-noadd_typedef",   Arg.Set disable_add_typedef, " ";
+    "--noadd-typedef-root",   Arg.Clear add_typedef_root, " ";
+    "--noadd-typedef",   Arg.Set disable_add_typedef, " ";
 
-    "-disable_multi_pass", Arg.Set disable_multi_pass, " ";
+    "--disable-multi-pass", Arg.Set disable_multi_pass, " ";
 ]
 
 (*****************************************************************************)
@@ -193,13 +189,15 @@ let diff_lines = ref (None : string option) (* number of lines of context *)
 
 (* for parse_c *)
 let use_cache = ref false
+let cache_prefix = ref (None : string option)
+let cache_limit = ref (None : int option)
 
 let cmdline_flags_other () =
   [
-    "-U", Arg.Int (fun n -> diff_lines := Some (Common.i_to_s n)),
+    "-U", Arg.Int (fun n -> diff_lines := Some (string_of_int n)),
     "  set number of diff context lines";
 
-    "-use_cache", Arg.Set use_cache,
+    "--use-cache", Arg.Set use_cache,
     "   use .ast_raw pre-parsed cached C file";
   ]
 
@@ -245,6 +243,7 @@ let set_long_bits n =
 
 type spacing = LINUX | SMPL
 let spacing = ref LINUX
+let indent = ref 0
 
 let set_linux_spacing _ = spacing := LINUX (*follow the conventions of Linux*)
 let set_smpl_spacing _ = spacing := SMPL   (*use spacing from the SP*)
@@ -259,3 +258,5 @@ let no_loops = ref false
 let no_gotos = ref false
 
 let keep_comments = ref false (* unparsing *)
+
+let parsing_header_for_types = ref false
