@@ -1,6 +1,4 @@
 
-val _handle_typedef : bool ref
-
 val enable_typedef  : unit -> unit
 val disable_typedef : unit -> unit
 val is_enabled_typedef : unit -> bool
@@ -21,7 +19,8 @@ val del_scope : unit -> unit
 
 val is_typedef : string -> bool
 
-val lexer_reset_typedef : unit -> unit
+val lexer_reset_typedef :
+    (string, identkind) Common.scoped_h_env option (* known typedefs *) -> unit
 
 val _old_state : (string, identkind) Common.scoped_h_env ref
 val save_typedef_state : unit -> unit
@@ -48,4 +47,3 @@ val pop_context: unit -> unit
 val default_hint : unit -> lexer_hint
 
 val is_top_or_struct : context -> bool
-
