@@ -23,15 +23,19 @@ val init_defs_builtins : Common.filename -> unit
 
 (* This is the main function *)
 val parse_c_and_cpp :
-    Common.filename (*cfile*) -> (program2 * Parsing_stat.parsing_stat)
+    bool (* true if format characters need to be parsed *) ->
+      Common.filename (*cfile*) ->
+	(program2 * Parsing_stat.parsing_stat)
 val parse_c_and_cpp_keep_typedefs :
     (string, Lexer_parser.identkind) Common.scoped_h_env option (*typedefs*) ->
       (string, Cpp_token_c.define_def) Hashtbl.t option (* macro defs *) ->
+      bool (* true if format characters need to be parsed *) ->
 	Common.filename (*cfile*) ->
 	  (extended_program2 * Parsing_stat.parsing_stat)
 
 (* use some .ast_raw memoized version, and take care if obsolete *)
 val parse_cache:
+    bool (* true if format characters need to be parsed *) ->
     Common.filename (*cfile*) -> (extended_program2 * Parsing_stat.parsing_stat)
 
 
@@ -52,8 +56,9 @@ val tokens_of_string: string -> Parser_c.token list
 
 val parse:                        Common.filename -> Ast_c.program
 val parse_print_error:            Common.filename -> Ast_c.program
-val parse_gen:
-    ((Lexing.lexbuf -> Parser_c.token) -> Lexing.lexbuf -> 'a) -> string -> 'a
+val parse_gen: cpp:bool -> tos:bool
+    -> ((Lexing.lexbuf -> Parser_c.token) -> Lexing.lexbuf -> 'a)
+    -> string -> 'a
 
 (* ---------------------------------------------------------------------- *)
 (* Easy way to build complex Ast elements from simple strings.
@@ -73,3 +78,10 @@ val print_commentized       : Parser_c.token list -> unit
 
 val program_of_program2 : program2 -> Ast_c.program
 val with_program2: (Ast_c.program -> Ast_c.program) -> program2 -> program2
+
+
+(* ---------------------------------------------------------------------- *)
+(* custom error reporting function *)
+type parse_error_function = int -> Parser_c.token list -> (int * int) ->
+    string array -> int -> unit
+val set_parse_error_function : parse_error_function -> unit
