@@ -422,58 +422,47 @@ let mark_end_define ii =
   in
   TDefEOL (ii')
 
-(* put the TDefEOL at the good place *)
-let rec define_line_1 acc xs =
-  match xs with
+(* put the TDefEOL at the right place *)
+let rec define_line_1 acc = function
   | [] -> List.rev acc
-  | TDefine ii::xs ->
-      let line = Ast_c.line_of_info ii in
-      let acc = (TDefine ii) :: acc in
-      define_line_2 acc line ii xs
-  | TUndef ii::xs ->
-      let line = Ast_c.line_of_info ii in
-      let acc = (TUndef ii) :: acc in
-      define_line_2 acc line ii xs
-  | TPragma ii::xs ->
-      let line = Ast_c.line_of_info ii in
-      let acc = (TPragma ii) :: acc in
-      define_line_2 acc line ii xs
-  | TCppEscapedNewline ii::xs ->
-      pr2 ("SUSPICIOUS: a \\ character appears outside of a #define at");
-      pr2 (Ast_c.strloc_of_info ii);
-      let acc = (TCommentSpace ii) :: acc in
-      define_line_1 acc xs
-  | x::xs -> define_line_1 (x::acc) xs
+  | token::tokens ->
+    begin match token with
+      | TDefine ii | TUndef ii | TPragma ii ->
+        let line = Ast_c.line_of_info ii in
+        define_line_2 (token::acc) line ii tokens
+      | TCppEscapedNewline ii ->
+        pr2 ("SUSPICIOUS: a \\ character appears outside of a #define at");
+        pr2 (Ast_c.strloc_of_info ii);
+        define_line_1 ((TCommentSpace ii) :: acc) tokens
+      | _ -> define_line_1 (token::acc) tokens
+    end
 
-and define_line_2 acc line lastinfo xs =
-  match xs with
+and define_line_2 acc line lastinfo = function
   | [] ->
       (* should not happened, should meet EOF before *)
       pr2 "PB: WEIRD";
-      List.rev (mark_end_define lastinfo::acc)
-  | x::xs ->
-      let line' = TH.line_of_tok x in
-      let info = TH.info_of_tok x in
-
-      (match x with
+      List.rev ((mark_end_define lastinfo)::acc)
+  | token::tokens as all_tokens ->
+      let line' = TH.line_of_tok token in
+      let info = TH.info_of_tok token in
+      (match token with
       | EOF ii ->
-	  let acc = (mark_end_define lastinfo) :: acc in
-	  let acc = (EOF ii) :: acc in
-          define_line_1 acc xs
+          define_line_1 (token::(mark_end_define lastinfo)::acc) tokens
       | TCppEscapedNewline ii ->
           if (line' <> line) then pr2 "PB: WEIRD: not same line number";
-	  let acc = (TCommentSpace ii) :: acc in
-          define_line_2 acc (line+1) info xs
-      | x ->
-          if line' =|= line
-          then define_line_2 (x::acc) (end_line_of_tok line' x) info xs
+          define_line_2 ((TCommentSpace ii)::acc) (line+1) info tokens
+      | _ ->
+          if line' = line
+          then
+            define_line_2
+              (token::acc) (end_line_of_tok line' token) info tokens
           else
 	    (* Put end of line token before the newline.  A newline at least
 	       must be there because the line changed and because we saw a
 	       #define previously to get to this function at all *)
 	    define_line_1
 	      ((List.hd acc)::(mark_end_define lastinfo::(List.tl acc)))
-	      (x::xs)
+	      all_tokens
       )
 
 (* for a comment, the end line is not the same as line_of_tok *)
@@ -488,23 +477,21 @@ and end_line_of_tok default = function
       |	_ -> failwith (Printf.sprintf "bad comment: %d" (TH.line_of_tok t)))
   |  t -> default
 
-let rec define_ident acc xs =
-  match xs with
+let rec define_ident acc = function
   | [] -> List.rev acc
-  | TUndef ii::xs ->
-      let acc = TUndef ii :: acc in
-      (match xs with
+  | token::tokens ->
+    let acc = token::acc in
+    (match token with
+    | TUndef ii ->
+      (match tokens with
 	TCommentSpace i1::TIdent (s,i2)::xs ->
-	  let acc = (TCommentSpace i1) :: acc in
-	  let acc = (TIdentDefine (s,i2)) :: acc in
-          define_ident acc xs
+          define_ident ((TIdentDefine (s,i2))::(TCommentSpace i1)::acc) xs
       | _ ->
-          pr2 "WEIRD: weird #define body";
-          define_ident acc xs
+          pr2 "WEIRD: weird #undef body";
+          define_ident acc tokens
       )
-  | TDefine ii::xs ->
-      let acc = TDefine ii :: acc in
-      (match xs with
+    | TDefine ii ->
+      (match tokens with
       | TCommentSpace i1::TIdent (s,i2)::TOPar (i3)::xs ->
           (* Change also the kind of TIdent to avoid bad interaction
            * with other parsing_hack tricks. For instant if keep TIdent then
@@ -547,8 +534,7 @@ let rec define_ident acc xs =
           pr2 "WEIRD: weird #define body";
           define_ident acc xs
       )
-  | TPragma ii::xs ->
-      let acc = TPragma ii :: acc in
+    | TPragma ii ->
       let rec loop acc = function
 	  ((TDefEOL i1) as x) :: xs -> define_ident (x::acc) xs
 	| TCommentSpace i1::TIdent (s,i2)::xs ->
@@ -576,10 +562,9 @@ let rec define_ident acc xs =
 	| xs ->
             pr2 "WEIRD: weird #pragma";
             define_ident acc xs in
-      loop acc xs
-  | x::xs ->
-      let acc = x :: acc in
-      define_ident acc xs
+      loop acc tokens
+    | _ -> define_ident acc tokens
+    )
 
 
 
@@ -846,7 +831,7 @@ let rec find_ifdef_mid xs =
             let counts = xxs +> List.map count_open_close_stuff_ifdef_clause in
             let cnt1, cnt2 = List.hd counts in
             if cnt1 <> 0 || cnt2 <> 0 &&
-               counts +> List.for_all (fun x -> x =*= (cnt1, cnt2))
+               counts +> List.for_all (fun x -> x = (cnt1, cnt2))
               (*
                 if counts +> List.exists (fun (cnt1, cnt2) ->
                 cnt1 <> 0 || cnt2 <> 0
@@ -1402,13 +1387,13 @@ let rec find_macro_lineparen xs =
           Parenthised (xxs,info_parens);
         ] as _line1
         ))
-    ::xs when col1 =|= 0
+    ::xs when col1 = 0
     ->
       let condition =
         (* to reduce number of false positive *)
         (match xs with
         | (Line (PToken ({col = col2 } as other)::restline2))::_ ->
-            TH.is_eof other.tok || (col2 =|= 0 &&
+            TH.is_eof other.tok || (col2 = 0 &&
              (match other.tok with
              | TOBrace _ -> false (* otherwise would match funcdecl *)
              | TCBrace _ when ctx <> InFunction -> false
@@ -1457,7 +1442,7 @@ let rec find_macro_lineparen xs =
       (* This can give a false positive for K&R functions if the function
          name is in the same column as the first parameter declaration. *)
       let condition =
-        (col1 =|= col2 &&
+        (col1 = col2 &&
             (match other.tok with
             | TOBrace _ -> false (* otherwise would match funcdecl *)
             | TCBrace _ when ctx <> InFunction -> false
@@ -1472,7 +1457,7 @@ let rec find_macro_lineparen xs =
         ||
         (col2 <= col1 &&
               (match other.tok, restline2 with
-              | TCBrace _, _ when ctx =*= InFunction -> true
+              | TCBrace _, _ when ctx = InFunction -> true
               | Treturn _, _ -> true
               | Tif _, _ -> true
               | Telse _, _ -> true
@@ -1490,7 +1475,7 @@ let rec find_macro_lineparen xs =
 
       if condition
       then
-        if col1 =|= 0 then ()
+        if col1 = 0 then ()
         else begin
           msg_macro_noptvirg s;
           macro.tok <- TMacroStmt (s, TH.info_of_tok macro.tok);
@@ -1518,7 +1503,7 @@ let rec find_macro_lineparen xs =
     (* when s ==~ regexp_macro *)
 
       let condition =
-        (col1 =|= col2 &&
+        (col1 = col2 &&
             col1 <> 0 && (* otherwise can match typedef of fundecl*)
             (match other.tok with
             | TPtVirg _ -> false
@@ -1530,7 +1515,7 @@ let rec find_macro_lineparen xs =
             )) ||
           (col2 <= col1 &&
               (match other.tok with
-              | TCBrace _ when ctx =*= InFunction -> true
+              | TCBrace _ when ctx = InFunction -> true
               | Treturn _ -> true
               | Tif _ -> true
               | Telse _ -> true
@@ -1957,7 +1942,7 @@ let lookahead2 ~pass next before =
   (* typedef inference, parse_typedef_fix3 *)
   (*-------------------------------------------------------------*)
   (* xx xx *)
-  | (TIdent(s,i1)::TIdent(s2,i2)::_ , _) when not_struct_enum before && s =$= s2
+  | (TIdent(s,i1)::TIdent(s2,i2)::_ , _) when not_struct_enum before && s = s2
       && ok_typedef s
       (* (take_safe 1 !passed_tok <> [TOPar]) ->  *)
     ->
@@ -2070,7 +2055,7 @@ let lookahead2 ~pass next before =
 
   (*  xx * yy      AND  in paramdecl *)
   | (TIdent (s, i1)::ptr , _)
-    when not_struct_enum before && (LP.current_context() =*= LP.InParameter)
+    when not_struct_enum before && (LP.current_context() = LP.InParameter)
 	&& pointer ~followed_by:(function TIdent _ -> true | _ -> false) ptr
 	&& ok_typedef s ->
       msg_typedef s i1 14; LP.add_typedef_root s;
@@ -2102,7 +2087,7 @@ let lookahead2 ~pass next before =
   (* [,(] xx [,)] AND param decl *)
   | (TIdent (s, i1)::(((TComma _|TCPar _)::_) as rest) ,
      ((TComma _ |TOPar _)::_ as bef))
-    when not_struct_enum before && (LP.current_context() =*= LP.InParameter)
+    when not_struct_enum before && (LP.current_context() = LP.InParameter)
       && k_and_r rest
       && not_has_type_before is_cparen rest
       && not_has_type_before is_oparen bef
@@ -2111,7 +2096,7 @@ let lookahead2 ~pass next before =
 	TKRParam(s,i1)
 
   | (TIdent (s, i1)::((TComma _|TCPar _)::_) , (TComma _ |TOPar _)::_ )
-    when not_struct_enum before && (LP.current_context() =*= LP.InParameter)
+    when not_struct_enum before && (LP.current_context() = LP.InParameter)
       && ok_typedef s
       ->
 
@@ -2198,7 +2183,7 @@ let lookahead2 ~pass next before =
 
   (* [(,] xx [   AND parameterdeclaration *)
   | (TIdent (s, i1)::TOCro _::_, (TComma _ |TOPar _)::_)
-      when (LP.current_context() =*= LP.InParameter)
+      when (LP.current_context() = LP.InParameter)
       && ok_typedef s
      ->
 
@@ -2225,7 +2210,7 @@ let lookahead2 ~pass next before =
 
   (*  xx * yy,      AND  in paramdecl *)
   | (TIdent (s, i1)::ptr , _)
-    when not_struct_enum before && (LP.current_context() =*= LP.InParameter)
+    when not_struct_enum before && (LP.current_context() = LP.InParameter)
 	&& pointer ~followed_by:(function TIdent _ -> true | _ -> false)
               ~followed_by_more:(function TComma _ :: _ -> true | _ -> false) ptr
 	&& ok_typedef s
@@ -2250,7 +2235,7 @@ let lookahead2 ~pass next before =
 
   (*  xx * yy ,     AND in Toplevel  *)
   | (TIdent (s, i1)::ptr , _)
-    when not_struct_enum before && (LP.current_context () =*= LP.InTopLevel)
+    when not_struct_enum before && (LP.current_context () = LP.InTopLevel)
 	&& ok_typedef s
 	&& pointer ~followed_by:(function TIdent _ -> true | _ -> false)
               ~followed_by_more:(function TComma _ :: _ -> true | _ -> false) ptr
@@ -2321,7 +2306,7 @@ let lookahead2 ~pass next before =
 
   (*  xx * yy)      AND in paramdecl *)
   | (TIdent (s, i1)::ptr , _)
-    when not_struct_enum before && (LP.current_context () =*= LP.InParameter)
+    when not_struct_enum before && (LP.current_context () = LP.InParameter)
 	&& ok_typedef s
 	&& pointer ~followed_by:(function TIdent _ -> true | _ -> false)
               ~followed_by_more:(function TCPar _ :: _ -> true | _ -> false) ptr
@@ -2370,7 +2355,7 @@ let lookahead2 ~pass next before =
   (*  xx ** yy *)  (* wrong ? *)
   | (TIdent (s, i1)::TMul _::TMul _::TIdent (s2, i2)::_ , _)
     when not_struct_enum before
-	&& (LP.current_context() =*= LP.InParameter)
+	&& (LP.current_context() = LP.InParameter)
 	&& ok_typedef s
     ->
 
@@ -2422,7 +2407,7 @@ let lookahead2 ~pass next before =
   | (TIdent (s, i1)::TCPar i2::(TIdent (_,i3)|TInt (_,i3))::_ ,
     (TOPar info)::x::_)
     when not (TH.is_stuff_taking_parenthized x) (* &&
-      Ast_c.line_of_info i2 =|= Ast_c.line_of_info i3 - why useful?
+      Ast_c.line_of_info i2 = Ast_c.line_of_info i3 - why useful?
       *)
       && ok_typedef s
       && not (ident x) (* possible K&R declaration *)
@@ -2545,7 +2530,7 @@ let lookahead2 ~pass next before =
         || (pass >= 2)
       then begin
 
-        if (LP.current_context () =*= LP.InInitializer)
+        if (LP.current_context () = LP.InInitializer)
         then begin
           pr2_cpp "In Initializer passing"; (* cheat: don't count in stat *)
           incr Stat.nIfdefInitializer;
@@ -2588,7 +2573,7 @@ let lookahead2 ~pass next before =
     * when the token contains "for_each".
     *)
   | (TIdent (s, i1)::TOPar _::rest, _)
-     when not (LP.current_context () =*= LP.InTopLevel)
+     when not (LP.current_context () = LP.InTopLevel)
       (* otherwise a function such as static void loopback_enable(int i) {
        * will be considered as a loop
        *)
@@ -2632,7 +2617,7 @@ let is_ifdef_and_same_tag (tag : Ast_c.matching_tag)
                           :bool
   = match x with
   | IfdefStmt (IfdefDirective ((_, tag2),_)) ->
-      tag =*= tag2
+      tag = tag2
   | StmtElem _ | CppDirectiveStmt _ -> false
   | IfdefStmt2 _ -> raise (Impossible 77)
 
