@@ -48,6 +48,11 @@ val filter_cpp_stuff :
 val insert_virtual_positions:
   Parser_c.token list -> Parser_c.token list
 
+(* mark suppported undisciplined uses of #ifdef *)
+val fix_tokens_ifdef : Parser_c.token list -> Parser_c.token list
+
+(* expand format strings *)
+val fix_tokens_strings : Parser_c.token list -> Parser_c.token list
 
 (* will among other things interally call cpp_token_c to macro
  * expand some macros *)
@@ -55,14 +60,11 @@ val fix_tokens_cpp :
   macro_defs:(string, Cpp_token_c.define_def) Hashtbl.t ->
   Parser_c.token list -> Parser_c.token list
 
-
 (* next stream tokens -> passed stream tokens -> final next token *)
 val lookahead :
   pass:int ->
   Parser_c.token list -> Parser_c.token list -> Parser_c.token
 
-
-
 (* ------------------------------------------------------------------------ *)
 (* Parsing hack helpers related to #define or #include *)
 (* ------------------------------------------------------------------------ *)
@@ -80,3 +82,10 @@ val tokens_include:
   Ast_c.info * string * string * bool ref ->
   Parser_c.token * Parser_c.token list
 
+(* ------------------------------------------------------------------------ *)
+(* Parsing hack helpers related to #ifdef *)
+(* ------------------------------------------------------------------------ *)
+
+(* #ifdef *)
+val cpp_ifdef_statementize:
+  Ast_c.program -> Ast_c.program
