@@ -59,7 +59,7 @@ let rec find_next_synchro ~next ~already_passed =
 
   let last_round = List.rev already_passed in
   if is_defined_passed_bis last_round
-  then find_next_synchro_define (last_round ++ next) []
+  then find_next_synchro_define (last_round @ next) []
   else
 
   let (before, after) =
@@ -73,7 +73,7 @@ let rec find_next_synchro ~next ~already_passed =
       | _ -> true
     )
   in
-  find_next_synchro_orig (after ++ next)  (List.rev before)
+  find_next_synchro_orig (after @ next)  (List.rev before)
 
 
 
@@ -83,7 +83,7 @@ and find_next_synchro_define next already_passed =
       pr2_err "ERROR-RECOV: end of file while in recovery mode";
       already_passed, []
   | (Parser_c.TDefEOL i as v)::xs  ->
-      pr2_err ("ERROR-RECOV: found sync end of #define, line "^i_to_s(TH.line_of_tok v));
+      pr2_err ("ERROR-RECOV: found sync end of #define, line "^string_of_int(TH.line_of_tok v));
       v::already_passed, xs
   | v::xs ->
       find_next_synchro_define xs (v::already_passed)
@@ -97,11 +97,11 @@ and find_next_synchro_orig next already_passed =
       pr2_err "ERROR-RECOV: end of file while in recovery mode";
       already_passed, []
 
-  | (Parser_c.TCBrace i as v)::xs when TH.col_of_tok v =|= 0 ->
-      pr2_err ("ERROR-RECOV: found sync '}' at line "^i_to_s (TH.line_of_tok v));
+  | (Parser_c.TCBrace i as v)::xs when TH.col_of_tok v = 0 ->
+      pr2_err ("ERROR-RECOV: found sync '}' at line "^string_of_int (TH.line_of_tok v));
 
       (match xs with
-      | [] -> raise Impossible (* there is a EOF token normally *)
+      | [] -> raise (Impossible 94) (* there is a EOF token normally *)
 
       (* still useful: now parser.mly allow empty ';' so normally no pb *)
       | Parser_c.TPtVirg iptvirg::xs ->
@@ -116,9 +116,9 @@ and find_next_synchro_orig next already_passed =
       | Parser_c.TCommentSpace sp::Parser_c.TIdent x::Parser_c.TPtVirg iptvirg
         ::xs ->
           pr2_err "ERROR-RECOV: found sync bis, eating ident, }, and ;";
+          (Parser_c.TPtVirg iptvirg)::
+          (Parser_c.TIdent x)::
           (Parser_c.TCommentSpace sp)::
-            (Parser_c.TPtVirg iptvirg)::
-            (Parser_c.TIdent x)::
             v::
             already_passed,
           xs
@@ -126,9 +126,9 @@ and find_next_synchro_orig next already_passed =
       | Parser_c.TCommentNewline sp::Parser_c.TIdent x::Parser_c.TPtVirg iptvirg
         ::xs ->
           pr2_err "ERROR-RECOV: found sync bis, eating ident, }, and ;";
+          (Parser_c.TPtVirg iptvirg)::
+          (Parser_c.TIdent x)::
           (Parser_c.TCommentNewline sp)::
-            (Parser_c.TPtVirg iptvirg)::
-            (Parser_c.TIdent x)::
             v::
             already_passed,
           xs
@@ -136,8 +136,8 @@ and find_next_synchro_orig next already_passed =
       | _ ->
           v::already_passed, xs
       )
-  | v::xs when TH.col_of_tok v =|= 0 && TH.is_start_of_something v  ->
-      pr2_err ("ERROR-RECOV: found sync col 0 at line "^ i_to_s(TH.line_of_tok v));
+  | v::xs when TH.col_of_tok v = 0 && TH.is_start_of_something v  ->
+      pr2_err ("ERROR-RECOV: found sync col 0 at line "^ string_of_int(TH.line_of_tok v));
       already_passed, v::xs
 
   | v::xs ->
