@@ -81,7 +81,7 @@ let print_parsing_stat_list ?(verbose=false) = fun statxs ->
       | _ -> false)
     +> List.iter (function
         {filename = file; have_timeout = timeout; bad = n} ->
-          pr (file ^ "  " ^ (if timeout then "TIMEOUT" else i_to_s n));
+          pr (file ^ "  " ^ (if timeout then "TIMEOUT" else string_of_int n));
         );
 
   pr "\n\n\n";
@@ -93,22 +93,22 @@ let print_parsing_stat_list ?(verbose=false) = fun statxs ->
       | _ -> false)
     +> List.iter (function
         {filename = file; commentized = n} ->
-          pr (file ^ "  " ^ (i_to_s n));
+          pr (file ^ "  " ^ (string_of_int n));
         );
 
   pr "\n\n\n---------------------------------------------------------------";
   end;
 
   pr (
-  (sprintf "NB total files = %d; " total) ^
-  (sprintf "perfect = %d; " perfect) ^
-  (sprintf "pbs = %d; "     (statxs +> List.filter (function
+  (Printf.sprintf "NB total files = %d; " total) ^
+  (Printf.sprintf "perfect = %d; " perfect) ^
+  (Printf.sprintf "pbs = %d; "     (statxs +> List.filter (function
       {have_timeout = b; bad = n} when n > 0 -> true | _ -> false)
                                +> List.length)) ^
-  (sprintf "timeout = %d; " (statxs +> List.filter (function
+  (Printf.sprintf "timeout = %d; " (statxs +> List.filter (function
       {have_timeout = true; bad = n} -> true | _ -> false)
                                +> List.length)) ^
-  (sprintf "=========> %d" ((100 * perfect) / total)) ^ "%"
+  (Printf.sprintf "=========> %d" ((100 * perfect) / total)) ^ "%"
 
   );
   let good = statxs +> List.fold_left (fun acc {correct = x} -> acc+x) 0 in
@@ -117,13 +117,15 @@ let print_parsing_stat_list ?(verbose=false) = fun statxs ->
   in
   let gf, badf = float_of_int good, float_of_int bad in
   let passedf = float_of_int passed in
+  let total = gf +. badf +. passedf in
   pr (
-  (sprintf "nb good = %d,  nb passed = %d " good passed) ^
-  (sprintf "=========> %f"  (100.0 *. (passedf /. gf)) ^ "% passed")
+  (Printf.sprintf "nb good = %d,  nb passed = %d " good passed) ^
+  (Printf.sprintf "=========> %2.2f"  (100.0 *. (passedf /. total)) ^ "% passed")
    );
   pr (
-  (sprintf "nb good = %d,  nb bad = %d " good bad) ^
-  (sprintf "=========> %f"  (100.0 *. (gf /. (gf +. badf))) ^ "% good"
+  (Printf.sprintf "nb good = %d,  nb bad = %d " good bad) ^
+  (Printf.sprintf "=========> %2.2f"
+     (100.0 *. ((gf +. passedf) /. total)) ^ "% good or passed"
    )
   )
 
@@ -214,6 +216,7 @@ let nIfdefExprPassing = ref 0
 let nIfdefPassing = ref 0
 
 let nIncludePassing = ref 0
+let nUndefPassing = ref 0
 let nDefinePassing = ref 0
 
 let nIfdefZero = ref 0
@@ -250,7 +253,7 @@ let nDefineInit = ref 0
 let nDefineOther = ref 0
 
 let nUndef = ref 0
-let nPragmaAndCo = ref 0
+let nOtherDirective = ref 0
 
 (* let nDirectiveTop = ref 0 *)
 let nDirectiveStmt = ref 0
@@ -293,6 +296,7 @@ let assoc_stat_number =
 
     "nIncludePassing", nIncludePassing;
     "nDefinePassing", nDefinePassing;
+    "nUndefPassing", nUndefPassing;
 
     "nMacroExpand", nMacroExpand;
     "nMacroHint", nMacroHint;
@@ -323,7 +327,7 @@ let assoc_stat_number =
     "nDefineOther", nDefineOther;
 
     "nUndef", nUndef;
-    "nPragmaAndCo", nPragmaAndCo;
+    "nOtherDirective", nOtherDirective;
 
     "nDirectiveStmt", nDirectiveStmt;
     "nDirectiveStruct", nDirectiveStruct;
