@@ -42,6 +42,7 @@ type pretty_printers = {
   arg_list        : (Ast_c.argument Ast_c.wrap2 list) printer;
   arg             : Ast_c.argument printer;
   statement       : Ast_c.statement printer;
+  statement_seq_list : Ast_c.statement_sequencable list printer;
   decl            : Ast_c.declaration printer;
   field           : Ast_c.field printer;
   field_list      : Ast_c.field list printer;
@@ -167,13 +168,23 @@ let mk_pretty_printers
 	pr_elem i1; pr_elem i2; pp_arg_list ts; pr_elem i3; pp_argument t
     | Delete(t),     [i1] -> pr_elem i1; pp_expression t
 
+    | Defined name, [i1] ->
+        pr_elem i1; (* defined *)
+        pp_name name;
+    | Defined name, [i1;i2;i3] ->
+        pr_elem i1; (* defined *)
+        pr_elem i2; (* ( *)
+        pp_name name;
+        pr_elem i3; (* ) *)
+
     | (Ident (_) | Constant _ | StringConstant _ | FunCall (_,_)
     | CondExpr (_,_,_) | Sequence (_,_) | Assignment (_,_,_)
     | Postfix (_,_) | Infix (_,_) | Unary (_,_) | Binary (_,_,_)
     | ArrayAccess (_,_) | RecordAccess (_,_) | RecordPtAccess (_,_)
     | SizeOfExpr (_) | SizeOfType (_) | Cast (_,_)
     | StatementExpr (_) | Constructor _
-    | ParenExpr (_) | New (_) | Delete (_)),_ -> raise (Impossible 95)
+    | ParenExpr (_) | New (_) | Delete (_)
+    | Defined (_)),_ -> raise (Impossible 95)
     );
 
     if !Flag_parsing_c.pretty_print_type_info
@@ -250,6 +261,10 @@ and pp_string_format (e,ii) =
       pr_elem i
 
 (* ---------------------- *)
+
+  and pp_statement_seq_list statxs =
+    statxs +> Common.print_between pr_nl pp_statement_seq
+
   and pp_statement = fun st ->
     match Ast_c.get_st_and_ii st with
     | Labeled (Label (name, st)), ii ->
@@ -268,8 +283,7 @@ and pp_string_format (e,ii) =
 	pr_unindent(); pr_elem i1; pr_elem i2; pr_nl(); pr_indent();
 	pp_statement st
     | Compound statxs, [i1;i2] ->
-        pr_elem i1; start_block();
-        statxs +> Common.print_between pr_nl pp_statement_seq;
+        pr_elem i1; start_block(); pp_statement_seq_list statxs;
         end_block(); pr_elem i2;
 
     | ExprStatement (None), [i] -> pr_elem i;
@@ -322,7 +336,7 @@ and pp_string_format (e,ii) =
               pp_statement (Ast_c.mk_st (ExprStatement e1opt) il1)
 	  | ForDecl decl -> pp_decl decl);
           pp_statement (Ast_c.mk_st (ExprStatement e2opt) il2);
-          assert (null il3);
+          assert (il3 = []);
           pp_statement (Ast_c.mk_st (ExprStatement e3opt) il3);
           pr_elem i3;
           indent_if_needed st (function _ -> pp_statement st);
@@ -366,7 +380,7 @@ and pp_string_format (e,ii) =
         )
 
     | NestedFunc def, ii ->
-        assert (null ii);
+        assert (ii = []);
         pp_def def
     | MacroStmt, ii ->
         ii +> List.iter pr_elem ;
@@ -500,14 +514,14 @@ and pp_string_format (e,ii) =
         | None -> [] | Some (s, iis) -> (*assert (List.length iis = 1);*) iis
       in
       let print_sto_qu (sto, (qu, iiqu)) =
-        let all_ii = get_sto sto ++ iiqu in
+        let all_ii = get_sto sto @ iiqu in
         all_ii
           +> List.sort Ast_c.compare_pos
           +> Common.print_between pr_space pr_elem
 
       in
       let print_sto_qu_ty (sto, (qu, iiqu), iity) =
-        let all_ii = get_sto sto ++ iiqu ++ iity in
+        let all_ii = get_sto sto @ iiqu @ iity in
         let all_ii2 = all_ii +> List.sort Ast_c.compare_pos in
 
         if all_ii <> all_ii2
@@ -588,22 +602,22 @@ and pp_string_format (e,ii) =
           print_sto_qu_ty (sto, qu, iis);
 
       | (StructUnionName (s, structunion), iis) ->
-          assert (List.length iis =|= 2);
+          assert (List.length iis = 2);
           print_sto_qu_ty (sto, qu, iis);
 
       | (EnumName  s, iis) ->
-          assert (List.length iis =|= 2);
+          assert (List.length iis = 2);
           print_sto_qu_ty (sto, qu, iis);
 
       | (Decimal(l,p), [dec;lp;cm;rp]) ->
 	  (* hope that sto before qu is right... cf print_sto_qu_ty *)
-	  let stoqulp = get_sto sto ++ (snd qu) ++ [dec] in
+	  let stoqulp = get_sto sto @ (snd qu) @ [dec] in
 	  Common.print_between pr_space pr_elem stoqulp;
 	  pr_elem lp; pp_expression l; pr_elem cm;
 	  do_option pp_expression p; pr_elem rp
 
       | (TypeName (name,typ), noii) ->
-          assert (null noii);
+          assert (noii = []);
           let (_s, iis) = get_s_and_info_of_name name in
           print_sto_qu_ty (sto, qu, [iis]);
 
@@ -655,7 +669,7 @@ and pp_string_format (e,ii) =
 	    (match x with
 	      (Simple (nameopt, typ)), iivirg ->
               (* first var cannot have a preceding ',' *)
-		assert (List.length iivirg =|= 0);
+		assert (List.length iivirg = 0);
 		let identinfo =
                   match nameopt with
 		  | None -> None
@@ -665,7 +679,7 @@ and pp_string_format (e,ii) =
 
 	    | (BitField (nameopt, typ, iidot, expr)), iivirg ->
                       (* first var cannot have a preceding ',' *)
-		assert (List.length iivirg =|= 0);
+		assert (List.length iivirg = 0);
 		(match nameopt with
 		| None ->
 		    pp_type typ;
@@ -975,7 +989,7 @@ and pp_string_format (e,ii) =
 	  }, iivirg) ->
 
             let (s,iis) = get_s_and_info_of_name name in
-	    assert (storage2 =*= storage);
+	    assert (storage2 = storage);
 	    iivirg +> List.iter pr_elem;
 	    pp_type_with_ident_rest
 	      (Some (s, iis)) returnType attrs;
@@ -992,7 +1006,7 @@ and pp_string_format (e,ii) =
 
 	pr_elem iivirg;
 
-    | MacroDecl ((s, es, true), iis::lp::rp::iiend::ifakestart::iisto) ->
+    | MacroDecl ((sto, s, es, true), iis::lp::rp::iiend::ifakestart::iisto) ->
 	pr_elem ifakestart;
 	iisto +> List.iter pr_elem; (* static and const *)
 	pr_elem iis;
@@ -1006,7 +1020,7 @@ and pp_string_format (e,ii) =
 	pr_elem rp;
 	pr_elem iiend;
 
-    | MacroDecl ((s, es, false), iis::lp::rp::ifakestart::iisto) ->
+    | MacroDecl ((sto, s, es, false), iis::lp::rp::ifakestart::iisto) ->
 	pr_elem ifakestart;
 	iisto +> List.iter pr_elem; (* static and const *)
 	pr_elem iis;
@@ -1020,7 +1034,7 @@ and pp_string_format (e,ii) =
 	pr_elem rp;
 
     | MacroDeclInit
-	((s, es, ini), iis::lp::rp::eq::iiend::ifakestart::iisto) ->
+	((sto, s, es, ini), iis::lp::rp::eq::iiend::ifakestart::iisto) ->
 	pr_elem ifakestart;
 	iisto +> List.iter pr_elem; (* static and const *)
 	pr_elem iis;
@@ -1124,8 +1138,8 @@ and pp_init (init, iinit) =
 		 | qu, (BaseType Void, ii) -> true
 		 | _ -> true
 	       );
-               assert (null iicomma);
-               assert (null ii_b_s);
+               assert (iicomma = []);
+               assert (ii_b_s = []);
                pp_type_with_ident None None t
 
            | paramst ->
@@ -1158,7 +1172,7 @@ and pp_init (init, iinit) =
 
         pr_elem iifunc2; pr_space();
         pr_elem i1;
-        statxs +> List.iter pp_statement_seq;
+	pp_statement_seq_list statxs;
         pr_elem i2;
     | _ -> raise (Impossible 118)
 
@@ -1286,7 +1300,7 @@ and pp_init (init, iinit) =
                      f_body = body;
                      f_attr = attrs},ii) ->
 
-		       assert(null body);
+		       assert (body = []);
       (*
 	 iif ii;
 	 iif iidotsb;
@@ -1463,6 +1477,7 @@ and pp_init (init, iinit) =
     arg_list   = pp_arg_list;
     arg        = pp_argument;
     statement  = pp_statement;
+    statement_seq_list = pp_statement_seq_list;
     decl       = pp_decl;
     field      = pp_field;
     field_list = pp_field_list;
@@ -1526,6 +1541,7 @@ let pp_binaryOp_simple   = ppc.binaryOp
 let pp_decl_simple       = ppc.decl
 let pp_field_simple      = ppc.field
 let pp_statement_simple  = ppc.statement
+let pp_statement_seq_list_simple  = ppc.statement_seq_list
 let pp_type_simple       = ppc.ty
 let pp_init_simple       = ppc.init
 let pp_toplevel_simple   = ppc.toplevel
@@ -1557,6 +1573,9 @@ let pp_arg_gen ~pr_elem ~pr_space =
 let pp_statement_gen ~pr_elem ~pr_space =
   (pp_elem_sp pr_elem pr_space).statement
 
+let pp_statement_seq_list_gen ~pr_elem ~pr_space =
+  (pp_elem_sp pr_elem pr_space).statement_seq_list
+
 let pp_decl_gen ~pr_elem ~pr_space =
   (pp_elem_sp pr_elem pr_space).decl
 
@@ -1620,4 +1639,3 @@ let (debug_info_of_node:
     ) in
     let pos = Lib_parsing_c.min_pinfo_of_node node in
     (spf "%s(n%d)--> %s" (Common.string_of_parse_info_bis pos) nodei s)
-
