@@ -24,6 +24,101 @@ let test_tokens_c file =
   ()
 
 
+(* ---------------------------------------------------------------------- *)
+
+(* Was in main, but using it in test_parsing_c *)
+let get_files path =
+  if !Flag.c_plus_plus
+  then
+    (* only C++ files, but contains .h files as that extension is ambiguous *)
+    cmd_to_list
+      (if !Flag.include_headers
+      then
+        "find "^ path ^" -name \"*.cpp\" -o -name \"*.cxx\" -o -name \"*.cc\""
+        ^"-o name \"*.h\" -o -name \"*.hpp\" -o -name \"*.hxx\""
+      else
+        "find "^ path ^" -name \"*.cpp\" -o -name \"*.cxx\" -o -name \"*.cc\"")
+  else
+    (* only .c files and .h files *)
+    cmd_to_list (* same as "true, "", _" case *)
+      (if !Flag.include_headers
+	  (* FIXME : Could we remove xs ?
+	     -use_glimpse requires a singleton.
+	     This is checked some lines before.
+	     then ("find "^(join " " (x::xs))^" -name \"*.[ch]\"")
+	     else ("find "^(join " " (x::xs))^" -name \"*.c\"")
+	  *)
+      then ("find "^ path ^" -name \"*.[ch]\"")
+      else ("find "^ path ^" -name \"*.c\""))
+
+let new_test_parse_gen xs =
+
+  Flag_parsing_c.debug_typedef := true;
+  Flag_parsing_c.debug_cpp := true;
+  Flag_parsing_c.debug_etdt := false;
+  Flag_parsing_c.filter_msg := true;
+
+  (*let dirname_opt =
+    match xs with
+    | [x] when is_directory x -> Some x
+    | _ -> None
+  in*)
+
+  (* old:
+     let xs = if !Flag.dir then
+     process_output_to_list ("find " ^ x ^" -name \"*.c\"") else x::xs in
+  *)
+  let fullxs = xs +> List.map get_files +> List.concat in
+
+  let stat_list = ref [] in
+  let newscore  = Common.empty_score () in
+
+  Common.check_stack_nbfiles (List.length fullxs);
+
+  fullxs +> List.iter (fun file ->
+
+    pr2 "";
+    pr2 ("PARSING: " ^ file);
+
+    (* test parsing of format strings as well *)
+    let (xs, stat) = Parse_c.parse_c_and_cpp true file in
+    xs +> List.iter (fun (ast, (s, toks)) ->
+      Parse_c.print_commentized toks
+    );
+
+    Common.push2 stat stat_list;
+    let s =
+      Printf.sprintf "bad = %d, timeout = %B"
+        stat.Parsing_stat.bad stat.Parsing_stat.have_timeout
+    in
+    if stat.Parsing_stat.bad = 0 && not stat.Parsing_stat.have_timeout
+    then Hashtbl.add newscore file (Common.Ok)
+    else Hashtbl.add newscore file (Common.Pb s)
+  );
+
+(* uses an explicit path; to fix
+  dirname_opt +> Common.do_option (fun dirname ->
+    pr2_xxxxxxxxxxxxxxxxx();
+    pr2 "regression testing  information";
+    pr2_xxxxxxxxxxxxxxxxx();
+    let str = Str.global_replace (Str.regexp "/") "__" dirname in
+    let def = if !Flag_parsing_c.filter_define_error then "_def_" else "" in
+    let ext = if ext = "c" then "" else ext in
+    let filename = "score_parsing__" ^str ^ def ^ ext ^ ".marshalled" in
+    if Sys.file_exists filename
+    then
+      Common.regression_testing newscore
+	(Filename.concat score_path
+	   ("score_parsing__" ^str ^ def ^ ext ^ ".marshalled"))
+  );
+*)
+
+  if !stat_list <> []
+  then begin
+    Parsing_stat.print_recurring_problematic_tokens !stat_list;
+    Parsing_stat.print_parsing_stat_list !stat_list;
+  end;
+  ()
 
 (* ---------------------------------------------------------------------- *)
 let test_parse_gen xs ext =
@@ -58,17 +153,18 @@ let test_parse_gen xs ext =
     pr2 "";
     pr2 ("PARSING: " ^ file);
 
-    let (xs, stat) = Parse_c.parse_c_and_cpp file in
+    (* test parsing of format strings as well *)
+    let (xs, stat) = Parse_c.parse_c_and_cpp true file in
     xs +> List.iter (fun (ast, (s, toks)) ->
       Parse_c.print_commentized toks
     );
 
     Common.push2 stat stat_list;
     let s =
-      sprintf "bad = %d, timeout = %B"
+      Printf.sprintf "bad = %d, timeout = %B"
         stat.Parsing_stat.bad stat.Parsing_stat.have_timeout
     in
-    if stat.Parsing_stat.bad =|= 0 && not stat.Parsing_stat.have_timeout
+    if stat.Parsing_stat.bad = 0 && not stat.Parsing_stat.have_timeout
     then Hashtbl.add newscore file (Common.Ok)
     else Hashtbl.add newscore file (Common.Pb s)
   );
@@ -80,7 +176,7 @@ let test_parse_gen xs ext =
     pr2_xxxxxxxxxxxxxxxxx();
     let str = Str.global_replace (Str.regexp "/") "__" dirname in
     let def = if !Flag_parsing_c.filter_define_error then "_def_" else "" in
-    let ext = if ext =$= "c" then "" else ext in
+    let ext = if ext = "c" then "" else ext in
     let filename = "score_parsing__" ^str ^ def ^ ext ^ ".marshalled" in
     if Sys.file_exists filename
     then
@@ -90,7 +186,7 @@ let test_parse_gen xs ext =
   );
 *)
 
-  if not (null !stat_list)
+  if !stat_list <> []
   then begin
     Parsing_stat.print_recurring_problematic_tokens !stat_list;
     Parsing_stat.print_parsing_stat_list !stat_list;
@@ -119,7 +215,7 @@ let test_parse_i xs =
 
 (* ---------------------------------------------------------------------- *)
 (* file can be   "foo.c"  or "foo.c:main" *)
-(* local function that is parameterized by whether to launch gv *)
+(* local function that is parametrized by whether to launch gv *)
 let local_test_cfg launchgv file =
   let (file, specific_func) =
     if file =~ "\\(.*\\.c\\):\\(.*\\)"
@@ -133,7 +229,8 @@ let local_test_cfg launchgv file =
   if not (file =~ ".*\\.c")
   then pr2 "warning: seems not a .c file";
 
-  let (program, _stat) = Parse_c.parse_c_and_cpp file in
+  (* no point to parse format strings *)
+  let (program, _stat) = Parse_c.parse_c_and_cpp false file in
 
   program +> List.iter (fun (e,_) ->
     let toprocess =
@@ -142,7 +239,7 @@ let local_test_cfg launchgv file =
 	  Some (Ast_c.str_of_name (defbis.Ast_c.f_name))
       | Some s, Ast_c.Definition (defbis,_)  ->
 	  let nm = Ast_c.str_of_name (defbis.Ast_c.f_name) in
-          if s =$= nm then Some nm else None
+          if s = nm then Some nm else None
       | _, _ -> None
     in
 
@@ -167,7 +264,7 @@ let local_test_cfg launchgv file =
 	      if launchgv
 	      then Filename.temp_file "output" ".dot"
 	      else
-		let fl = Filename.chop_extension (Filename.basename file) in 
+		let fl = Filename.chop_extension (Filename.basename file) in
 		fl^":"^fn^".dot" in
             Ograph_extended.print_ograph_mutable flow' (filename) launchgv
           )
@@ -179,11 +276,11 @@ let test_cfg = local_test_cfg true
 
 
 let test_cfg_ifdef file =
-  let (ast2, _stat) = Parse_c.parse_c_and_cpp file in
+  Flag_parsing_c.ifdef_to_if := true;
+  (* no point to parse format strings *)
+  let (ast2, _stat) = Parse_c.parse_c_and_cpp false file in
   let ast = Parse_c.program_of_program2 ast2 in
 
-  let ast = Cpp_ast_c.cpp_ifdef_statementize ast in
-
   ast +> List.iter (fun e ->
     (try
         let flow = Ast_to_flow.ast_to_control_flow e in
@@ -201,7 +298,8 @@ let test_parse_unparse infile =
   if not (infile =~ ".*\\.c")
   then pr2 "warning: seems not a .c file";
 
-  let (program2, _stat) = Parse_c.parse_c_and_cpp infile in
+  (* test parsing of format strings *)
+  let (program2, _stat) = Parse_c.parse_c_and_cpp true infile in
   let program2_with_ppmethod =
     program2 +> List.map (fun x -> x, Unparse_c.PPnormal)
   in
@@ -238,7 +336,8 @@ let test_type_c infile =
 
   Flag_parsing_c.pretty_print_type_info := true;
 
-  let (program2, _stat) =  Parse_c.parse_c_and_cpp infile in
+  (* no point to parse format strings *)
+  let (program2, _stat) =  Parse_c.parse_c_and_cpp false infile in
   let _program2 =
     program2
     +> Common.unzip
@@ -260,7 +359,8 @@ let test_type_c infile =
 (* ---------------------------------------------------------------------- *)
 (* ex: demos/platform_ifdef.c *)
 let test_comment_annotater infile =
-  let (program2, _stat) =  Parse_c.parse_c_and_cpp infile in
+  (* no point to parse format strings *)
+  let (program2, _stat) =  Parse_c.parse_c_and_cpp false infile in
   let asts = program2 +> List.map (fun (ast,_) -> ast) in
   let toks = program2 +> List.map (fun (ast, (s, toks)) -> toks) +>
     List.flatten in
@@ -312,7 +412,8 @@ let test_compare_c_hardcoded () =
 
 (* ---------------------------------------------------------------------- *)
 let test_attributes file =
-  let (ast2, _stat) = Parse_c.parse_c_and_cpp file in
+  (* no point to parse format strings *)
+  let (ast2, _stat) = Parse_c.parse_c_and_cpp false file in
   let ast = Parse_c.program_of_program2 ast2 in
 
   Visitor_c.vk_program { Visitor_c.default_visitor_c with
@@ -342,16 +443,17 @@ let test_attributes file =
 
 let cpp_options () = [
   Cpp_ast_c.I "/home/yyzhou/pad/linux/include";
-] ++
+] @
   Cpp_ast_c.cpp_option_of_cmdline
   (!Flag_parsing_c.cpp_i_opts,!Flag_parsing_c.cpp_d_opts)
 
 let test_cpp file =
-  let (ast2, _stat) = Parse_c.parse_c_and_cpp file in
+  Flag_parsing_c.ifdef_to_if := true;
+  (* no point to parse format strings *)
+  let (ast2, _stat) = Parse_c.parse_c_and_cpp false file in
   let dirname = Filename.dirname file in
   let ast = Parse_c.program_of_program2 ast2 in
-  let ast = Cpp_ast_c.cpp_expand_include (cpp_options()) dirname ast in
-  let _ast = Cpp_ast_c.cpp_ifdef_statementize ast in
+  let _ast = Cpp_ast_c.cpp_expand_include (cpp_options()) dirname ast in
 
 
   ()
@@ -439,7 +541,8 @@ let test_parse xs =
     pr2 "";
     pr2 ("PARSING: " ^ file);
 
-    let (xs, stat) = Parse_c.parse_c_and_cpp file in
+    (* test parsing of format strings *)
+    let (xs, stat) = Parse_c.parse_c_and_cpp true file in
     xs +> List.iter (fun (ast, (s, toks)) ->
       Parse_c.print_commentized toks
     );
@@ -447,7 +550,7 @@ let test_parse xs =
     Common.push2 stat stat_list;
   );
 
-  if not (null !stat_list)
+  if !stat_list <> []
   then begin
     Parsing_stat.print_recurring_problematic_tokens !stat_list;
     Parsing_stat.print_parsing_stat_list !stat_list;
@@ -483,55 +586,56 @@ let test_xxx a  =
 (*****************************************************************************)
 
 let actions () = [
-  "-tokens_c", "   <file>",
+  "--tokens-c", "   <file>",
   Common.mk_action_1_arg test_tokens_c;
-  "-parse_c", "   <file or dir>",
+  "--parse-c", "   <file or dir>",
   Common.mk_action_n_arg test_parse_c;
-  "-parse_h", "   <file or dir>",
+  "--parse-h", "   <file or dir>",
   Common.mk_action_n_arg test_parse_h;
-  "-parse_ch", "   <file or dir>",
+  "--parse-ch", "   <file or dir>",
   Common.mk_action_n_arg test_parse_ch;
-  "-parse_i", "   <file or dir>",
+  "--parse-i", "   <file or dir>",
   Common.mk_action_n_arg test_parse_i;
+  "--parse-c++", "   <file or dir>",
+  Common.mk_action_n_arg new_test_parse_gen;
 
-  "-parse", "   <file or dir>",
+  "--parse", "   <file or dir>",
   Common.mk_action_n_arg test_parse;
 
-  "-show_flow", "   <file or file:function>",
+  "--show-flow", "   <file or file:function>",
   Common.mk_action_1_arg (local_test_cfg true);
-  "-control_flow", "   <file or file:function>",
+  "--control-flow", "   <file or file:function>",
   Common.mk_action_1_arg (local_test_cfg true);
-  "-control_flow_to_file", "   <file or file:function>",
+  "--control-flow-to-file", "   <file or file:function>",
   Common.mk_action_1_arg (local_test_cfg false);
-  "-test_cfg_ifdef", " <file>",
+  "--test-cfg-ifdef", " <file>",
   Common.mk_action_1_arg test_cfg_ifdef;
-  "-parse_unparse", "   <file>",
+  "--parse-unparse", "   <file>",
   Common.mk_action_1_arg test_parse_unparse;
-(*  "-parse_and_print_sexp", "   <file>",
+(*  "--parse-and-print-sexp", "   <file>",
     Common.mk_action_1_arg parse_and_print_sexp;*)
-  "-type_c", "   <file>",
+  "--type-c", "   <file>",
   Common.mk_action_1_arg test_type_c;
-  "-compare_c", "   <file1> <file2>",
+  "--compare-c", "   <file1> <file2>",
   Common.mk_action_2_arg test_compare_c (* result is in unix code *);
-  "-comment_annotater_c", "   <file>",
+  "--comment-annotater-c", "   <file>",
   Common.mk_action_1_arg test_comment_annotater;
 
-  "-compare_c_hardcoded", "  ",
+  "--compare-c-hardcoded", "  ",
   Common.mk_action_0_arg test_compare_c_hardcoded;
 
-  "-test_attributes", " <file>",
+  "--test-attributes", " <file>",
   Common.mk_action_1_arg test_attributes;
-  "-test_cpp", " <file>",
+  "--test-cpp", " <file>",
   Common.mk_action_1_arg test_cpp;
 
-  "-extract_macros", " <file or dir>",
+  "--extract-macros", " <file or dir>",
   Common.mk_action_1_arg (extract_macros ~selection:false) ;
 
-  "-extract_macros_select", " <file or dir>",
+  "--extract-macros-select", " <file or dir>",
   Common.mk_action_1_arg (extract_macros ~selection:true);
 
 
-  "-xxx", "   <file1> <>",
+  "--xxx", "   <file1> <>",
   Common.mk_action_n_arg test_xxx;
 ]
-
