@@ -84,10 +84,12 @@ let mk_fulltype bt str =
     Ast_c.cocci_tag =
      {contents =
        Some (Ast_cocci.CONTEXT (Ast_cocci.NoPos, Ast_cocci.NOTHING), [])};
+    Ast_c.annots_tag = Token_annot.empty;
     Ast_c.comments_tag = {contents =
         {Ast_c.mbefore = []; Ast_c.mafter = [];
          Ast_c.mbefore2 = []; Ast_c.mafter2 = []
-        }}}]
+        }};
+    Ast_c.danger = ref Ast_c.NoDanger;}]
 
 let (int_type: Ast_c.fullType) =
   (* Lib_parsing_c.al_type   (Parse_c.type_of_string "int")*)
@@ -106,6 +108,7 @@ let rec is_completed_and_simplified ty =
   | BaseType x  -> true
   | Pointer t -> is_completed_and_simplified t
   | Array (e, t) -> is_completed_and_simplified t
+  | Decimal (len, prec_opt) -> true
   | StructUnion (su, sopt, fields) ->
       (* recurse fields ? Normally actually don't want,
        * prefer to have a StructUnionName when it's possible *)
@@ -205,9 +208,9 @@ let structdef_to_struct_name ty =
           qu, Ast_c.mk_tybis (StructUnionName (su, s)) [i1;i2]
       | None, _ ->
           ty
-      | x -> raise Impossible
+      | x -> raise (Impossible 126)
       )
-  | _ -> raise Impossible
+  | _ -> raise (Impossible 127)
 
 
 (*****************************************************************************)
@@ -233,7 +236,7 @@ let type_of_decl decl =
   match decl with
   | Ast_c.DeclList (xs,ii1) ->
       (match xs with
-      | [] -> raise Impossible
+      | [] -> raise (Impossible 128)
 
       (* todo? for other xs ? *)
       | (x,ii2)::xs ->
@@ -243,7 +246,7 @@ let type_of_decl decl =
           (* TODO normalize ? what if nested structure definition ? *)
           v_type
       )
-  | Ast_c.MacroDecl _ ->
+  | Ast_c.MacroDecl _ | Ast_c.MacroDeclInit _ ->
       pr2_once "not handling MacroDecl type yet";
       raise Todo
 
@@ -255,7 +258,7 @@ let structdef_of_decl decl =
   match decl with
   | Ast_c.DeclList (xs,ii1) ->
       (match xs with
-      | [] -> raise Impossible
+      | [] -> raise (Impossible 129)
 
       (* todo? for other xs ? *)
       | (x,ii2)::xs ->
@@ -265,10 +268,10 @@ let structdef_of_decl decl =
           (match Ast_c.unwrap_typeC v_type with
           | Ast_c.StructUnion (su, _must_be_some, fields) ->
               (su, fields)
-          | _ -> raise Impossible
+          | _ -> raise (Impossible 130)
           )
       )
-  | Ast_c.MacroDecl _ -> raise Impossible
+  | Ast_c.MacroDecl _ | Ast_c.MacroDeclInit _ -> raise (Impossible 131)
 
 
 
@@ -346,7 +349,7 @@ let lub op t1 t2 =
      * arithmetic are written with the pointer in the first position.
      *
      * Also when an expression contain a typedef, as in
-     * 'dma_addr + 1' where dma_addr was declared as a varialbe
+     * 'dma_addr + 1' where dma_addr was declared as a variable
      * of type dma_addr_t, then again I want to have in the lub
      * the typedef and it is often again in the first position.
      *
@@ -406,7 +409,8 @@ let lub op t1 t2 =
 	    Some t1
 	| Ast_c.Minus,Ast_c.BaseType(Ast_c.IntType _),Ast_c.Pointer _ ->
 	    Some t2
-	| Ast_c.Minus,Ast_c.Pointer _,Ast_c.Pointer _ ->
+	| Ast_c.Minus,(Ast_c.Pointer _ | Ast_c.Array _),
+	  (Ast_c.Pointer _ | Ast_c.Array _) ->
 	    Some ptr_diff_type
         (* todo, Pointer, Typedef, etc *)
         | _, _, _ -> Some t1
@@ -417,8 +421,6 @@ let lub op t1 t2 =
   | None -> None, Ast_c.NotTest
   | Some ft ->  Some (ft, Ast_c.NotLocalVar), Ast_c.NotTest
 
-
-
 (*****************************************************************************)
 (* type lookup *)
 (*****************************************************************************)
@@ -441,7 +443,7 @@ let (type_field:
             match fieldkind with
             | Simple (Some name, t) | BitField (Some name, t, _, _) ->
                 let s = Ast_c.str_of_name name in
-                if s =$= fld
+                if s = fld
                 then Common.push2 t res
                 else ()
 
@@ -526,5 +528,3 @@ let rec function_pointer_type_opt x =
       function_pointer_type_opt ft
 
   | _ -> None
-
-
