@@ -24,7 +24,7 @@ module TH = Token_helpers
 but not comments and directives within deleted terms.  should use the
 labels found in the control-flow graph *)
 
-
+let default_indent = ref "\t"
 
 (*****************************************************************************)
 (* Wrappers *)
@@ -54,7 +54,7 @@ type min =
   | Ctx
 
 type token2 =
-  | T2 of Parser_c.token * min 
+  | T2 of Parser_c.token * min
         * int option (* orig index, abstracting away comments and space *)
         * Unparse_cocci.nlhint option
   | Fake2 of Ast_c.info * min
@@ -74,7 +74,7 @@ type token3 =
 
 
 (* similar to the tech in parsing_hack *)
-type token_extended = 
+type token_extended =
   { tok2 : token2;
     str  : string;
     idx  : int option; (* to know if 2 tokens were consecutive in orig file *)
@@ -210,10 +210,10 @@ let remove_useless_fakeInfo_struct program =
       | Ast_c.InitList args, ii ->
         (match ii with
         | [_;_] -> ini
-        | i1 :: i2 :: iicommaopt :: tl when 
-           (not (contain_plus iicommaopt)) 
+        | i1 :: i2 :: iicommaopt :: tl when
+           (not (contain_plus iicommaopt))
         && (not (contain_plus i2))
-        && (Ast_c.is_fake iicommaopt) -> 
+        && (Ast_c.is_fake iicommaopt) ->
           (* sometimes the guy put a normal iicommaopt *)
           Ast_c.InitList args, (i1 :: i2 :: tl)
         | ii -> Ast_c.InitList args, ii
@@ -241,9 +241,9 @@ let get_fakeInfo_and_tokens celem toks =
       (* get the associated comments/space/cppcomment tokens *)
       let (before, x, after) =
         !toks_in +> split_when (fun tok ->
-          info =*= TH.info_of_tok tok)
+          info = TH.info_of_tok tok)
       in
-      assert(info =*= TH.info_of_tok x);
+      assert(info = TH.info_of_tok x);
       (*old: assert(before +> List.for_all (TH.is_comment)); *)
       before +> List.iter (fun x ->
         if not (TH.is_comment x)
@@ -265,23 +265,43 @@ let get_fakeInfo_and_tokens celem toks =
 
   Pretty_print_c.pp_program_gen pr_elem pr_space celem;
 
-  if not (null !toks_in)
+  if  (!toks_in <> [])
   then failwith "WEIRD: unparsing not finished";
 
   List.rev !toks_out
 
-(* Fake nodes that have BEFORE code or are - should be moved over any subsequent
-whitespace and newlines, but not any comments, to get as close to the affected
-code as possible.  Similarly, fake nodes that have AFTER code should be moved
-backwards.  No fake nodes should have both before and after code. *)
+(* Fake nodes that have BEFORE code or are - should be moved over any
+subsequent whitespace and newlines, but not any comments starting in column
+0 or the last newline, to get as close to the affected code as possible.
+Similarly, fake nodes that have AFTER code should be moved backwards.  No
+fake nodes should have both before and after code. *)
 
 let displace_fake_nodes toks =
   let is_fake = function Fake1 _ -> true | _ -> false in
-  let is_whitespace = function
+  let is_whitespace_or_noncol0_comment = function
     | T1(Parser_c.TCommentSpace _)
   (* patch: cocci    *)
     | T1(Parser_c.TCommentNewline _) -> true
+    | T1(Parser_c.TComment i) ->
+	(* column 0 is the leftmost column. *)
+	Ast_c.col_of_info i > 0
     | _ -> false in
+  let is_nonnl_whitespace_or_noncol0_comment = function
+    | T1(Parser_c.TCommentSpace _) -> true
+  (* patch: cocci    *)
+    | T1(Parser_c.TComment i) ->
+	(* column 0 is the leftmost column. *)
+	Ast_c.col_of_info i > 0
+    | _ -> false in
+  let is_whitespace_or_comment = function
+    | T1(Parser_c.TCommentSpace _)
+    | T1(Parser_c.TCommentNewline _)
+    | T1(Parser_c.TComment _) -> true
+    | _ -> false in
+  let all_directives l =
+    List.for_all
+      (List.for_all (function Ast_cocci.Directive _ -> true | _ -> false))
+      l in
   let rec loop toks =
     let fake_info =
       try Some (split_when is_fake toks)
@@ -291,24 +311,33 @@ let displace_fake_nodes toks =
       (match !(info.Ast_c.cocci_tag) with
       | Some x ->
         (match x with
+        | (Ast_cocci.CONTEXT(_,Ast_cocci.BEFORE (l,_)),_)
+	  when all_directives l ->
+          (* move the fake node forwards *)
+          let (whitespace,rest) = span is_whitespace_or_comment aft in
+          bef @ whitespace @ fake :: (loop rest)
         | (Ast_cocci.MINUS(_,_,_,Ast_cocci.REPLACEMENT _),_)
-          (* for , replacement is more likely to be like after, but not clear...
+          (* for , replacement is more likely to be like after, but not clear.
 	     but treating it as after breaks a lot of tests. *)
-
         | (Ast_cocci.CONTEXT(_,Ast_cocci.BEFORE _),_) ->
           (* move the fake node forwards *)
-          let (whitespace,rest) = span is_whitespace aft in
+          let (whitespace,rest) = span is_whitespace_or_noncol0_comment aft in
+          bef @ whitespace @ fake :: (loop rest)
+        | (Ast_cocci.MINUS(_,_,_,Ast_cocci.NOREPLACEMENT),_) ->
+          (* move the fake node forwards *)
+          let (whitespace,rest) =
+	    span is_nonnl_whitespace_or_noncol0_comment aft in
           bef @ whitespace @ fake :: (loop rest)
-
         | (Ast_cocci.CONTEXT(_,Ast_cocci.AFTER _),_) ->
           (* move the fake node backwards *)
           let revbef = List.rev bef in
-          let (revwhitespace,revprev) = span is_whitespace revbef in
+          let (revwhitespace,revprev) =
+	    span is_whitespace_or_noncol0_comment revbef in
           let whitespace = List.rev revwhitespace in
           let prev = List.rev revprev in
           prev @ fake :: (loop (whitespace @ aft))
         | (Ast_cocci.CONTEXT(_,Ast_cocci.BEFOREAFTER _),_) ->
-          failwith "fake node should not be before-after"	
+          failwith "fake node should not be before-after"
         | (Ast_cocci.CONTEXT(_,Ast_cocci.NOTHING),_)
         | _ -> bef @ fake :: (loop aft) (* old: was removed when have simpler yacfe *)
         )
@@ -344,7 +373,7 @@ let expand_mcode toks =
       let str = Ast_c.str_of_info info in
       let isminus = match minus with Min _ -> true | Ctx -> false in
       (* don't add fake string if the thing should be removed *)
-      if str =$= "" || isminus
+      if str = "" || isminus
       then push2 (Fake2 (info,minus)) toks_out
       (* fx the fake "," at the end of a structure or enum.
       no idea what other fake info there can be... *)
@@ -372,7 +401,7 @@ let expand_mcode toks =
 
       let optindex =
         if TH.is_origin tok && not (TH.is_real_comment tok)
-        then 
+        then
           begin
             incr index;
             Some !index
@@ -524,10 +553,10 @@ let generated_newline = function
 
 let is_fake2 = function Fake2 _ -> true | _ -> false
 
-let is_whitespace x = 
+let is_whitespace x =
   is_space x || is_newline_or_comment x
 
-let is_whitespace_or_fake x = 
+let is_whitespace_or_fake x =
   is_space x || is_newline_or_comment x || is_fake2 x
 
 let is_minusable_comment = function
@@ -544,7 +573,7 @@ let is_minusable_comment = function
     | Parser_c.TCommentCpp (Token_c.CppDirective, _) -> true
     (*
     | Parser_c.TCommentMisc _
-    | Parser_c.TCommentCpp (Token_c.CppPassingCosWouldGetError, _) -> 
+    | Parser_c.TCommentCpp (Token_c.CppPassingCosWouldGetError, _) ->
       false
     *)
     | _ -> false
@@ -564,12 +593,12 @@ let is_minusable_comment_nocpp = function
   | _ -> false
 
 let all_coccis = function
-  | Cocci2 _ | C2 _ | Comma _ | Indent_cocci2 
+  | Cocci2 _ | C2 _ | Comma _ | Indent_cocci2
   | Unindent_cocci2 _ | EatSpace2 -> true
   | _ -> false
 
 (* previously gave up if the first character was a newline, but not clear why *)
-let is_minusable_comment_or_plus x = 
+let is_minusable_comment_or_plus x =
   is_minusable_comment x || all_coccis x
 
 let set_minus_comment adj = function
@@ -599,16 +628,16 @@ let set_minus_comment adj = function
 
 (* don't touch ifdefs, done after *)
 let set_minus_comment_or_plus adj = function
-  | Cocci2 _ | C2 _ | Comma _ | Indent_cocci2 
+  | Cocci2 _ | C2 _ | Comma _ | Indent_cocci2
   | Unindent_cocci2 _ | EatSpace2 as x -> x
   | x -> set_minus_comment adj x
 
 let is_minus = function
   | T2 (_, Min _, _, _) -> true
-  | _ -> false 
+  | _ -> false
 
 let drop_minus xs =
-  xs +> exclude is_minus 
+  xs +> exclude is_minus
 
 let drop_expanded xs =
   xs +> exclude (function
@@ -624,7 +653,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
   (* get rid of expanded tok *)
   let xs = drop_expanded xs in
 
-  let minus_or_comment_or_fake x = 
+  let minus_or_comment_or_fake x =
     is_minus x || is_minusable_comment x || is_fake2 x in
 
   let minus_or_comment_nocpp x =
@@ -651,7 +680,10 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
     | [] -> []
     | (T2(Parser_c.TCommentNewline c,_b,_i,_h) as x)::
       ((T2(_,Min adj1,_,_)) as t1)::xs ->
+	(* don't want to drop newline if - and + code mixed, but do want to
+	   drop a trailing newline that is before + code *)
       let (minus_list,rest) = span_not_context (t1::xs) in
+      let (minus_list,rest) = drop_trailing_plus minus_list rest in
       let (pre_minus_list,_) = span not_context_newline minus_list in
       let contains_plus = List.exists is_plus pre_minus_list in
       let x =
@@ -660,7 +692,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
           when List.for_all minus_or_comment_or_fake minus_list ->
           set_minus_comment_or_plus adj1 x
         | _ -> x in
-      x :: adjust_within_minus contains_plus minus_list 
+      x :: adjust_within_minus contains_plus minus_list
          @ adjust_around_minus rest
     | ((Fake2(_,Min _)) as t0)::
       (T2(Parser_c.TCommentNewline c,_b,_i,_h) as x)::
@@ -674,7 +706,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
           when List.for_all minus_or_comment_or_fake minus_list ->
           set_minus_comment_or_plus adj1 x
         | _ -> x in
-      t0 :: x :: adjust_within_minus contains_plus minus_list 
+      t0 :: x :: adjust_within_minus contains_plus minus_list
          @ adjust_around_minus rest
     | ((Fake2(_,Min adj1) | T2(_,Min adj1,_,_)) as t1)::xs ->
       let (minus_list,rest) = span_not_context (t1::xs) in
@@ -704,7 +736,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
           (List.map (set_minus_comment_or_plus adj1) not_minus_list)
           @ (adjust_within_minus (cp || newcp) (t2::xs))
         else
-          not_minus_list 
+          not_minus_list
 	  @ (adjust_within_minus (cp || newcp) (t2::xs))
       | _ ->
         if cp
@@ -717,6 +749,17 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
           @ rest)
       )
     | xs -> failwith "should always start with minus"
+  and drop_trailing_plus minus_list rest =
+    let rec loop acc = function
+	x::xs ->
+	  if is_plus x
+	  then loop (x::acc) xs
+	  else
+	    if is_newline x
+	    then (List.rev (x::xs), acc@rest)
+	    else (minus_list,rest) (*do nothing if the + code is not after nl*)
+      | _ -> failwith "not possible - always at least one - token" in
+    loop [] (List.rev minus_list)
   and span_not_context xs =
    (* like span not_context xs, but have to parse ifdefs *)
    let rec loop seen_ifdefs = function
@@ -782,7 +825,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
   let rec adjust_after_brace = function
     | [] -> []
     | ((T2(_,Ctx,_,_)) as x)::((T2(_,Min adj,_,_)::_) as xs)
-      when str_of_token2 x =$= "{" ->
+      when str_of_token2 x = "{" ->
       let (between_minus,rest) = span minus_or_comment_nonl xs in
       let (newlines,rest) = span is_whitespace rest in
       let (drop_newlines,last_newline) =
@@ -821,7 +864,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
   let rec adjust_before_brace = function
     | [] -> []
     | ((T2(t,Ctx,_,_)) as x)::xs
-      when str_of_token2 x =$= "}" || is_newline_or_comment x ->
+      when str_of_token2 x = "}" || is_newline_or_comment x ->
       let (outer_spaces,rest) = span is_space xs in
       x :: outer_spaces @
       (match rest with
@@ -843,7 +886,7 @@ let remove_minus_and_between_and_expanded_and_fake1 xs =
       m ::
       (List.map (set_minus_comment adj) spaces) @
       (adjust_before_brace rest)
-    | ((T2 (t0,Ctx, idx0,h0)) as m0) :: 
+    | ((T2 (t0,Ctx, idx0,h0)) as m0) ::
       ((T2 (t,Min adj,idx,h)) as m) :: rest
       when TH.str_of_tok t0 = "" ->
       (* This is for the case of a #define that is completely deleted,
@@ -1080,17 +1123,18 @@ let check_danger toks =
     match get_danger tok with
       Some Ast_c.Danger -> false
     | _ -> true in
-  let not_nodanger tok =
+  let nonspace_danger tok =
     match get_danger tok with
-      Some Ast_c.NoDanger -> false
-    | _ -> true in
+      Some Ast_c.Danger -> true
+    | Some Ast_c.NoDanger -> is_space tok || is_newline_or_comment tok
+    | _ -> false in
   let unminus tok =
     match (tok,get_danger tok) with
       (T2(tok,Min _,a,b),Some Ast_c.Danger) -> T2(tok,Ctx,a,b)
     | _ -> tok in
   let rec unminus_initial_danger toks =
     let (front,rest) = span not_danger toks in
-    let (dangers,rest) = span not_nodanger rest in
+    let (dangers,rest) = span nonspace_danger rest in
     front @ (List.map unminus dangers) @ rest in
   let unminus_danger_end = function
       T2(tok,Min _,a,b) -> T2(tok,Ctx,a,b)
@@ -1322,10 +1366,12 @@ let add_newlines toks tabbing_unit =
     let (tu,tlen) =
       match tabbing_unit with
       | Some "\t" -> ("\t",8)
-      | Some "" -> ("\t",8) (* not sure why... *)
+	| None | Some "" ->
+	  if !Flag_parsing_c.indent = 0
+	  then ("\t",8) (* not sure why "" case... *)
+	  else (!default_indent,!Flag_parsing_c.indent)
       | Some s -> (* assuming only tabs or spaces *)
-	  (s,simple_string_length s 0)
-      | None -> ("\t",8) in
+	  (s,simple_string_length s 0) in
     let rec loop seen =
       if seen + tlen <= n
       then tu ^ loop (seen + tlen)
@@ -1576,7 +1622,7 @@ let add_newlines toks tabbing_unit =
 let new_tabbing2 space =
   list_of_string space
     +> List.rev
-    +> take_until (fun c -> c =<= '\n')
+    +> take_until (fun c -> c = '\n')
     +> List.rev
     +> List.map string_of_char
     +> String.concat ""
@@ -1752,6 +1798,12 @@ let adjust_by_function getter op k q vl xs =
       fn PlusOnly vl1
   | _ -> vl
 
+let getval (am,ap) = function
+    PlusOnly -> ap
+  | MinusOnly -> am
+  | Both -> am (* no idea, pick - arbitrarily *)
+  | Neither -> am
+
 let adjust_by_op fn (am,ap) = function
     PlusOnly -> (am,fn ap)
   | MinusOnly -> (fn am,ap)
@@ -1778,12 +1830,13 @@ let token_effect tok dmin dplus inparens inassn inbrace accumulator xs =
   let info = parse_token tok in
   match info with
     (Tok ")",op)
-    when inparens <= 1 && inassn = 0 && inbrace > 0 ->
+    when getval inparens op <= 1 && getval inassn op = 0 &&
+      getval inbrace op > 0 ->
       let nopen_brace a b = not (open_brace a b) in
       let do_nothing a b = b in
       let accumulator =
 	adjust_by_function nopen_brace op accadd1 do_nothing accumulator xs in
-      (Other 1,dmin,dplus,0,0,inbrace,accumulator)
+      (Other 1,dmin,dplus,(0,0),(0,0),inbrace,accumulator)
   | (Tok "else",op) ->
       (* is_nl is for the case where the next statement is on the same line
 	 as the else *)
@@ -1793,23 +1846,26 @@ let token_effect tok dmin dplus inparens inassn inbrace accumulator xs =
       let do_nothing a b = b in
       let accumulator =
 	adjust_by_function nopen_brace op accadd1 do_nothing accumulator xs in
-      (Other 1,dmin,dplus,0,0,inbrace,accumulator)
+      (Other 1,dmin,dplus,(0,0),(0,0),inbrace,accumulator)
   | (Tok "{",op) ->
       let (dmin,dplus) = add1 op (dmin,dplus) in
       let accumulator = add1top op accumulator in
-      (Other 2,dmin,dplus,inparens,0,inbrace+1,accumulator)
+      (Other 2,dmin,dplus,inparens,(0,0),add1 op inbrace,accumulator)
   | (Tok "}",op) ->
       let (dmin,dplus) = sub1 op (dmin,dplus) in
       let accumulator = sub1top op accumulator in
-      (Other 3,dmin,dplus,inparens,0,inbrace-1,drop_zeroes op accumulator xs)
-  | (Tok(";"|","),op) when inparens = 0 && inassn <= 1 ->
-      (Other 4,dmin,dplus,inparens,0,inbrace,drop_zeroes op accumulator xs)
+      (Other 3,dmin,dplus,inparens,(0,0),sub1 op inbrace,
+       drop_zeroes op accumulator xs)
+  | (Tok(";"|","),op) when getval inparens op = 0 && getval inassn op <= 1 ->
+      (Other 4,dmin,dplus,inparens,(0,0),inbrace,drop_zeroes op accumulator xs)
   | (Tok ";",op) ->
-      (Other 5,dmin,dplus,inparens,max 0 (inassn-1),inbrace,accumulator)
-  | (Tok "=",op) when inparens+inassn = 0 ->
-      (Other 6,dmin,dplus,inparens,1,inbrace,accumulator)
-  | (Tok "(",op) -> (Other 7,dmin,dplus,inparens+1,inassn,inbrace,accumulator)
-  | (Tok ")",op) -> (Other 8,dmin,dplus,inparens-1,inassn,inbrace,accumulator)
+      (Other 5,dmin,dplus,inparens,sub1 op inassn,inbrace,accumulator)
+  | (Tok "=",op) when getval inparens op + getval inassn op = 0 ->
+      (Other 6,dmin,dplus,inparens,add1 op (0,0),inbrace,accumulator)
+  | (Tok "(",op) ->
+      (Other 7,dmin,dplus,add1 op inparens,inassn,inbrace,accumulator)
+  | (Tok ")",op) ->
+      (Other 8,dmin,dplus,sub1 op inparens,inassn,inbrace,accumulator)
   | (Ind Indent_cocci2,op) ->
       (Drop,dmin,dplus,inparens,inassn,inbrace,accumulator)
   | (Ind (Unindent_cocci2 true),op) ->
@@ -1823,11 +1879,13 @@ let token_effect tok dmin dplus inparens inassn inbrace accumulator xs =
       then (* ignore indentation *)
 	(Label,dmin,dplus,inparens,inassn,inbrace,accumulator)
       else
+	let inp = getval inparens op in
+	let ina = getval inassn op in
 	let rebuilder min plus =
 	  match op with
-	    Both -> CtxNL(after,min,plus,inparens+inassn)
-	  | MinusOnly -> MinNL(after,min,plus,inparens+inassn)
-	  | PlusOnly -> PlusNL(plus,inparens+inassn)
+	    Both -> CtxNL(after,min,plus,inp+ina)
+	  | MinusOnly -> MinNL(after,min,plus,inp+ina)
+	  | PlusOnly -> PlusNL(plus,inp+ina)
 	  | _ -> failwith "not possible" in
 	let numacc =
 	  (List.length (fst accumulator), List.length (snd accumulator)) in
@@ -1868,7 +1926,7 @@ let parse_indentation xs =
 	front @
 	((n+List.length front),res,x) ::
 	loop (n+1) dmin dplus inparens inassn inbrace accumulator xs in
-  loop 1 0 0 0 0 0 ([],[]) xs
+  loop 1 0 0 (0,0) (0,0) (0,0) ([],[]) xs
 
 exception NoInfo
 
@@ -1918,7 +1976,8 @@ let update_map_min n spaces tabbing_unit past_minus_map depthmin dmin
 
 let times before n tabbing_unit ctr =
   (if n < 0 then failwith (Printf.sprintf "n is %d\n" n));
-  let tabbing_unit = match tabbing_unit with None -> "\t" | Some tu -> tu in
+  let tabbing_unit =
+    match tabbing_unit with None -> !default_indent | Some tu -> tu in
   let rec loop = function
       0 -> before
     | n -> (loop (n-1)) ^ tabbing_unit in
@@ -1927,7 +1986,8 @@ let times before n tabbing_unit ctr =
 (* adds to the front *)
 let times_before after n tabbing_unit ctr =
   (if n < 0 then failwith (Printf.sprintf "n is %d\n" n));
-  let tabbing_unit = match tabbing_unit with None -> "\t" | Some tu -> tu in
+  let tabbing_unit =
+    match tabbing_unit with None -> !default_indent | Some tu -> tu in
   let rec loop = function
       0 -> after
     | n -> tabbing_unit ^ (loop (n-1)) in
@@ -1936,7 +1996,8 @@ let times_before after n tabbing_unit ctr =
 (* drops from the front *)
 let untimes_before cur n tabbing_unit ctr =
   (if n < 0 then failwith (Printf.sprintf "n is %d\n" n));
-  let tabbing_unit = match tabbing_unit with None -> "\t" | Some tu -> tu in
+  let tabbing_unit =
+    match tabbing_unit with None -> !default_indent | Some tu -> tu in
   let len = String.length tabbing_unit in
   let tabbing_unit = Str.regexp_string tabbing_unit in
   let rec loop cur = function
@@ -1994,11 +2055,16 @@ let plus_search_in_maps n depth inparens past_minmap minmap tu t =
     try Some(List.assoc (depth,inparens) minmap) with _ -> None in
   get_answer fail2 map1 map2
 
-let context_search_in_maps n depth inparens past_minmap minmap tu t =
+let context_search_in_maps n depth samedelta inparens past_minmap minmap tu t =
   let findn map =
-    try
-      Some(List.find (function ((_,ip),(n1,_)) -> ip = inparens && n = n1) map)
-    with Not_found -> None in
+    if not samedelta
+    then None
+    else
+      (* favor just shifing left *)
+      try
+	Some(List.find (function ((_,ip),(n1,_)) -> ip = inparens && n = n1)
+	       map)
+      with Not_found -> None in
   let before = findn past_minmap in
   let after = findn minmap in (* should be the same... *)
   (if not (before = after)
@@ -2085,7 +2151,9 @@ let adjust_indentation xs =
 	  let t =
 	    if not (depthmin = depthplus) (*&& is_cocci rest*)
 	    then
-	      context_search_in_maps n depthplus inparens past_minmap minmap
+	      context_search_in_maps n depthplus
+		((depthmin - depthplus) = (dmin - dplus))
+		inparens past_minmap minmap
 		tabbing_unit (C2("\n",None))
 	    else t in
 	  (out_tu,minmap,t::res)
@@ -2126,8 +2194,8 @@ let rec find_paren_comma = function
   (* do nothing if was like this in original file *)
   | { str = "("; idx = Some p1 } :: ({ str = ","; idx = Some p2} :: _ as xs)
   | { str = ","; idx = Some p1 } :: ({ str = ","; idx = Some p2} :: _ as xs)
-  | { str = ","; idx = Some p1 } :: ({ str = ")"; idx = Some p2} :: _ as xs) 
-    when p2 =|= p1 + 1 ->
+  | { str = ","; idx = Some p1 } :: ({ str = ")"; idx = Some p2} :: _ as xs)
+    when p2 = p1 + 1 ->
     find_paren_comma xs
 
   (* otherwise yes can adjust *)
@@ -2170,8 +2238,8 @@ let drop_line toks =
 	(false, toks) in
   let rec loop toks =
     match toks with
-    | (T2(_, Min _, _, _) as x) :: tl 
-      when str_of_token2 x =$= "}" -> 
+    | (T2(_, Min _, _, _) as x) :: tl
+      when str_of_token2 x = "}" ->
 	let (drop, tl) = space_until_newline tl in
 	(drop, x :: tl)
     | hd :: tl when is_whitespace hd ->
@@ -2225,9 +2293,9 @@ let print_all_tokens2 pr xs =
     let current_kind = ref KOrigin in
     xs +> List.iter (fun t ->
       let newkind = kind_of_token2 t in
-      if newkind =*= !current_kind
+      if newkind = !current_kind
       then pr (str_of_token2 t)
-      else 
+      else
         begin
           pr (end_mark);
           pr (start_mark newkind);
@@ -2236,7 +2304,7 @@ let print_all_tokens2 pr xs =
         end
     );
   else
-    let to_whitespace s = 
+    let to_whitespace s =
       let r = Bytes.copy s in
       for i = 1 to String.length r do
         let c = String.get r (i-1) in
@@ -2338,7 +2406,7 @@ let pp_program2 xs outfile  =
           then
             (* nothing else to do for sgrep *)
             drop_expanded(drop_fake(drop_minus toks))
-          else 
+          else
             begin
               (* phase2: can now start to filter and adjust *)
 	      let toks = check_danger toks in
@@ -2365,7 +2433,7 @@ let pp_program2 xs outfile  =
 
         (* in theory here could reparse and rework the ast! or
          * apply some SP. Not before cos julia may have generated
-         * not parsable file. Need do unparsing_tricks call before 
+         * not parsable file. Need do unparsing_tricks call before
 	 * being ready to reparse. *)
         print_all_tokens2 pr toks;
 
@@ -2374,9 +2442,13 @@ let pp_program2 xs outfile  =
   )
 
 let pp_program a b =
+  (if !Flag_parsing_c.indent > 0
+  then default_indent := String.make !Flag_parsing_c.indent ' ');
   profile_code "C unparsing" (fun () -> pp_program2 a b)
 
 
 let pp_program_default xs outfile =
+  (if !Flag_parsing_c.indent > 0
+  then default_indent := String.make !Flag_parsing_c.indent ' ');
   let xs' = xs +> List.map (fun x -> x, PPnormal) in
   pp_program xs' outfile
