@@ -329,8 +329,7 @@ let rec vk_expr = fun bigf expr ->
      *          List.iter (vk_statement bigf) statxs
      *)
     | StatementExpr ((statxs, is)) ->
-        iif is;
-        statxs +> List.iter (vk_statement_sequencable bigf);
+        iif is; vk_statement_sequencable_list bigf statxs
 
     | Constructor (t, init) ->
         vk_type bigf t; vk_ini bigf init
@@ -342,6 +341,7 @@ let rec vk_expr = fun bigf expr ->
         vk_argument_list bigf ts;
 	vk_argument bigf t
     | Delete e -> vk_expr bigf e
+    | Defined name -> vk_name bigf name
 
 
   in exprf expr
@@ -397,7 +397,7 @@ and vk_statement = fun bigf (st: Ast_c.statement) ->
     | Labeled (Default st) -> statf st;
 
     | Compound statxs ->
-        statxs +> List.iter (vk_statement_sequencable bigf)
+	vk_statement_sequencable_list bigf statxs
     | ExprStatement (eopt) -> do_option (vk_expr bigf) eopt;
 
     | Selection  (If (e, st1, st2)) ->
@@ -442,6 +442,9 @@ and vk_statement = fun bigf (st: Ast_c.statement) ->
 
   in statf st
 
+and vk_statement_sequencable_list = fun bigf stms ->
+  stms +> List.iter (vk_statement_sequencable bigf)
+
 and vk_statement_sequencable = fun bigf stseq ->
   let f = bigf.kstatementseq in
 
@@ -455,7 +458,7 @@ and vk_statement_sequencable = fun bigf stseq ->
     | IfdefStmt2 (ifdef, xxs) ->
         ifdef +> List.iter (vk_ifdef_directive bigf);
         xxs +> List.iter (fun xs ->
-          xs +> List.iter (vk_statement_sequencable bigf)
+	  vk_statement_sequencable_list bigf xs
         )
 
   in f (k, bigf) stseq
@@ -537,10 +540,10 @@ and vk_decl = fun bigf d ->
         iif ii;
         vk_onedecl bigf x
       );
-    | MacroDecl ((s, args, ptvg),ii) ->
+    | MacroDecl ((_stob, s, args, ptvg),ii) ->
         iif ii;
         vk_argument_list bigf args
-    | MacroDeclInit ((s, args, ini),ii) ->
+    | MacroDeclInit ((_stob, s, args, ini),ii) ->
         iif ii;
         vk_argument_list bigf args;
 	vk_ini bigf ini
@@ -704,7 +707,7 @@ and vk_def = fun bigf d ->
           decls +> List.iter (vk_decl bigf);
         );
 
-        statxs +> List.iter (vk_statement_sequencable bigf)
+	vk_statement_sequencable_list bigf statxs
   in f (k, bigf) d
 
 
@@ -873,7 +876,7 @@ and vk_node = fun bigf node ->
     match F.unwrap n with
 
     | F.FunHeader (def) ->
-        assert(null (fst def).f_body);
+        assert( (fst def).f_body = []);
         vk_def bigf def;
 
     | F.Decl decl -> vk_decl bigf decl
@@ -1160,7 +1163,7 @@ let rec vk_expr_s = fun bigf expr ->
       | CondExpr (e1, e2, e3)   -> CondExpr (exprf e1, fmap exprf e2, exprf e3)
       | Sequence (e1, e2)        -> Sequence (exprf e1, exprf e2)
       | Assignment (e1, op, e2)  ->
-        let e1 = exprf e1 in 
+        let e1 = exprf e1 in
         let op = vk_assignOp_s bigf op in
         let e2 = exprf e2 in
         Assignment (e1, op, e2)
@@ -1194,6 +1197,7 @@ let rec vk_expr_s = fun bigf expr ->
 	  New (Some (ts +> List.map (fun (e,ii) ->
 	    vk_argument_s bigf e, iif ii)), vk_argument_s bigf t)
       | Delete e      -> Delete (vk_expr_s bigf e)
+      | Defined name  -> Defined (vk_name_s bigf name)
 
     in
     (e', typ'), (iif ii)
@@ -1446,15 +1450,15 @@ and vk_decl_s = fun bigf d ->
     match decl with
     | DeclList (xs, ii) ->
         DeclList (List.map aux xs,   iif ii)
-    | MacroDecl ((s, args, ptvg),ii) ->
+    | MacroDecl ((stob, s, args, ptvg),ii) ->
         MacroDecl
-          ((s,
+          ((stob, s,
            args +> List.map (fun (e,ii) -> vk_argument_s bigf e, iif ii),
            ptvg),
           iif ii)
-    | MacroDeclInit ((s, args, ini),ii) ->
+    | MacroDeclInit ((stob, s, args, ini),ii) ->
         MacroDeclInit
-          ((s,
+          ((stob, s,
            args +> List.map (fun (e,ii) -> vk_argument_s bigf e, iif ii),
 	   vk_ini_s bigf ini),
           iif ii)
@@ -1794,7 +1798,7 @@ and vk_node_s = fun bigf node ->
     F.rewrap node (
     match F.unwrap node with
     | F.FunHeader (def) ->
-        assert (null (fst def).f_body);
+        assert ( (fst def).f_body = []);
         F.FunHeader (vk_def_s bigf def)
 
     | F.Decl declb -> F.Decl (vk_decl_s bigf declb)
@@ -1857,7 +1861,7 @@ and vk_node_s = fun bigf node ->
                  i_content = copt;
                  }
       ->
-        assert (copt =*= None);
+        assert (copt = None);
         F.Include {i_include = (s, iif ii);
                     i_rel_pos = h_rel_pos;
                     i_is_in_ifdef = b;
