@@ -99,7 +99,7 @@ and metavar =
   | MetaFieldDecl of arity * meta_name (* name *)
   | MetaFieldListDecl of arity * meta_name (* name *) * list_len (*len*)
   | MetaStmDecl of arity * meta_name (* name *)
-  | MetaStmListDecl of arity * meta_name (* name *)
+  | MetaStmListDecl of arity * meta_name (* name *) * list_len (*len*)
   | MetaFuncDecl of arity * meta_name (* name *)
   | MetaLocalFuncDecl of arity * meta_name (* name *)
   | MetaPosDecl of arity * meta_name (* name *)
@@ -490,7 +490,7 @@ and base_rule_elem =
   | MetaRuleElem  of meta_name mcode * keep_binding * inherited
   | MetaStmt      of meta_name mcode * keep_binding * metaStmtInfo *
 	             inherited
-  | MetaStmtList  of meta_name mcode * keep_binding * inherited
+  | MetaStmtList  of meta_name mcode * listlen * keep_binding * inherited
 
   | Exp           of expression
   | TopExp        of expression (* for macros body *)
