@@ -795,7 +795,7 @@ let rec equal_statement s1 s2 =
       equal_mcode exec1 exec2 && equal_mcode lang1 lang2 &&
       equal_mcode sem1 sem2
   | (Ast0.MetaStmt(name1,_),Ast0.MetaStmt(name2,_))
-  | (Ast0.MetaStmtList(name1,_),Ast0.MetaStmtList(name2,_)) ->
+  | (Ast0.MetaStmtList(name1,_,_),Ast0.MetaStmtList(name2,_,_)) ->
       equal_mcode name1 name2
   | (Ast0.Disj(starter1,_,mids1,ender1),Ast0.Disj(starter2,_,mids2,ender2)) ->
       equal_mcode starter1 starter2 &&
