@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./insert_plus.ml"
 (* The error message "no available token to attach to" often comes in an
 argument list of unbounded length.  In this case, one should move a comma so
 that there is a comma after the + code. *)
@@ -69,8 +48,6 @@ it *)
 	   Ast0.NestExpr(starter,exp,ender,whencode,multi) ->
 	     Ast0.NestExpr(starter,exp,ender,None,multi)
 	 | Ast0.Edots(dots,whencode) -> Ast0.Edots(dots,None)
-	 | Ast0.Ecircles(dots,whencode) -> Ast0.Ecircles(dots,None)
-	 | Ast0.Estars(dots,whencode) -> Ast0.Estars(dots,None)
 	 | e -> e)) in
 
   let initialiser r k i =
@@ -87,8 +64,6 @@ it *)
 	   Ast0.Nest(started,stm_dots,ender,whencode,multi) ->
 	     Ast0.Nest(started,stm_dots,ender,[],multi)
 	 | Ast0.Dots(dots,whencode) -> Ast0.Dots(dots,[])
-	 | Ast0.Circles(dots,whencode) -> Ast0.Circles(dots,[])
-	 | Ast0.Stars(dots,whencode) -> Ast0.Stars(dots,[])
 	 | s -> s)) in
 
   let topfn r k e = Ast0.TopTag(e) :: (k e) in
@@ -202,7 +177,7 @@ bind to that; not good for isomorphisms *)
 	| x::xs -> bind x (loop xs) in
       loop l in
 
-    let l = Ast0.undots d in
+    let l = Ast0.unwrap d in
     match checklast with
       None -> multibind (List.map f l)
     | Some checklast ->
@@ -283,9 +258,8 @@ bind to that; not good for isomorphisms *)
     | Ast0.Nest(starter,stmt_dots,ender,whencode,multi) ->
 	mcode starter @ r.VT0.combiner_rec_statement_dots stmt_dots @
 	mcode ender
-    | Ast0.Dots(d,whencode) | Ast0.Circles(d,whencode)
-    | Ast0.Stars(d,whencode) -> mcode d (* ignore whencode *)
-    | Ast0.OptStm s | Ast0.UniqueStm s ->
+    | Ast0.Dots(d,whencode) -> mcode d (* ignore whencode *)
+    | Ast0.OptStm s ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_statement s
     | _ -> do_nothing r k s in
@@ -301,30 +275,29 @@ bind to that; not good for isomorphisms *)
       Ast0.NestExpr(starter,expr_dots,ender,whencode,multi) ->
 	mcode starter @
 	r.VT0.combiner_rec_expression_dots expr_dots @ mcode ender
-    | Ast0.Edots(d,whencode) | Ast0.Ecircles(d,whencode)
-    | Ast0.Estars(d,whencode) -> mcode d (* ignore whencode *)
-    | Ast0.OptExp e | Ast0.UniqueExp e ->
+    | Ast0.Edots(d,whencode) -> mcode d (* ignore whencode *)
+    | Ast0.OptExp e ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_expression e
     | _ -> do_nothing r k e in
 
   let ident r k e =
     match Ast0.unwrap e with
-      Ast0.OptIdent i | Ast0.UniqueIdent i ->
+      Ast0.OptIdent i ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_ident i
     | _ -> do_nothing r k e in
 
   let typeC r k e =
     match Ast0.unwrap e with
-      Ast0.OptType t | Ast0.UniqueType t ->
+      Ast0.OptType t ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_typeC t
     | _ -> do_nothing r k e in
 
   let decl r k e =
     match Ast0.unwrap e with
-      Ast0.OptDecl d | Ast0.UniqueDecl d ->
+      Ast0.OptDecl d ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_declaration d
     | _ -> do_nothing r k e in
@@ -332,14 +305,14 @@ bind to that; not good for isomorphisms *)
   let initialiser r k e =
     match Ast0.unwrap e with
       Ast0.Idots(d,whencode) -> mcode d (* ignore whencode *)
-    | Ast0.OptIni i | Ast0.UniqueIni i ->
+    | Ast0.OptIni i ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_initialiser i
     | _ -> do_nothing r k e in
 
   let param r k e =
     match Ast0.unwrap e with
-      Ast0.OptParam p | Ast0.UniqueParam p ->
+      Ast0.OptParam p ->
 	(* put the + code on the thing, not on the opt *)
 	r.VT0.combiner_rec_parameter p
     | _ -> do_nothing r k e in
@@ -573,6 +546,7 @@ let collect_plus_nodes root =
       Ast0.Exp(exp) -> r.VT0.combiner_rec_expression exp
     | Ast0.TopExp(exp) -> r.VT0.combiner_rec_expression exp
     | Ast0.Ty(ty) -> r.VT0.combiner_rec_typeC ty
+    | Ast0.TopId(id) -> r.VT0.combiner_rec_ident id
     | Ast0.TopInit(init) -> r.VT0.combiner_rec_initialiser init
     | Ast0.Decl(bef,decl) ->
 	 do_nothing_extra (pre_info bef) [] mk_statement r k e
@@ -594,8 +568,7 @@ let collect_plus_nodes root =
   replaced by one statement, in single_statement *)
   let stmt_dots r k e =
     match Ast0.unwrap e with
-      Ast0.DOTS([s]) | Ast0.CIRCLES([s]) | Ast0.STARS([s]) ->
-	r.VT0.combiner_rec_statement s
+      [s] -> r.VT0.combiner_rec_statement s
     | _ -> do_nothing mk_stmtdots r k e in
 
   let toplevel r k e =
