@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./yes_pycocci.ml"
 open Ast_c
 open Common
 open Pycaml
@@ -58,13 +37,13 @@ let _pycocci_tuple6 (a,b,c,d,e,f) =
 (* ------------------------------------------------------------------- *)
 
 let check_return_value msg v =
-  if v =*= (pynull ()) then
+  if v = (pynull ()) then
 	  (pyerr_print ();
 	  Common.pr2 ("while " ^ msg ^ ":");
 	  raise Pycocciexception)
   else ()
 let check_int_return_value msg v =
-  if v =|= -1 then
+  if v = -1 then
 	  (pyerr_print ();
           Common.pr2 ("while " ^ msg ^ ":");
 	  raise Pycocciexception)
@@ -157,7 +136,7 @@ let has_environment_binding name =
   let (rule, name) = (Array.get a 1, Array.get a 2) in
   let orule = pystring_asstring rule in
   let oname = pystring_asstring name in
-  let e = List.exists (function (x,y) -> orule =*= x && oname =$= y)
+  let e = List.exists (function (x,y) -> orule = x && oname = y)
       !the_environment in
   if e then _pycocci_true () else _pycocci_false ()
 
@@ -178,11 +157,6 @@ let pycocci_init () =
   (* initialize *)
   if not !initialised then (
   initialised := true;
-  (* use python_path_base as default (overridable) dir for coccilib *)
-  let python_path_base = Printf.sprintf "%s/coccinelle" (Unix.getenv "HOME") in
-  let python_path = try Unix.getenv "PYTHONPATH" ^ ":" ^ python_path_base
-                    with Not_found -> python_path_base in
-  Unix.putenv "PYTHONPATH" python_path;
   let _ = if not (py_isinitialized () != 0) then
   	(if !Flag.show_misc then Common.pr2 "Initializing python\n%!";
 	py_initialize()) in
@@ -248,14 +222,14 @@ let get_variable name =
 
 let contains_binding e (_,(r,m),_) =
   try
-    let _ = List.find (function ((re, rm), _) -> r =*= re && m =$= rm) e in
+    let _ = List.find (function ((re, rm), _) -> r = re && m = rm) e in
     true
   with Not_found -> false
 
 let construct_variables mv e =
   let find_binding (r,m) =
     try
-      let elem = List.find (function ((re,rm),_) -> r =*= re && m =$= rm) e in
+      let elem = List.find (function ((re,rm),_) -> r = re && m = rm) e in
       Some elem
     with Not_found -> None
   in
@@ -287,14 +261,24 @@ let construct_variables mv e =
 	(pytuple_fromarray (Array.of_list [str;elements])) in
     let _ = build_variable py repr in () in
 
-  List.iter (function (py,(r,m),_) ->
+  List.iter (function (py,(r,m),_,init) ->
     match find_binding (r,m) with
-      None -> ()
-(*    | Some (_, Ast_c.MetaExprVal (expr,_)) ->
+      None ->
+	(match init with
+	  Ast_cocci.MVInitString s ->
+            let _ = build_variable py (pystring_fromstring s) in
+	    ()
+	| Ast_cocci.MVInitPosList ->
+	    let pylocs = pytuple_fromarray (Array.of_list []) in
+	    let _ = build_variable py pylocs in
+	    ()
+	| Ast_cocci.NoMVInit ->
+	    failwith "python variables should be bound")
+(*    | Some (_, Ast_c.MetaExprVal (expr,_,_)) ->
        let expr_repr = instantiate_Expression(expr) in
        let _ = build_variable py expr_repr in
        () *)
-  (*  | Some (_, Ast_c.MetaIdVal (id,_)) ->
+  (*  | Some (_, Ast_c.MetaIdVal id) ->
        let id_repr = instantiate_Identifier(id) in
        let _ = build_variable py id_repr in
        () *)
@@ -340,7 +324,7 @@ let construct_script_variables mv =
     mv
 
 let retrieve_script_variables mv =
-  List.map (function (_,py) -> get_variable py) mv
+  List.map (function (_,py) -> Ast_c.MetaIdVal(get_variable py)) mv
 
 let set_coccifile cocci_file =
 	cocci_file_name := cocci_file;
