@@ -4,30 +4,30 @@
 
 /* This file contains:
  *   - macros found in <.h>
- *   - macros found in ".h" 
- *     but where we cant detect that it will be a "bad macro"
+ *   - macros found in ".h"
+ *     but where we cannot detect that it will be a "bad macro"
  *   - hints, cf below.
- * 
+ *
  * A "bad macro" is a macro using free variables or when expanded
- * that influence the control-flow of the code. In those cases it 
+ * that influence the control-flow of the code. In those cases it
  * is preferable to expand the macro so that the coccinelle engine
  * has a more accurate representation of what is going on.
- * 
  *
  *
  *
- * old: this file was also containing what is below but now we 
+ *
+ * old: this file was also containing what is below but now we
  * try to expand on demand the macro found in the c file, so those cases
  * are not needed any more:
  *   - macros found in .c; macros that cannot be parsed.
  *     In the future should be autodetected
  *     (not so easy to do same for macros in .h cos require to access .h file)
  *   - macros found in .c; macros correctly parsed
- *     but where we cant detect that it will be a "bad macro"
+ *     but where we cannot detect that it will be a "bad macro"
  *
  * Some of those macros could be deleted and the C code rewritten because
  * they are "bad" macros.
- * 
+ *
  * todo? perhaps better if could enable/disable some of those expansions
  * as different software may use conflicting macros.
  *
@@ -40,9 +40,9 @@
 // Hints
 // ****************************************************************************
 
-/* Cooperation with parsing_hack.ml: some body of macros in this file, such  
+/* Cooperation with parsing_hack.ml: some body of macros in this file, such
  * as MACROSTATEMENT, are considered as magic strings.
- * I can't just expand those macros into some 'whatever();' because I need 
+ * I can't just expand those macros into some 'whatever();' because I need
  * to generate a TMacroStmt for solving some ambiguities in the grammar
  * for the toplevel stuff I think.
  * Right now a set of special strings are used as "hints" to the parser
@@ -74,20 +74,25 @@
 // after a -extract_macros
 // update: now handled in lexer, simplify stuff
 //#define __stdcall /*could: YACFE_ATTRIBUTE*/
-//#define __declspec(a) 
+//#define __declspec(a)
 
 //#define WINAPI
 //#define CALLBACK
 
 
 // ****************************************************************************
-// Linux macros 
+// Linux macros
 // ****************************************************************************
 
 // ----------------------------------------------------------------------------
 // Attributes. could perhaps generalize via "__.*"
 // ----------------------------------------------------------------------------
 #define  __init
+#define  __initconst
+#define  __page_aligned_data
+#define  __page_aligned_bss
+#define  __always_unused
+#define  __visible
 #define  __exit
 #define  __user
 #define  __iomem
@@ -102,6 +107,7 @@
 #define  __initdata_or_module
 #define  __pminit
 #define  __pminitdata
+#define  __irq_entry
 
 #define  __cacheline_aligned
 #define  ____cacheline_aligned
@@ -119,7 +125,7 @@
 
 #define  __must_check
 // pb
-#define  __unused 
+#define  __unused
 #define  __maybe_unused
 
 
@@ -132,7 +138,7 @@
 
 #define  __xipram
 
-// in the other part of the kernel, in arch/, mm/, etc 
+// in the other part of the kernel, in arch/, mm/, etc
 #define  __sched
 #define  __initmv
 #define  __exception
@@ -178,7 +184,7 @@
 
 #define __thread
 #define __used
-#define __pure 
+#define __pure
 
 #define __ref
 #define __refdata
@@ -202,21 +208,21 @@
  * be considered as a declaration with XX being a typedef, so would
  * Have ambiguity. So at least by adding this special case, we can
  * catch more correct string-macro, no more a XX YY but now a good
- * "XX" YY 
- * 
+ * "XX" YY
+ *
  * cf include/linux/kernel.h
  *
- * For stringification I need to have at least a witness, a string, 
+ * For stringification I need to have at least a witness, a string,
  * and sometimes have just printk(KERN_WARNING MYSTR) and it could
  * be transformed in a typedef later, so better to at least
  * transform in string already the string-macro we know.
- * 
- * Perhaps better to apply also as soon as possible the 
+ *
+ * Perhaps better to apply also as soon as possible the
  * correct macro-annotation tagging (__init & co) to be able to
  * filter them as soon as possible so that they will not polluate
  * our pattern-matching that come later.
  */
-  
+
 #define  KERN_EMERG "KERN_EMERG"
 #define  KERN_ALERT "KERN_ALERT"
 #define  KERN_CRIT "KERN_CRIT"
@@ -227,15 +233,15 @@
 #define  KERN_DEBUG "KERN_DEBUG"
 
 
-/* EX_TABLE & co. 
+/* EX_TABLE & co.
  *
  * Replaced by a string. We can't put everything as comment
  * because it can be part of an expression where we wait for
- * something, where we wait for a string. So at least we 
+ * something, where we wait for a string. So at least we
  * must keep the EX_TABLE token and transform it as a string.
  *
- * normally not needed if have good stringification of macro 
- * but those macros are sometimes used multiple times 
+ * normally not needed if have good stringification of macro
+ * but those macros are sometimes used multiple times
  * as in EX_TABLE(0b) EX_TABLE(1b)  and we don't detect
  * it well yet.
  */
@@ -272,7 +278,7 @@
 
 #define  PNMI_STATIC static
 #define  RLMT_STATIC static
-#define  SISINITSTATIC static 
+#define  SISINITSTATIC static
 #define  SCTP_STATIC static
 
 #define  BUGLVL if
@@ -315,6 +321,9 @@
 #define  ASC_INITDATA
 #define  in2000__INITDATA
 #define  PACKED
+#define  __packed
+#define  __rcu
+#define  __percpu
 
 #define  WPMINFO
 #define  CPMINFO
@@ -341,7 +350,7 @@
 #define  EARLY_INIT_SECTION_ATTR
 
 // pb
-//#define  INIT 
+//#define  INIT
 
 #define  IDI_CALL_ENTITY_T
 #define  IDI_CALL_LINK_T
@@ -351,19 +360,20 @@
  * code
  */
 #define uninitialized_var(x) x = x
-// as in u16 uninitialized_var(ioboard_type);	/* GCC be quiet */ 
+// as in u16 uninitialized_var(ioboard_type);	/* GCC be quiet */
 
 // ----------------------------------------------------------------------------
 // ----------------------------------------------------------------------------
 
-#define __releases(x) 
-#define __acquires(x) 
+#define __releases(x)
+#define __acquires(x)
 
 //now in lexer
-//#define __declspec(x) 
+//#define __declspec(x)
 
-#define __page_aligned(x) 
-#define __vsyscall(x) 
+#define __page_aligned(x)
+#define __aligned(x)
+#define __vsyscall(x)
 
 // ----------------------------------------------------------------------------
 // ----------------------------------------------------------------------------
@@ -413,12 +423,12 @@ static const struct machine_desc __mach_desc_##_type	\
 // include/linux/types.h
 //#define BITS_TO_LONGS(bits) \
 //	(((bits)+BITS_PER_LONG-1)/BITS_PER_LONG)
-#define DECLARE_BITMAP(name,bits) \
-	/*unsigned*/ long name[BITS_TO_LONGS(bits)]
+#define DECLARE_BITMAP(name,bits)
+//	/*unsigned*/ long name[BITS_TO_LONGS(bits)]
 
 
 // include/asm-i386/percpu.h
-// interesting macro where we see the need of __typeof__(type) with 
+// interesting macro where we see the need of __typeof__(type) with
 // for example DECLARE_PER_CPU(char[256], iucv_dbf_txt_buf);
 #define DEFINE_PER_CPU(type, name) \
     __attribute__((__section__(".data.percpu"))) __typeof__(type) per_cpu__##name
@@ -440,7 +450,7 @@ struct subsystem _name##_subsys = { \
 // ----------------------------------------------------------------------------
 
 // pb: if use this macro then we will not transform the argument of CS_CHECK
-// in some rules. 
+// in some rules.
 //#define CS_CHECK(fn, ret) \
 //  do { last_fn = (fn); if ((last_ret = (ret)) != 0) goto cs_failed; } while (0)
 
@@ -493,8 +503,8 @@ struct subsystem _name##_subsys = { \
 
 
 // net/ipv4/netfilter/ip_conntrack_helper_h323_asn1.c
-// also used in other.c that don't do any include :( 
-// but locally redefined in drivers/net/bnx2.c :( with a 
+// also used in other.c that don't do any include :(
+// but locally redefined in drivers/net/bnx2.c :( with a
 // #define FNAME	0x8
 #define FNAME(name) name,
 
@@ -535,7 +545,7 @@ struct subsystem _name##_subsys = { \
 
 // drivers/net/wireless/arlan-proc.c
 // incomplete macro, the real macro is quite complex and use other macros
-#define ARLAN_SYSCTL_TABLE_TOTAL(x) 
+#define ARLAN_SYSCTL_TABLE_TOTAL(x)
 
 
 // ----------------------------------------------------------------------------
@@ -723,8 +733,8 @@ do {									\
 	struct meta_obj *dst, int *err)
 
 
-#define GDTH_INITFUNC(x,y) x y 
-#define ASC_INITFUNC(x,y) x y 
+#define GDTH_INITFUNC(x,y) x y
+#define ASC_INITFUNC(x,y) x y
 
 
 // ----------------------------------------------------------------------------
@@ -744,8 +754,25 @@ do {									\
 //#define __PROM_O32
 
 // ----------------------------------------------------------------------------
-// for tests-big/ macros, may be obsolete now cos fixed in latest kernel 
+// for tests-big/ macros, may be obsolete now cos fixed in latest kernel
 // ----------------------------------------------------------------------------
 
 // rule10
 //#define	 ACPI_MODULE_NAME(x)
+
+// ----------------------------------------------------------------------------
+// system calls
+// ----------------------------------------------------------------------------
+
+#define SYSCALL_DEFINE1(func, t1, a1) \
+    asmlinkage unsigned long func(t1 a1)
+#define SYSCALL_DEFINE2(func, t1, a1, t2, a2) \
+    asmlinkage unsigned long func(t1 a1, t2 a2)
+#define SYSCALL_DEFINE3(func, t1, a1, t2, a2, t3, a3) \
+    asmlinkage unsigned long func(t1 a1, t2 a2, t3 a3)
+#define SYSCALL_DEFINE4(func, t1, a1, t2, a2, t3, a3, t4, a4) \
+    asmlinkage unsigned long func(t1 a1, t2 a2, t3 a3, t4 a4)
+#define SYSCALL_DEFINE5(func, t1, a1, t2, a2, t3, a3, t4, a4, t5, a5) \
+    asmlinkage unsigned long func(t1 a1, t2 a2, t3 a3, t4 a4, t5 a5)
+#define SYSCALL_DEFINE6(func, t1, a1, t2, a2, t3, a3, t4, a4, t5, a5, t6, a6) \
+    asmlinkage unsigned long func(t1 a1, t2 a2, t3 a3, t4 a4, t5 a5, t6 a6)
