@@ -1,37 +1,16 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./cstripenv.ml"
 (* This tool strips code from a C file that relies on the external
  * macro and type environment, which we would obtain via commandline
  * parameters and includes.
  * The resulting file is more likely to be analyzable without the
  * headers, although it does affect the semantics of the original
  * program.
- * 
+ *
  * It does so by removing toplevel elements that cannot be parsed
  * correctly because of macro's. Macro's that are interpreted as
  * functions are still kept.
@@ -48,7 +27,7 @@ let hide_visitor =
       begin
 	match p with
 	  Ast_c.NotParsedCorrectly ii ->
-            let first_i = List.hd ii in	  
+            let first_i = List.hd ii in
 	    let last_i  = List.hd (List.rev ii) in
 	    Ast_c.put_annot_info first_i Token_annot.Exclude_start Token_annot.Unit;
 	    Ast_c.put_annot_info last_i Token_annot.Exclude_end Token_annot.Unit
