@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./splitpatch.ml"
 (* split patch per file *)
 
 (* ------------------------------------------------------------------------ *)
@@ -514,7 +493,12 @@ let make_mail_header o date maintainers ctr number cover subject =
   | _ -> failwith "no maintainers");
   if number = 1 && not cover
   then Printf.fprintf o "Subject: [PATCH] %s\n\n" subject
-  else Printf.fprintf o "Subject: [PATCH %d/%d] %s\n\n" ctr number subject
+  else
+    if number >= 100
+    then Printf.fprintf o "Subject: [PATCH %03d/%d] %s\n\n" ctr number subject
+    else if number >= 10
+    then Printf.fprintf o "Subject: [PATCH %02d/%d] %s\n\n" ctr number subject
+    else Printf.fprintf o "Subject: [PATCH %d/%d] %s\n\n" ctr number subject
 
 let print_info o info_tbl files =
   let do_one prefix file =
@@ -536,7 +520,7 @@ let cluster_by_dir diffs =
 	 (function (file,diff) ->
 	   (Filename.dirname file, file, diff))
 	 diffs) in
-  let rec loop = function 
+  let rec loop = function
       [] -> []
     | (dir,file,diffs)::rest ->
 	match loop rest with
@@ -557,7 +541,7 @@ let make_message_files subject cover message nonmessage date maintainer_table
       (function (services,maintainers) ->
 	function diffs ->
 	  function rest ->
-	    if services=[default_string] or nomerge
+	    if services=[default_string] || nomerge
 	    then
 	      (* if no maintainer, then one file per diff *)
 	      let diffs =
@@ -596,6 +580,10 @@ let make_message_files subject cover message nonmessage date maintainer_table
 		rest)
       maintainer_table [] in
   let number = List.length elements in
+  let elements =
+    List.sort
+      (fun (_,(ctr1,_,_,_,_)) (_,(ctr2,_,_,_,_)) -> compare ctr1 ctr2)
+      elements in
   let generated =
     List.map
       (function (common,(ctr,the_rest,maintainers,files,diffs)) ->
@@ -625,13 +613,13 @@ let make_message_files subject cover message nonmessage date maintainer_table
 	(if not(stat = Unix.WEXITED 0)
 	then (print_all stderr info; Printf.fprintf stderr "\n"));
 	output_file)
-      (List.rev elements) in
+      elements in
   let later = add_ext(Printf.sprintf "%s%d" front (number+1)) in
   if Sys.file_exists later
   then Printf.fprintf stderr "Warning: %s and other files may be left over from a previous run\n" later;
   generated
 
-let make_cover_file n subject cover front date maintainer_table =
+let make_cover_file n file subject cover front date maintainer_table =
   match cover with
     None -> ()
   | Some cover ->
@@ -663,8 +651,21 @@ let make_cover_file n subject cover front date maintainer_table =
       let o = open_out output_file in
       make_mail_header o date maintainers_and_lists 0 n true subject;
       print_all o cover;
-      Printf.fprintf o "\n";
-      close_out o
+      Printf.fprintf o "\n---\n\n";
+      let l = cmd_to_list (Printf.sprintf "diffstat -p1 < %s" file) in
+      let adjust_after =
+	match !prefix_after with
+	  None -> l
+	| Some pa ->
+	    let pa = (String.concat "/" (Str.split (Str.regexp "/") pa))^"/" in
+	    List.map
+	      (function l -> String.concat "" (Str.split (Str.regexp pa) l))
+	      l in
+      List.iter
+	(function line -> Printf.fprintf o "%s\n" line)
+	adjust_after;
+      close_out o;
+      ()
 
 let mail_sender = "git send-email" (* use this when it works *)
 let mail_sender = "cocci-send-email.perl"
@@ -696,7 +697,7 @@ let make_output_files subject cover message nonmessage
   let generated =
     make_message_files subject cover message nonmessage date maintainer_table
       patch front add_ext nomerge dirmerge info_tbl in
-  make_cover_file (List.length generated) subject cover front date
+  make_cover_file (List.length generated) patch subject cover front date
     maintainer_table;
   generate_command front cover generated
 
