@@ -1,30 +1,9 @@
 (*
- * Copyright 2012-2015, Inria
- * Julia Lawall, Gilles Muller
- * Copyright 2010-2011, INRIA, University of Copenhagen
- * Julia Lawall, Rene Rydhof Hansen, Gilles Muller, Nicolas Palix
- * Copyright 2005-2009, Ecole des Mines de Nantes, University of Copenhagen
- * Yoann Padioleau, Julia Lawall, Rene Rydhof Hansen, Henrik Stuart, Gilles Muller, Nicolas Palix
- * This file is part of Coccinelle.
- *
- * Coccinelle is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, according to version 2 of the License.
- *
- * Coccinelle is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Coccinelle.  If not, see <http://www.gnu.org/licenses/>.
- *
- * The authors reserve the right to distribute this or future versions of
- * Coccinelle under other licenses.
+ * This file is part of Coccinelle, lincensed under the terms of the GPL v2.
+ * See copyright.txt in the Coccinelle source code for more information.
+ * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
  *)
 
-
-# 0 "./spp.ml"
 open Common
 
 exception WrongArguments
@@ -86,7 +65,7 @@ let main () =
              let cpp_flags = cpp_flags_filter args in
              let cmd2 =
                (spf "cpp %s %s > %s.i"
-                  (Common.join " " cpp_flags)
+                  (String.concat " " cpp_flags)
                   file
                   file)
              in
@@ -94,7 +73,7 @@ let main () =
                let ret2 = Sys.command cmd2 in
 		 if ret2 > 0 then exit ret2;
 		 let sp_args = fix_args args file in
-		 let cmd = "spatch " ^ (Common.join " " sp_args) in
+		 let cmd = "spatch " ^ (String.concat " " sp_args) in
 		   pr2 cmd;
 		   let ret = Sys.command cmd in
 		     exit ret
@@ -108,7 +87,7 @@ let main () =
       let (nargs, outfile) = get_outputfile args in
       let cmd2 =
         (spf "cat %s > %s"
-                  (Common.join " " nargs)
+                  (String.concat " " nargs)
                   outfile)
       in
         pr2 cmd2;
